@@ -25,7 +25,8 @@ proc asjob_main {{root .}} {
    init_asjob
    set asjob::fen_root $root
    set asjob::popup .asjob_popup
-   wm protocol $asjob::fen_root WM_DELETE_WINDOW { set asjob::actu(indic) 0;destroy $asjob::fen_root }
+   set asjob::popup_clear .asjob_popup_clear
+   wm protocol $asjob::fen_root WM_DELETE_WINDOW { set asjob::actu(indic) 0; destroy $asjob::fen_root }
    wm title    $asjob::fen_root [ashare::mess ihm 137 $astk::astk_version]
    set_icon $asjob::fen_root
    if { $asjob::fen_root == "." } {
@@ -110,15 +111,22 @@ proc loadStateJob {w {bysel 0}} {
                set is [valid_serveur $machexe $user nom_complet]
                set out ""
                if { $is == -888 } {
-                  set out "Serveur dans l'tat off"
+                  set out [ashare::mess ihm 395]
                } elseif { $is != -999 } {
+                  set nsrv $astk::inv(cmpl,$machexe,$user)
                   # etat du serveur
+                  set ftmp [get_tmpname .actu_export]
+                  set idexp [open $ftmp w]
+                  write_server_infos $idexp $nsrv
+                  puts $idexp "P jobid $num"
+                  puts $idexp "P nomjob $nom"
+                  puts $idexp "P mode $mode"
+                  close $idexp
                   set lcmd ""
-                  append lcmd [file join $astk::config($astk::inv(cmpl,$machexe,$user),rep_serv) "bin" as_run]
-                  append lcmd " --actu"
+                  append lcmd [file join $ashare:::prefix "bin" as_run]
+                  append lcmd " --proxy --actu --schema=[get_schema $nsrv actu] $ftmp"
                   append lcmd [ashare::get_glob_args]
-                  set argu "$num $nom $mode"
-                  set retour [ashare::rexec_cmd $astk::inv(cmpl,$machexe,$user) astk::config $lcmd $argu 0 out $asjob::fen_root]
+                  set retour [ashare::rexec_cmd -1 astk::config $lcmd "" 0 out $asjob::fen_root progress]
                } else {
                   set out [ashare::mess ihm 360]
                   ashare::mess erreur 47 $machexe $user
@@ -226,13 +234,20 @@ proc suppr_job { w } {
                      set confirm "yes"
                   }
                   if { $confirm == "yes" } {
-                     set retour -1
                      lappend ljconf $sel
-                     append cmd [file join $astk::config($nsrv,rep_serv) "bin" as_run]
-                     append cmd " --del"
+                     set ftmp [get_tmpname .del_export.$nf]
+                     set idexp [open $ftmp w]
+                     write_server_infos $idexp $nsrv
+                     puts $idexp "P jobid $num"
+                     puts $idexp "P nomjob $nom"
+                     puts $idexp "P mode $mode"
+                     puts $idexp "P noeud $noeud"
+                     close $idexp
+                     set retour -1
+                     append cmd [file join $ashare::prefix "bin" as_run]
+                     append cmd " --proxy --del --schema=[get_schema $nsrv stop_del] $ftmp"
                      append lcmd [ashare::get_glob_args]
-                     append cmd " --signal=KILL"
-                     append cmd " $num $nom $mode $noeud ; "
+                     append cmd " --signal=KILL ; "
                   }
                }
                append cmd "\""
@@ -242,7 +257,7 @@ proc suppr_job { w } {
             # execution si plus d'un job  supprimer
                set out ""
                if { $inc > 0 } {
-                  set retour [ashare::rexec_cmd $nsrv astk::config $cmd "" 0 out $asjob::fen_root]
+                  set retour [ashare::rexec_cmd -1 astk::config $cmd "" 0 out $asjob::fen_root progress]
                }
                # nbre de code retour
                set nret [llength $retour]
@@ -287,14 +302,18 @@ proc purge_job { } {
    # interrogation de chaque serveur
    for {set nsrv 0} {$nsrv < $astk::config(nb_serv)} {incr nsrv} {
       set nbj 0
-      set cmd [file join $astk::config($nsrv,rep_serv) "bin" as_run]
-      append lcmd [ashare::get_glob_args]
-      append cmd " --purge_flash"
+      set ftmp [get_tmpname .purge_export]
+      set idexp [open $ftmp w]
+      write_server_infos $idexp $nsrv
+      close $idexp
+      set cmd [file join $ashare::prefix "bin" as_run]
+      append cmd [ashare::get_glob_args]
+      append cmd " --proxy --purge_flash --schema=[get_schema $nsrv purge_flash] $ftmp"
       set id [array startsearch asjob::TextJobs]
       for {set i 0} {$i < $nb_jobs} {incr i} {
          set elt    [array nextelement asjob::TextJobs $id]
          set valjob [lindex [array get asjob::TextJobs $elt] 1]
-         
+
          set num     [lindex $valjob [lindex $asjob::paraJob(numero) 0]]
          set machexe [lindex $valjob [lindex $asjob::paraJob(machine) 0]]
          set user    [lindex $valjob [lindex $asjob::paraJob(user) 0]]
@@ -311,7 +330,7 @@ proc purge_job { } {
       array donesearch asjob::TextJobs $id
       # execution si plus d'un job sur ce serveur
       if { $nbj > 0 } {
-         set iret [ashare::rexec_cmd $nsrv astk::config $cmd "" 0 out $asjob::fen_root]
+         set iret [ashare::rexec_cmd -1 astk::config $cmd "" 0 out $asjob::fen_root progress]
          if { $iret != 0 } {
             set asjob::status "<ERREUR> Purge sur $machexe, Code retour : $iret"
          }
@@ -328,7 +347,7 @@ proc susp_job { w } {
       for {set i 0} {$i < [llength $indsel]} {incr i} {
          set nsel [lindex $indsel $i]
          set sel  [lindex $asjob::Jobs $nsel]
-      # on appelle le service as_edit
+      # on appelle le service as_del
          set num     [lindex $sel [lindex $asjob::paraJob(numero) 0]]
          set nom     [lindex $sel [lindex $asjob::paraJob(nom) 0]]
          set mode    [lindex $sel [lindex $asjob::paraJob(mode) 0]]
@@ -340,21 +359,29 @@ proc susp_job { w } {
             set retour -1
             set is [valid_serveur $machexe $user nom_complet]
             if { $is == -888 } {
-               set out "Serveur dans l'tat off"
+               set out [ashare::mess ihm 395]
             } elseif { $is != -999 } {
+               set nsrv $astk::inv(cmpl,$machexe,$user)
+               set ftmp [get_tmpname .del_export]
+               set idexp [open $ftmp w]
+               write_server_infos $idexp $nsrv
+               puts $idexp "P jobid $num"
+               puts $idexp "P nomjob $nom"
+               puts $idexp "P mode $mode"
+               puts $idexp "P noeud $noeud"
+               close $idexp
                set lcmd ""
-               append lcmd [file join $astk::config($astk::inv(cmpl,$machexe,$user),rep_serv) "bin" as_run]
-               append lcmd " --del"
+               append lcmd [file join $ashare::prefix "bin" as_run]
+               append lcmd " --proxy --del --schema=[get_schema $nsrv stop_del] $ftmp"
                append lcmd [ashare::get_glob_args]
                append lcmd " --signal=USR1"
-               set argu "$num $nom $mode $noeud"
-               set retour [ashare::rexec_cmd $astk::inv(cmpl,$machexe,$user) astk::config $lcmd $argu 1 out $asjob::fen_root]
+               set retour [ashare::rexec_cmd -1 astk::config $lcmd "" 0 out $asjob::fen_root progress]
             } else {
                set out [ashare::mess ihm 360]
                ashare::mess erreur 47 $machexe $user
             }
          } else {
-            set asjob::status "<ALARME> tat du job = $etat"
+            set asjob::status "<ALARM> job status = $etat"
          }
       }
    }
@@ -378,6 +405,19 @@ proc textLoadFile {w file} {
       close $f
    }
 }
+
+#### ===========
+proc textLoadVar { w var } {
+#### ===========
+# Cette procdure permet de charger le contenu d'une variable dans un
+# widget de type Text.
+#
+# Arguments:
+# w    : Nom d'une fenetre de type text
+    $w delete 1.0 end
+    $w insert end $var
+}
+
 #### ===========
 proc lbxLoadFile {w file} {
 #### ===========
@@ -435,27 +475,37 @@ proc editJobSel {w type} {
             set is [valid_serveur $machexe $user nom_complet]
             set out ""
             if { $is == -888 } {
-               set out "Serveur dans l'tat off"
+               set out [ashare::mess ihm 395]
             } elseif { $is != -999 } {
+               set nsrv $astk::inv(cmpl,$machexe,$user)
                set bg 1
-               set lcmd ""
-               append lcmd [file join $astk::config($astk::inv(cmpl,$machexe,$user),rep_serv) "bin" as_run]
-               append lcmd " --edit"
                if { $action == "output_html" } {
-                  append lcmd " --result_to_output"
                   set bg 0
                   set type "output"
                }
+               set ftmp [get_tmpname .edit_export]
+               set idexp [open $ftmp w]
+               write_server_infos $idexp $nsrv
+               puts $idexp "P jobid $num"
+               puts $idexp "P nomjob $nom"
+               puts $idexp "P mode $mode"
+               puts $idexp "P display $ashare::DISPLAY"
+               puts $idexp "P edit_type $type"
+               close $idexp
+               set lcmd ""
+               append lcmd [file join $ashare::prefix "bin" as_run]
+               append lcmd " --proxy --edit --schema=[get_schema $nsrv edit] $ftmp"
+               if { $action == "output_html" } {
+                  append lcmd " --result_to_output"
+               }
                append lcmd [ashare::get_glob_args]
-               set displ $ashare::DISPLAY
-               set argu "$num $nom $mode $type $displ"
-               set retour [ashare::rexec_cmd $astk::inv(cmpl,$machexe,$user) astk::config $lcmd $argu $bg out $asjob::fen_root]
+               set retour [ashare::rexec_cmd -1 astk::config $lcmd "" $bg out $asjob::fen_root]
                if { $action == "output_html" } {
                   set fres [file join $astk::tmpdir "$nom.$num.output"]
                   set idout [open $fres "w"]
                   puts $idout $out
                   close $idout
-                  set retour [ashare::rexec_cmd -1 astk::config [file join $ashare::prefix "bin" "as_run"] "--convert_to_html --output=$fres.html $fres" 0 out $asjob::fen_root]
+                  set retour [ashare::rexec_cmd -1 astk::config [file join $ashare::prefix "bin" "as_run"] "--convert_to_html --output=$fres.html $fres" 0 out $asjob::fen_root progress]
                   ashare::file_open_url $fres.html
                }
             } else {
@@ -471,11 +521,72 @@ proc editJobSel {w type} {
                set asjob::status "<INFO> Edition $num $nom"
             }
          } else {
-            set asjob::status "<ALARME> tat du job = $etat"
+            set asjob::status [ashare::mess ihm 394 $etat ENDED]
+            loadStateJob $w 1
          }
       }
    }
 }
+
+#### =============
+proc getResultsSel { w } {
+#### =============
+# rcupre les fichiers rsultats
+# Arguments:
+# w : widget listbox
+   if { [$w curselection] == "" } {
+      set asjob::status [ashare::mess ihm 393]
+   } else {
+      set indsel [$w curselection]
+      set nsel   [lindex $indsel 0]
+      $w selection clear 0 end
+      $w selection set $nsel
+      set sel   [lindex $asjob::Jobs $nsel]
+
+      set num     [lindex $sel [lindex $asjob::paraJob(numero) 0]]
+      set nom     [lindex $sel [lindex $asjob::paraJob(nom) 0]]
+      set mode    [lindex $sel [lindex $asjob::paraJob(mode) 0]]
+      set machexe [lindex $sel [lindex $asjob::paraJob(machine) 0]]
+      set user    [lindex $sel [lindex $asjob::paraJob(user) 0]]
+      set etat    [lindex $sel [lindex $asjob::paraJob(etat) 0]]
+      if { $etat == "ENDED" } {
+            set retour -1
+            set is [valid_serveur $machexe $user nom_complet]
+            set out ""
+            if { $is == -888 } {
+               set out [ashare::mess ihm 395]
+            } elseif { $is != -999 } {
+               set nsrv $astk::inv(cmpl,$machexe,$user)
+               set bg 0
+               set ftmp [get_tmpname .getres_export]
+               set idexp [open $ftmp w]
+               write_server_infos $idexp $nsrv
+               puts $idexp "P jobid $num"
+               puts $idexp "P nomjob $nom"
+               puts $idexp "P mode $mode"
+               close $idexp
+               set lcmd ""
+               append lcmd [file join $ashare::prefix "bin" as_run]
+               append lcmd " --proxy --get_results --schema=[get_schema $nsrv get_results]"
+               append lcmd [ashare::get_glob_args]
+               set argu "$ftmp"
+               set retour [ashare::rexec_cmd -1 astk::config $lcmd $argu $bg out $asjob::fen_root progress]
+            } else {
+               set out [ashare::mess ihm 360]
+               ashare::mess erreur 47 $machexe $user
+            }
+            if { $retour != 0 } {
+               set asjob::status [ashare::mess erreur 54 [ashare::mess ihm 392] $retour]
+            } else {
+               set asjob::status [ashare::mess ihm 396]
+            }
+
+      } else {
+         set asjob::status [ashare::mess ihm 394 $etat ENDED]
+      }
+   }
+}
+
 #### ==========
 proc tailJobSel { w } {
 #### ==========
@@ -485,7 +596,7 @@ proc tailJobSel { w } {
    global expr_tail
 #
    if { [$w curselection] == "" } {
-      set asjob::status "<ALARME> Slectionner tout d'abord un job !"
+      set asjob::status [ashare::mess ihm 393]
    } else {
       lire_job asjob::TextJobs $asjob::NomSuivi
       set indsel [$w curselection]
@@ -493,7 +604,7 @@ proc tailJobSel { w } {
       $w selection clear 0 end
       $w selection set $nsel
       set sel  [lindex $asjob::Jobs $nsel]
-      
+
       set num     [lindex $sel [lindex $asjob::paraJob(numero) 0]]
       set sel $asjob::TextJobs($num)
   #
@@ -507,26 +618,27 @@ proc tailJobSel { w } {
       set etat    [lindex $sel [lindex $asjob::paraJob(etat) 0]]
       if { $etat == "RUN" } {
          set nb        $astk::config(-1,nb_ligne)
-         set output    [file join $astk::tmpdir output]
-         file delete -force $output
-         if { [ashare::meme_machine $astk::config(-1,nom_complet) $machexe] 
-           && $astk::config(-1,login) == $user } {
-            set r_output  "$output"
-         } else {
-            set r_output  "$astk::config(-1,login)@$astk::config(-1,nom_complet):$output"
-         }
          set retour -1
          set is [valid_serveur $machexe $user nom_complet]
          set out ""
          if { $is == -888 } {
-            set out "Serveur dans l'tat off"
+            set out [ashare::mess ihm 395]
          } elseif { $is != -999 } {
+            set nsrv $astk::inv(cmpl,$machexe,$user)
+            set ftmp [get_tmpname .tail_export]
+            set idexp [open $ftmp w]
+            write_server_infos $idexp $nsrv
+            puts $idexp "P jobid $num"
+            puts $idexp "P nomjob $nom"
+            puts $idexp "P mode $mode"
+            puts $idexp "P tail_nbline $nb"
+            puts $idexp "P tail_regexp $expr_tail"
+            close $idexp
             set lcmd ""
-            append lcmd [file join $astk::config($astk::inv(cmpl,$machexe,$user),rep_serv) "bin" as_run]
-            append lcmd " --tail"
+            append lcmd [file join $ashare::prefix "bin" as_run]
+            append lcmd " --proxy --tail --schema=[get_schema $nsrv tail] $ftmp"
             append lcmd [ashare::get_glob_args]
-            set argu "$num $nom $mode $r_output $nb \"$expr_tail\""
-            set retour [ashare::rexec_cmd $astk::inv(cmpl,$machexe,$user) astk::config $lcmd $argu 0 out $asjob::fen_root]
+            set retour [ashare::rexec_cmd -1 astk::config $lcmd "" 0 out $asjob::fen_root progress]
          } else {
             set out [ashare::mess ihm 360]
             ashare::mess erreur 47 $machexe $user
@@ -550,13 +662,13 @@ proc tailJobSel { w } {
             lbxLoadFile $w $asjob::NomSuivi
          } else {
             set asjob::status "<INFO> Consultation  $num $nom"
-            textLoadFile $asjob::actu(f_tail) $output
+            textLoadVar $asjob::actu(f_progress) $out
          }
          $w yview end
-         $asjob::actu(f_tail) yview end
+         $asjob::actu(f_progress) yview end
       } else {
-         $asjob::actu(f_tail) delete 1.0 end
-         set asjob::status "<ALARME> tat du job = $etat"
+         $asjob::actu(f_progress) delete 1.0 end
+         set asjob::status [ashare::mess ihm 394 $etat RUN]
       }
    }
 }
@@ -565,7 +677,7 @@ proc reactu_jobs  { } {
 #### ============
    if { $asjob::actu(indic) == 1 && $astk::config(-1,freq_actu) > 0 } {
       loadStateJob $asjob::actu(f_actu)
-      set val_ms [expr $astk::config(-1,freq_actu) * 60 * 1000]
+      set val_ms [expr int($astk::config(-1,freq_actu) * 60) * 1000]
       set asjob::actu(id_after) [after $val_ms {reactu_jobs}]
    } else {
       if { $asjob::actu(id_after) > 0 } {
@@ -609,7 +721,7 @@ proc affiche_main { w } {
    set fstat $w.statusbar
 #
    set asjob::actu(f_actu) $fensuiv.ftx1.lbx
-   set asjob::actu(f_tail) $ftail.lbx2
+   set asjob::actu(f_progress) $ftail.lbx2
 #  Barre de status
    pack [frame $fstat] -side bottom -fill x -pady 2
 
@@ -647,26 +759,26 @@ proc affiche_main { w } {
 # Liste des boutons situs  droite
 #
    set m  $fbout.file.m
-   menubutton $fbout.file -text "Editer" -font $but_fnt -menu $m -relief raised \
+   menubutton $fbout.file -text [ashare::mess ihm 410] -font $but_fnt -menu $m -relief raised \
         -background $astk::ihm(couleur,valid)
    menu $m -tearoff 0 \
         -foreground $astk::ihm(couleur,menu_foreground) \
         -background $astk::ihm(couleur,menu_background)
-   $m add command -label "Fichier output" -underline 8 -font $but_fnt -command "editJobSel $fensuiv.ftx1.lbx output"
-   $m add command -label "Fichier error"  -underline 8 -font $but_fnt -command "editJobSel $fensuiv.ftx1.lbx error"
+   $m add command -label [ashare::mess ihm 397] -underline 8 -font $but_fnt -command "editJobSel $fensuiv.ftx1.lbx output"
+   $m add command -label [ashare::mess ihm 398]  -underline 8 -font $but_fnt -command "editJobSel $fensuiv.ftx1.lbx error"
    grid $fbout.file -row 0 -column 0 -sticky ew -pady 5
 
-   button $fbout.su -text "Supprimer " -font $but_fnt -command "suppr_job $fensuiv.ftx1.lbx"
+   button $fbout.su -text [ashare::mess ihm 406] -font $but_fnt -command "suppr_job $fensuiv.ftx1.lbx"
    grid $fbout.su   -row 1 -column 0 -sticky ew -pady 5
 
    # initialise le verrouillage
    set loadStateJob_lock 0
-   button $fbout.ac -text "Actualiser " -font $but_fnt -command "loadStateJob $fensuiv.ftx1.lbx"
+   button $fbout.ac -text [ashare::mess ihm 404] -font $but_fnt -command "loadStateJob $fensuiv.ftx1.lbx"
    grid $fbout.ac   -row 2 -column 0 -sticky ew -pady 5
 
    checkbutton $fbout.cb -variable asjob::actu(indic) -command "reactu_jobs"
    grid $fbout.cb   -row 2 -column 1 -sticky w -pady 5
-   
+
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Listbox utilise pour afficher la liste des travaux
 #
@@ -683,9 +795,9 @@ proc affiche_main { w } {
 # Champ utilis pour la recherche d'expressions rgulires dans le fichier message
 #
    frame  $ftail.filtre
-   label  $ftail.filtre.label -text "Filtre :" -font $but_fnt -anchor w
+   label  $ftail.filtre.label -text "[ashare::mess ihm 399] :" -font $but_fnt -anchor w
    entry  $ftail.filtre.entry -width 40 -textvariable expr_tail
-   button $ftail.filtre.button -text "Rechercher " -font $but_fnt -command "tailJobSel $fensuiv.ftx1.lbx"
+   button $ftail.filtre.button -text [ashare::mess ihm 411] -font $but_fnt -command "tailJobSel $fensuiv.ftx1.lbx"
    pack   $ftail.filtre.label -side left
    pack   $ftail.filtre.entry -side left -expand yes -fill x
    pack   $ftail.filtre.button -side left -pady 5 -padx 10
@@ -702,6 +814,7 @@ proc affiche_main { w } {
    pack $ftail.scrolly -side right  -fill y
    pack $ftail.scrollx -side bottom -fill x
    pack $ftail.lbx2    -expand yes -fill both
+   bind $ftail.lbx2 <3> { clear_text_menu %W %X %Y }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Barre de status : affichage des erreurs, alarmes et informations
@@ -753,19 +866,19 @@ proc affiche_main { w } {
    }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-#  ctrl+Q pour fermer
-   bind $asjob::fen_root <Control-Key-Q> "set asjob::actu(indic) 0;destroy $asjob::fen_root"
-   bind $asjob::fen_root <Control-Key-q> "set asjob::actu(indic) 0;destroy $asjob::fen_root"
+#  ctrl+w pour fermer
+   bind $asjob::fen_root <Control-Key-w> "set asjob::actu(indic) 0;destroy $asjob::fen_root"
 
    update
-   wm geometry $asjob::fen_root $asjob::size(root)
-# ne marche pas bien : la fenetre se maximise !?
-#    ashare::trace_geom asjob $asjob::fen_root
+   ashare::trace_geom asjob $asjob::fen_root
 
    # initialisation du popup menu
    if { ! [winfo exists $asjob::popup] } {
       asjob_popup $w.princ.suivi $asjob::popup
    }
+   if { ! [winfo exists $asjob::popup_clear] } {
+      clear_text_popup $asjob::popup_clear
+   }
 }
 
 # construit le popup menu
@@ -774,16 +887,38 @@ proc asjob_popup { fensuiv m } {
    menu $m -tearoff 0 -bd 1 \
         -foreground $astk::ihm(couleur,menu_foreground) \
         -background $astk::ihm(couleur,menu_background)
-   $m add command -label "Editer output" -font $astk::ihm(font,labmenuB) -command "editJobSel $fensuiv.ftx1.lbx output"
-   #$m add command -label "Editer output.html BETA" -font $astk::ihm(font,labmenu) -command "editJobSel $fensuiv.ftx1.lbx output_html"
-   $m add command -label "Editer error" -font $astk::ihm(font,labmenu)  -command "editJobSel $fensuiv.ftx1.lbx error"
-   $m add command -label "Editer export" -font $astk::ihm(font,labmenu)  -command "editJobSel $fensuiv.ftx1.lbx export"
+   $m add command -label [ashare::mess ihm 400] -font $astk::ihm(font,labmenuB) -command "editJobSel $fensuiv.ftx1.lbx output"
+   #$m add command -label [ashare::mess ihm 403] -font $astk::ihm(font,labmenu) -command "editJobSel $fensuiv.ftx1.lbx output_html"
+   $m add command -label [ashare::mess ihm 401] -font $astk::ihm(font,labmenu) -command "editJobSel $fensuiv.ftx1.lbx error"
+   $m add command -label [ashare::mess ihm 402] -font $astk::ihm(font,labmenu) -command "editJobSel $fensuiv.ftx1.lbx export"
+   $m add command -label [ashare::mess ihm 392] -font $astk::ihm(font,labmenu) -command "getResultsSel $fensuiv.ftx1.lbx"
    $m add separator
-   $m add command -label "Actualiser" -font $astk::ihm(font,labmenu) -command "loadStateJob $fensuiv.ftx1.lbx 1"
-   $m add command -label "Actualiser tous" -font $astk::ihm(font,labmenu)  -command "$fensuiv.bout.ac invoke"
+   $m add command -label [ashare::mess ihm 404] -font $astk::ihm(font,labmenu) -command "loadStateJob $fensuiv.ftx1.lbx 1"
+   $m add command -label [ashare::mess ihm 405] -font $astk::ihm(font,labmenu) -command "$fensuiv.bout.ac invoke"
    $m add separator
-   $m add command -label "Supprimer" -font $astk::ihm(font,labmenu)  -command "$fensuiv.bout.su invoke"
-   $m add command -label "Arrter proprement" -font $astk::ihm(font,labmenu)  -command "susp_job $fensuiv.ftx1.lbx"
-   $m add command -label "Purger flasheur" -font $astk::ihm(font,labmenu)  -command "purge_job"
+   $m add command -label [ashare::mess ihm 406] -font $astk::ihm(font,labmenu) -command "$fensuiv.bout.su invoke"
+   $m add command -label [ashare::mess ihm 407] -font $astk::ihm(font,labmenu) -command "susp_job $fensuiv.ftx1.lbx"
+   $m add command -label [ashare::mess ihm 408] -font $astk::ihm(font,labmenu) -command "purge_job"
 }
 
+# reinit progress text
+#################################################################
+proc clear_progress { w } {
+    $w delete 1.0 end
+    catch { file delete $ashare::fic_progress }
+}
+
+# popup clear text
+#################################################################
+proc clear_text_popup { m } {
+    menu $m -tearoff 0 -bd 1 \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
+   $m add command -label [ashare::mess ihm 409] -font $astk::ihm(font,labmenuB) -command "clear_progress $asjob::actu(f_progress)"
+}
+
+# clear text
+#################################################################
+proc clear_text_menu { w x y } {
+   tk_popup $asjob::popup_clear $x $y
+}
