@@ -27,10 +27,27 @@ proc ashare::init_mots_config { } {
    set ashare::mots(MCF_serv) { serveur }
    set ashare::mots(MCS_serv) { nom_complet login home etat rep_serv asrun_vers recup last_recup \
                                 xterm editeur }
-   set ashare::mots(MCS_serv_opt) { plate-forme \
-                             batch batch_tpsmax batch_memmax batch_nbpmax batch_mpi_nbpmax batch_queue_group \
-                             interactif interactif_tpsmax interactif_memmax interactif_nbpmax interactif_mpi_nbpmax \
-                             vers noeud mach_ref islocal }
+   set ashare::mots(MCS_serv_opt) { plate-forme
+                             batch batch_tpsmax batch_memmax batch_nbpmax batch_mpi_nbpmax batch_queue_group
+                             interactif interactif_tpsmax interactif_memmax interactif_nbpmax interactif_mpi_nbpmax
+                             vers noeud mach_ref islocal
+                             protocol_exec protocol_copyto protocol_copyfrom proxy_dir
+                             schema_actu
+                             schema_edit
+                             schema_get_results
+                             schema_info
+                             schema_purge_flash
+                             schema_sendmail
+                             schema_serv
+                             schema_stop_del
+                             schema_tail
+                             schema_get_export
+                             schema_create_issue
+                             schema_insert_in_db
+                             schema_profile_modifier
+                             schema_calcul
+                             schema_execute
+                             }
 }
 
 # Lecture de la liste des serveurs disponibles et de leurs options
@@ -39,9 +56,9 @@ proc ashare::lire_options { fich tabl } {
    upvar $tabl config
    if { $ashare::dbg >= 4 } {
       ashare::log "<DEBUG> (lire_options) Lecture $fich" }
-   
+
    set config(nb_serv) 0
-   
+
    set iret [lire_mc_val $fich mots vale nlu ]
    if { $iret != 0 } {
       return $iret
@@ -141,7 +158,6 @@ proc ashare::lire_options { fich tabl } {
 }
 
 # Sauvegarde des options (serveurs et options de config)
-#MC_TEST pas encore partag !
 #################################################################
 proc ashare::save_options { } {
    # garde l'ancien fichier
@@ -166,13 +182,15 @@ proc ashare::save_options { } {
          }
          if { $mcs == "vers" || $mcs == "noeud" } {
             for { set j 0 } { $j < $astk::config($serv,nb_$mcs) } { incr j } {
-               puts $id "$mcs : $astk::config($serv,$mcs,$j)"
+               set val [unexpandvars $astk::config($serv,$mcs,$j)]
+               puts $id "$mcs : $val"
             }
          } else {
             set val  $astk::config($serv,$mcs)
             if { $val == "" } {
                set val "_VIDE"
             }
+            set val [unexpandvars $val]
             puts $id "$mcs : $val"
          }
       }
@@ -188,19 +206,19 @@ proc ashare::save_options { } {
 proc whoami {} {
     global env
     if {[info exists env(USER)]} {
-   return $env(USER)
+        return $env(USER)
     }
     if {[info exists env(LOGNAME)]} {
-   return $env(LOGNAME)
+        return $env(LOGNAME)
     }
     if {[info exists env(USERNAME)]} {
-   return $env(USERNAME)
+        return $env(USERNAME)
     }
     if {[info exists env(VCSID)]} {
-   return $env(VCSID)
+        return $env(VCSID)
     }
     if {[catch {exec whoami} whoami]} {
-   return nobody
+        return nobody
     }
     return $whoami
 }
