@@ -841,6 +841,9 @@ proc import_astk_serv { fich append } {
             mclient -
             follow_output -
             liste_test -
+            testlist -
+            memory_limit -
+            time_limit -
             platform -
             studyid -
             aster_root -
