@@ -56,6 +56,15 @@ proc lance_astk_serv { batch } {
          return $iret
       }
    }
+# exception pour asdenot, on demande confirmation
+   if { $astk::profil(agla) == "oui" && $astk::profil(asdenot) == "oui"  } {
+        set msg [ashare::mess ihm 429 $astk::profil(version)]
+        set iret [tk_messageBox -message $msg -title [ashare::mess ihm 138] -type yesno -icon question -parent .]
+        if { $iret != "yes" } {
+           ashare::mess erreur 24
+           return -999
+        }
+   }
 # exception pour asdeno, on cree un profil bidon, on garde le bon dans sav_prof
    if { $astk::profil(agla) == "oui" && $astk::profil(asdeno) == "oui"  } {
       array set sav_prof [array get astk::profil]
@@ -98,12 +107,10 @@ proc lance_astk_serv { batch } {
    set lcmd ""
    set argu ""
    # as_exec fichier_export
-   append lcmd [file join $astk::config($serv,rep_serv) "bin" as_run]
-   append lcmd " --serv"
+   append lcmd [file join $ashare::prefix "bin" as_run]
+   append lcmd " --proxy --serv --schema=[get_schema $serv serv]"
    append lcmd [ashare::get_glob_args]
-   if { $astk::config($serv,islocal) != "oui"
-     || [ashare::meme_machine $astk::config($serv,nom_complet) $astk::config($astk::profil(serv_fich_export),nom_complet)] != 1
-     || $astk::config($serv,login) != $astk::config($astk::profil(serv_fich_export),login) } {
+   if { [is_localhost_serv $astk::profil(serv_fich_export)] == 0 } {
       append argu "$astk::config($astk::profil(serv_fich_export),login)@$astk::config($astk::profil(serv_fich_export),nom_complet):"
    }
    append argu $astk::profil(nom_fich_export)
@@ -114,7 +121,7 @@ proc lance_astk_serv { batch } {
 
 # execution
    change_status "[ashare::mess ihm 49]..."
-   set iret [ ashare::rexec_cmd $serv astk::config $lcmd $argu 0 out .]
+   set iret [ ashare::rexec_cmd -1 astk::config $lcmd $argu 0 out . progress]
    set jret $iret
    if { $iret == 0 } {
       if { $soumbtc == 0 } {
@@ -122,6 +129,10 @@ proc lance_astk_serv { batch } {
          set nomjob [get_nomjob]
          set jret [retour_as_exec $nomjob $out]
       } else {
+         set fname [decode_consbtc_output $out]
+         set msg [ashare::mess ihm 412 $astk::config($serv,nom_complet) $fname]
+         change_status $msg
+         tk_messageBox -message $msg -type ok -icon info
          set jret $soumbtc
       }
    } else {
@@ -143,14 +154,16 @@ proc retour_as_exec { nomjob out } {
    set jret 0
 # indices ihm
    set serv $astk::inv(serv,$astk::profil(serveur))
+   set studyid "unknown"
    # decodage du retour
    if { [regexp {JOBID[ ]*=[ ]*([0-9a-zA-Z\._\-]+)} $out mat1 jobid] != 1 ||
         [regexp {QUEUE[ ]*=[ ]*([-a-z_A-Z0-9]+)} $out mat1 queue] != 1 } {
       set jret 3
    }
+   regexp {STUDYID[ ]*=[ ]*([-a-z_A-Z0-9]+)} $out mat1 studyid
    if { $jret == 0} {
       if { $astk::profil(batch) } {
-         set msg [ashare::mess ihm 125 $jobid $queue]
+         set msg [ashare::mess ihm 125 $jobid $queue $studyid]
       } else {
          set msg [ashare::mess ihm 68 $jobid]
       }
@@ -197,8 +210,8 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
    set imsg(4) 40
    # mise  zro des flags
    foreach var {etude tests sources surcharge} {
-      for {set j 0} { $j < $astk::UL($var,nbre) } {incr j} {
-         set flg($astk::UL($var,$j,nom)) ""
+      for {set j 0} { $j < $astk::UL_ref($var,nbre) } {incr j} {
+         set flg($astk::UL_ref($var,$j,nom)) ""
       }
    }
    foreach typ {exec cmde ele etude dbg env astout} {
@@ -210,9 +223,8 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
    set vers $astk::profil(version)
    # paramtres
    puts $idexp "P profastk $astk::config($astk::profil(serv_profil),login)@$astk::config($astk::profil(serv_profil),nom_complet):$astk::profil(nom_profil)"
-   puts $idexp "P serveur $astk::config($serv,nom_complet)"
+   write_server_infos $idexp $serv
    puts $idexp "P noeud $astk::profil(noeud)"
-   puts $idexp "P username $astk::config($serv,login)"
    puts $idexp "P mclient $astk::config(-1,nom_complet)"
    puts $idexp "P uclient $astk::config(-1,login)"
    puts $idexp "P version $astk::profil(version)"
@@ -234,11 +246,16 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
       set opt  [lindex $astk::ihm(l_opt) [expr $i * 3]]
       puts $idexp "P $opt $astk::profil(opt_val,$opt)"
    }
+   if { [in_yes_values $astk::profil(opt_val,multiple)] } {
+      puts $idexp "P multiple_server_list $astk::profil(multiple_server_list)"
+      puts $idexp "P multiple_result_on_client $astk::profil(multiple_result_on_client)"
+   }
    # nom du job
    set lign "P nomjob "
    append lign [get_nomjob]
    puts $idexp $lign
    puts $idexp "P origine ASTK $astk::astk_version"
+   # obsolete si version >= 1.9
    puts $idexp "P display $ashare::DISPLAY"
 
    # paramtre spcial
@@ -253,7 +270,7 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
    if { $ashare::dbg >= 5 } {
       puts $idexp "P srv_dbg oui"
    }
-   
+
    # arguments utilisateur
    set tmp $astk::profil(args)
    # on identifie les arguments non rptables (valeurs nulles ignorees)
@@ -270,7 +287,7 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
       }
    }
    puts $idexp "A args $tmp"
-   
+
 
    ###########################
    # mmoire et temps
@@ -305,22 +322,11 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
    ###########################
    # suivi interactif
    if { $astk::profil(suivi_interactif) } {
+      #if { [is_localhost_serv $serv] == 0 } {
+        #set iret 2
+        #set imsg($iret) 50
+      #}
       puts $idexp "P follow_output yes"
-      set cmd $astk::config($serv,xterm)
-      if { $cmd != "" } {
-         if { [regexp -- {@D} $cmd] == 0 } {
-            append cmd " -display @D"
-         }
-         set cmd [ashare::subst_var $cmd]
-         # retirer "-e ..."
-         regsub -- {-e.*$} $cmd "" cmd
-         puts $idexp "P xterm $cmd"
-# it is not any more an error (the server must defined a terminal entry) 
-##      } else {
-##         set msg [ashare::mess erreur 15 [ashare::mess ihm 82] $astk::profil(serveur)]
-##         tk_messageBox -message $msg -type ok -icon info
-##         change_status $msg
-      }
    }
    ###########################
    # valeurs des paramtres
@@ -364,14 +370,14 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
          set iret $jret
       }
    }
-   if { $astk::profil(opt_val,distrib) != "" } {
+   if { [in_yes_values $astk::profil(opt_val,distrib)] } {
       if { ($flg(distr) == "") || ([regexp "D" $flg(distr)] != 1)
         || ($flg(repe)  == "") || ([regexp "R" $flg(repe)]  != 1) } {
          set iret 4
          set imsg($iret) 53
       }
    }
-   
+
    # fin onglet etude
    ###########################
    # Bouton tests coch
@@ -495,6 +501,13 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
             set imsg($iret) 29
          }
       }
+      # pas base ou bhdf en D et ele en D en mme temps
+      if { $iret < 4
+        && (   ( [regexp "D" $flg(base)] == 1 || [regexp "D" $flg(bhdf)] == 1)
+              && [regexp "D" $flg(ele)] == 1 ) } {
+            set iret 4
+            set imsg($iret) 57
+      }
    }
    # message d'info ou d'erreur
    if { $iret > 0 } {
@@ -515,7 +528,7 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
    return $iret
 }
 
-# exporte le contenu d'une "liste de fichers" pour run_aster
+# exporte le contenu d'une "liste de fichiers" pour as_run
 # types de liste : etude, tests, sources, surcharge
 # code retour : 2 = messages d'info mis ; 4 = erreur
 # tout_dist (voir exporter)
@@ -534,9 +547,7 @@ proc liste_astk_serv { var idexp vers {tout_dist "non"} {verif_suppl "oui"}} {
       set valf ""
       set sfic $astk::inv(serv,$astk::profil($var,fich,$i,serv))
       set serv $astk::inv(serv,$astk::profil(serveur))
-      if { $tout_dist == "oui" ||
-          ([ashare::meme_machine $astk::config($sfic,nom_complet) $astk::config($serv,nom_complet)] != 1
-        || $astk::config($sfic,login) != $astk::config($serv,login)) } {
+      if { $tout_dist == "oui" || [is_localhost_serv $sfic] == 0 } {
          append valf "$astk::config($sfic,login)@$astk::config($sfic,nom_complet):"
       }
       if { [string index $astk::profil($var,fich,$i,nom) 0] == "/" } {
@@ -581,7 +592,7 @@ proc liste_astk_serv { var idexp vers {tout_dist "non"} {verif_suppl "oui"}} {
             set typ "libr"
          }
 
-         set lign $astk::profil($var,fich,$i,FR) 
+         set lign $astk::profil($var,fich,$i,FR)
          append lign " "
          append lign $typ
          append lign " "
@@ -592,15 +603,15 @@ proc liste_astk_serv { var idexp vers {tout_dist "non"} {verif_suppl "oui"}} {
          append lign $astk::profil($var,fich,$i,UL)
       # on regarde quel type on traite
          set flgold $flg($typ)
-         for {set j 0} { $j < $astk::UL($var,nbre) } {incr j} {
-            if { $typ == $astk::UL($var,$j,nom) } {
+         for {set j 0} { $j < $astk::UL_ref($var,nbre) } {incr j} {
+            if { $typ == $astk::UL_ref($var,$j,nom) } {
                append flg($typ) $flag
                set ityp $j
                break
             }
          }
       # vrifier que la compression est autorise
-         if { $astk::profil($var,fich,$i,compress) && $astk::UL($var,$ityp,cpr) == 0 } {
+         if { $astk::profil($var,fich,$i,compress) && $astk::UL_ref($var,$ityp,cpr) == 0 } {
             ashare::mess erreur 37 $typ
             set jret 4
          }
@@ -609,7 +620,7 @@ proc liste_astk_serv { var idexp vers {tout_dist "non"} {verif_suppl "oui"}} {
             puts $idexp $lign
          } else {
          # fichier non rptable (et commun  plusieurs profils)
-            if { $astk::UL($var,$ityp,rep) < 0 } {
+            if { $astk::UL_ref($var,$ityp,rep) < 0 } {
                # s'il existe, on prend sa valeur, sinon on gardera 0
                set ini 0
                catch { set ini $ul_nrep($typ) }
@@ -619,7 +630,7 @@ proc liste_astk_serv { var idexp vers {tout_dist "non"} {verif_suppl "oui"}} {
                } else {
                   set ficrep 1
                }
-            } elseif { $astk::UL($var,$ityp,rep) == 2 } {
+            } elseif { $astk::UL_ref($var,$ityp,rep) == 2 } {
          # fichier rptable une fois en donne, une fois en rsultat maximum
                if { ([regexp D $flgold] && [regexp D $flag])
                  || ([regexp R $flgold] && [regexp R $flag]) } {
@@ -627,7 +638,7 @@ proc liste_astk_serv { var idexp vers {tout_dist "non"} {verif_suppl "oui"}} {
                } else {
                   puts $idexp $lign
                }
-            } elseif { $astk::UL($var,$ityp,rep) == 1 } {
+            } elseif { $astk::UL_ref($var,$ityp,rep) == 1 } {
          # fichier rptable
                puts $idexp $lign
             } elseif { $flgold == "" } {
@@ -701,3 +712,12 @@ proc get_nomjob { } {
    }
    return $nomjob
 }
+
+# lors que le calcul n'est pas soumis, l'endroit o a t
+# produit le fichier btc est dans l'output (as_run >= 1.9 seulement).
+#################################################################
+proc decode_consbtc_output { out } {
+    set fname "unknown"
+    regexp -line {BTCFILE[ ]*=[ ]*(.+?)$} $out mat1 fname
+    return $fname
+}
