@@ -35,6 +35,7 @@ proc colonnes_fich { var } {
 # liste des fichiers ETUDE, TESTS, SOURCES, SURCHARGE
 #################################################################
 proc liste_fich {tfic pos_debut var} {
+   filtre_listul
    set nombre $astk::profil($var,nbfic)
    init_sel
    set nblig [lindex [grid size $tfic] 1]
@@ -103,7 +104,8 @@ proc liste_fich {tfic pos_debut var} {
       for {set j $ideb} {$j < $astk::UL($var,nbre)} {incr j} {
          incr ind
          $m add radiobutton
-         $m entryconfigure $ind -label $astk::UL($var,$j,nom) -font $astk::ihm(font,lablst) -command "set_UL $i $j $var ; modprof" -variable astk::profil($var,fich,$i,type)
+         $m entryconfigure $ind -label $astk::UL($var,$j,nom) -font $astk::ihm(font,lablst) \
+            -command "set_UL $i $astk::UL($var,$j,nom) $var ; modprof" -variable astk::profil($var,fich,$i,type)
       }
       $tfic.lig($i,type) configure -font $astk::ihm(font,lablst) -pady 0
       [lindex [$tfic.lig($i,type) configure -menu] 4] configure -type
@@ -355,7 +357,7 @@ proc nouv_act { fenetre_liste var } {
    set astk::profil($var,fich,$i,FR) "F"
    incr astk::profil($var,nbfic)
    liste_fich $fenetre_liste [expr $astk::profil($var,nbfic) - 1] $var
-   set_UL $i $ideb $var
+   set_UL $i $astk::UL($var,$ideb,nom) $var
 }
 
 # action ouvrir
@@ -397,7 +399,7 @@ proc parcourir_act { fenetre_liste var } {
 
       # positionner le type et l'UL en fonction de l'extension
       # par defaut, on met le premier type
-      set_UL $astk::profil($var,nbfic) $ideb $var
+      set_UL $astk::profil($var,nbfic) $astk::UL($var,$ideb,nom) $var
       set astk::profil($var,fich,$astk::profil($var,nbfic),type) $astk::UL($var,$ideb,nom)
       set astk::profil($var,fich,$astk::profil($var,nbfic),UL) $astk::UL($var,$ideb,num)
       set nlib ""
@@ -406,22 +408,22 @@ proc parcourir_act { fenetre_liste var } {
       }
       set found 0
       # cherche extension == type
-      for { set ic 0 } { $ic < $astk::UL($var,nbre) } { incr ic } {
+      for { set ic 0 } { $ic < $astk::UL_ref($var,nbre) } { incr ic } {
          # si .hist == .hist ou ".histor" commence par '.hist'
-         if { [string tolower $ext] == ".$astk::UL($var,$ic,nom)" } {
-            set astk::profil($var,fich,$astk::profil($var,nbfic),type) $astk::UL($var,$ic,nom)
-            set_UL $astk::profil($var,nbfic) $ic $var
+         if { [string tolower $ext] == ".$astk::UL_ref($var,$ic,nom)" } {
+            set astk::profil($var,fich,$astk::profil($var,nbfic),type) $astk::UL_ref($var,$ic,nom)
+            set_UL $astk::profil($var,nbfic) $astk::UL_ref($var,$ic,nom) $var
             set found 1
             break
          }
       }
       if { $found == 0 } {
          # cherche extension.startswith(type)  ('histor'.startswith('hist'))
-         for { set ic 0 } { $ic < $astk::UL($var,nbre) } { incr ic } {
+         for { set ic 0 } { $ic < $astk::UL_ref($var,nbre) } { incr ic } {
             # si .hist == .hist ou ".histor" commence par '.hist'
-            if { [string first ".$astk::UL($var,$ic,nom)" [string tolower $ext]] > -1 } {
-               set astk::profil($var,fich,$astk::profil($var,nbfic),type) $astk::UL($var,$ic,nom)
-               set_UL $astk::profil($var,nbfic) $ic $var
+            if { [string first ".$astk::UL_ref($var,$ic,nom)" [string tolower $ext]] > -1 } {
+               set astk::profil($var,fich,$astk::profil($var,nbfic),type) $astk::UL_ref($var,$ic,nom)
+               set_UL $astk::profil($var,nbfic) $astk::UL_ref($var,$ic,nom) $var
                set found 1
                break
             }
@@ -429,12 +431,12 @@ proc parcourir_act { fenetre_liste var } {
       }
       if { $found == 0 } {
          # cherche type.find(extension) >= 0  ('mmed'.find('med'))
-         for { set ic 0 } { $ic < $astk::UL($var,nbre) } { incr ic } {
+         for { set ic 0 } { $ic < $astk::UL_ref($var,nbre) } { incr ic } {
             # si .hist == .hist ou ".histor" commence par '.hist'
-            if { [string first [string tolower [string range $ext 1 end]] $astk::UL($var,$ic,nom)] > -1
+            if { [string first [string tolower [string range $ext 1 end]] $astk::UL_ref($var,$ic,nom)] > -1
             } {
-               set astk::profil($var,fich,$astk::profil($var,nbfic),type) $astk::UL($var,$ic,nom)
-               set_UL $astk::profil($var,nbfic) $ic $var
+               set astk::profil($var,fich,$astk::profil($var,nbfic),type) $astk::UL_ref($var,$ic,nom)
+               set_UL $astk::profil($var,nbfic) $astk::UL_ref($var,$ic,nom) $var
                set found 1
                break
             }
@@ -473,7 +475,7 @@ proc detr_act { fenetre_liste } {
 #################################################################
 proc bind_3_detruire { w x y var fenetre_liste } {
    #set var $astk::sel(liste)
-   ashare::log "#XXX DELETE_ALL $w, $x:$y $fenetre_liste / $var"
+   #ashare::log "#XXX DELETE_ALL $w, $x:$y $fenetre_liste / $var"
    set iret [ tk_messageBox -message [ashare::mess ihm 390] \
       -title [ashare::mess ihm 143] -type yesno -icon question ]
    if { $iret == "yes" && $astk::profil($var,nbfic) > 0 } {
@@ -594,22 +596,30 @@ proc swap_line { var i j} {
 
 # affecte le numero de l'UL et flag par defaut
 #################################################################
-proc set_UL { nli choix var } {
-   set astk::profil($var,fich,$nli,UL) $astk::UL($var,$choix,num)
+proc set_UL { nli type var } {
+   set choix 0
+   for {set nul 0} {$nul < $astk::UL_ref($var,nbre)} {incr nul} {
+      if { $type == $astk::UL_ref($var,$nul,nom) } {
+         set choix $nul
+         break
+      }
+   }
+
+   set astk::profil($var,fich,$nli,UL) $astk::UL_ref($var,$choix,num)
 # on positionne les flags DRC selon le type
-   if { [regexp D+ $astk::UL($var,$choix,def)] == 1 } {
+   if { [regexp D+ $astk::UL_ref($var,$choix,def)] == 1 } {
       set astk::profil($var,fich,$nli,donnee) 1
    } else {
       set astk::profil($var,fich,$nli,donnee) 0
    }
-   if { [regexp R+ $astk::UL($var,$choix,def)] == 1 } {
+   if { [regexp R+ $astk::UL_ref($var,$choix,def)] == 1 } {
       set astk::profil($var,fich,$nli,resultat) 1
    } else {
       set astk::profil($var,fich,$nli,resultat) 0
    }
    # on ne modifie pas le flag C s'il y a dj un nom de fichier
    if { $astk::profil($var,fich,$nli,nom) == "" || $astk::profil($var,fich,$nli,nom) == ".gz" } {
-      if { [regexp C+ $astk::UL($var,$choix,def)] == 1 } {
+      if { [regexp C+ $astk::UL_ref($var,$choix,def)] == 1 } {
          set astk::profil($var,fich,$nli,compress) 1
       } else {
          set astk::profil($var,fich,$nli,compress) 0
@@ -674,7 +684,7 @@ proc create_popup { m } {
         -background $astk::ihm(couleur,menu_background)
    $m add command -label [ashare::mess ihm 169] -font $astk::ihm(font,labmenuB) -command {ashare::file_open typ}
    $m add command -label [ashare::mess ihm 171] -font $astk::ihm(font,labmenu)  -command {ashare::file_open edit}
-   $m add command -label [ashare::mess ihm 179] -font $astk::ihm(font,labmenu)  -command {ashare::file_print_to}
+   #$m add command -label [ashare::mess ihm 179] -font $astk::ihm(font,labmenu)  -command {ashare::file_print_to}
    $m add separator
    $m add cascade -menu $m.opw -label [ashare::mess ihm 170] -font $astk::ihm(font,labmenu) -state disabled
    $m add command -label [ashare::mess ihm 252] -font $astk::ihm(font,labmenu)  -command {valeur_defaut}
@@ -774,21 +784,21 @@ proc action_compress { var i } {
    # numro du type dans astk::UL, et types "FR" possibles
    set typdef "X"
    set nul 0
-   for {set nul 0} {$nul < $astk::UL($var,nbre)} {incr nul} {
-      if { $astk::profil($var,fich,$i,type) == $astk::UL($var,$nul,nom) } {
-         set typdef $astk::UL($var,$nul,FR)
+   for {set nul 0} {$nul < $astk::UL_ref($var,nbre)} {incr nul} {
+      if { $astk::profil($var,fich,$i,type) == $astk::UL_ref($var,$nul,nom) } {
+         set typdef $astk::UL_ref($var,$nul,FR)
          break
       }
    }
    # si le type n'est pas compressible, on decoche immdiatement
-   if { $astk::UL($var,$nul,cpr) == 0 } {
+   if { $astk::UL_ref($var,$nul,cpr) == 0 } {
       set astk::profil($var,fich,$i,compress) 0
    }
    # ajoute/supprime .gz si le type Fichier est possible
    if { [regexp F $typdef] } {
       regsub {\.gz *$} $astk::profil($var,fich,$i,nom) "" astk::profil($var,fich,$i,nom)
       if { $astk::profil($var,fich,$i,compress)
-        && $astk::UL($var,$nul,cpr) } {
+        && $astk::UL_ref($var,$nul,cpr) } {
          regsub { *$} $astk::profil($var,fich,$i,nom) ".gz" astk::profil($var,fich,$i,nom)
       }
    }
