@@ -91,6 +91,8 @@ proc astk_princ { { REINI "INI" } } {
 
    # fenetre init
    catch {destroy .fen_about}
+   catch {destroy $astk::ihm(asjob)}
+   show_fen $astk::ihm(asjob)
    
    # affichage
    ashare::pointeur on
