@@ -57,8 +57,8 @@ proc create_menu_fichier { fenetre_parent {REINI "INI"} } {
       $fenetre_parent.fic.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 357]..." -command "insert_in_db"
    }
    $fenetre_parent.fic.mnu add separator
-   $fenetre_parent.fic.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 247]..." -command "print_conf"
-   $fenetre_parent.fic.mnu add separator
+   #$fenetre_parent.fic.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 247]..." -command "print_conf"
+   #$fenetre_parent.fic.mnu add separator
    $fenetre_parent.fic.mnu add command -font $astk::ihm(font,labmenu) -label [ashare::mess ihm 366]      -accelerator "Ctrl+W" -command "nouveau"
    $fenetre_parent.fic.mnu add command -font $astk::ihm(font,labmenu) -label [ashare::mess ihm 32]       -accelerator "Ctrl+Q" -command "quitter"
    dern_prof $fenetre_parent.fic.mnu
@@ -85,9 +85,9 @@ proc create_menu_fichier { fenetre_parent {REINI "INI"} } {
    }
    incr i
    incr i
-   set ashare::context($fenetre_parent.fic.mnu,$i) 247
-   incr i
-   incr i
+   #set ashare::context($fenetre_parent.fic.mnu,$i) 247
+   #incr i
+   #incr i
    set id_close $i
    set ashare::context($fenetre_parent.fic.mnu,$i) 365
    incr i
@@ -208,7 +208,7 @@ proc create_menu_options { fenetre_parent {REINI "INI"} } {
       menubutton $fenetre_parent.opt -font $astk::ihm(font,labmenu) -text [ashare::mess ihm 250] \
         -foreground $astk::ihm(couleur,menu_foreground) \
         -background $astk::ihm(couleur,menu_background) \
-        -underline 0 -menu $fenetre_parent.opt.mnu
+        -underline 1 -menu $fenetre_parent.opt.mnu
       pack $fenetre_parent.opt -side left
    } else {
       destroy $fenetre_parent.opt.mnu
@@ -281,6 +281,7 @@ proc create_menu_aide { fenetre_parent } {
    menu $fenetre_parent.help.mnu -tearoff 0 -bd 1 \
         -foreground $astk::ihm(couleur,menu_foreground) \
         -background $astk::ihm(couleur,menu_background)
+   set id_log 8
    $fenetre_parent.help.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 110]..." -command {aff_aide . 110}
    $fenetre_parent.help.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 111]..." -command {aff_aide . 111}
    $fenetre_parent.help.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 190]..." -command {aff_aide . 190}
@@ -289,11 +290,12 @@ proc create_menu_aide { fenetre_parent } {
    $fenetre_parent.help.mnu add separator
    if { $astk::agla(num_serv) > -1 } {
       $fenetre_parent.help.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 269]..." -command {contact_ata}
+      incr id_log
    }
    $fenetre_parent.help.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 323]..." -command {aff_aide . 323}
    $fenetre_parent.help.mnu add separator
-   $fenetre_parent.help.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 196]..." -command {show_fen $astk::ihm(log) force}
+   $fenetre_parent.help.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 196]..." -accelerator "Ctrl+M" -command {show_fen $astk::ihm(log) force}
    $fenetre_parent.help.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 106]..." -command {a_propos .}
 # aide contextuelle
-   #bind $fenetre_parent.help.mnu <<MenuSelect>> "ShowStatus menu $fenetre_parent.help.mnu astk"
+   bind . <Control-Key-m> "$fenetre_parent.help.mnu invoke $id_log"
 }
