@@ -281,8 +281,7 @@ proc run_Stanley { {numfich -1} } {
    set valf ""
    set sfic $astk::inv(serv,$astk::profil($var,fich,$indice,serv))
    set serv $astk::inv(serv,$astk::profil(serveur))
-   if { [ashare::meme_machine $astk::config($sfic,nom_complet) $astk::config($serv,nom_complet)] != 1
-     || $astk::config($sfic,login) != $astk::config($serv,login) } {
+   if { [is_localhost_serv $sfic] == 0 } {
       append valf "$astk::config($sfic,login)@$astk::config($sfic,nom_complet):"
    }
    if { [string index $astk::profil($var,fich,$indice,nom) 0] == "/" } {
@@ -331,17 +330,17 @@ proc run_Stanley { {numfich -1} } {
    set lcmd ""
    set argu ""
 # tool_stanley profil
-   append lcmd [file join $astk::config($serv,rep_serv) "bin" as_run]
-   append lcmd " --serv"
+   #XXX assert serv_export == -1 !
+   append lcmd [file join $ashare::prefix "bin" as_run]
+   append lcmd " --proxy --serv --schema=[get_schema $serv serv]"
    append lcmd [ashare::get_glob_args]
-   if { [ashare::meme_machine $astk::config($serv,nom_complet) $astk::config($serv_export,nom_complet)] != 1
-     || $astk::config($serv,login) != $astk::config($serv_export,login) } {
+   if { [is_localhost_serv $serv_export] == 0 } {
       append argu "$astk::config($serv_export,login)@$astk::config($serv_export,nom_complet):"
    }
    append argu $nom_export
 
 #  execution
-   set iret [ ashare::rexec_cmd $serv astk::config $lcmd $argu 0 out .]
+   set iret [ ashare::rexec_cmd -1 astk::config $lcmd $argu 0 out . progress]
    set jret $iret
    if { $iret == 0 } {
    # traitement du retour
