@@ -84,7 +84,7 @@ proc rex_saisie_fiche { fich_asso } {
    # entete
    label $fen.f.em -font $astk::ihm(font,labbout) -text [ashare::mess ihm 216] -anchor w
    pack $fen.f.em -fill x -expand yes
-   
+
    pack [frame $fen.f.f1a -relief flat -bd 0] -anchor w -padx 5
    label $fen.f.f1a.lab -font $astk::ihm(font,lab) -text "[ashare::mess ihm 89]*" -width 30 -anchor w
    label $fen.f.f1a.val -font $astk::ihm(font,lab) -text $astk::config(-1,nom_user)
@@ -109,7 +109,7 @@ proc rex_saisie_fiche { fich_asso } {
    # paramtres
    label $fen.f.pa -font $astk::ihm(font,labbout) -text [ashare::mess ihm 221] -anchor w
    pack $fen.f.pa -fill x -expand yes
-   
+
    pack [frame $fen.f.f1c -relief flat -bd 0] -anchor w -padx 5
    # type de fiche
    label $fen.f.f1c.lab -font $astk::ihm(font,lab) -text [ashare::mess ihm 217] -width 30 -anchor w
@@ -171,7 +171,7 @@ proc rex_saisie_fiche { fich_asso } {
       button $fen.valid.ok -font $astk::ihm(font,labbout) -text [ashare::mess ihm 215] \
          -command "rex_envoi $fen $fich_asso" -bg $astk::ihm(couleur,valid)
       pack $fen.valid.ok $fen.valid.annuler -side left -padx 10 -pady 5
-   
+
    wm deiconify $fen
 }
 
@@ -189,20 +189,29 @@ proc rex_envoi { parent fich_asso } {
       return
    }
 
-   # fichiers associs
+   set fexp [get_tmpname .file_rex_export]
+   # l'extension est obligatoire au moment de l'export
+   append fexp ".export"
+   set serv $astk::agla(num_serv)
    if { $fich_asso } {
-      set fexp [file join $astk::tmpdir .file_rex_export]
-      set astk::profil(special) ""
-      set iret [exporter astk_serv -1 $fexp "verif" "oui"]
-      if { $iret != 0 } {
-         set msg [ashare::mess erreur 40]
-         change_status $msg
-         tk_messageBox -message $msg -type ok -icon info -parent $parent
-         return
-      }
+       set astk::profil(special) ""
+       # on force la slection du serveur AGLA pour l'export
+       adapt_satellite 2
+       set iret [exporter astk_serv -1 $fexp "verif" "oui"]
+       adapt_satellite 0
+       if { $iret != 0 } {
+          set msg [ashare::mess erreur 40]
+          change_status $msg
+          tk_messageBox -message $msg -type ok -icon info -parent $parent
+          return
+       }
+   } else {
+      set idexp [open $fexp w]
+      write_server_infos $idexp $serv
+      close $idexp
    }
 
-   set frex [file join $astk::tmpdir .file_rex_fiche]
+   set frex [get_tmpname .file_rex_fiche]
    set idrex [open $frex w]
    puts $idrex "@NOMUSER@"
    regsub -all " " $astk::config(-1,nom_user) "\." tmp
@@ -240,26 +249,14 @@ proc rex_envoi { parent fich_asso } {
 # prparation de la ligne de commande  excuter
    set lcmd ""
    set argu ""
-   set serv $astk::agla(num_serv)
-   append lcmd [file join $astk::config($serv,rep_serv) "bin" as_run]
-   append lcmd " --create_issue"
+   append lcmd [file join $ashare::prefix "bin" as_run]
+   append lcmd " --proxy --create_issue --schema=[get_schema $serv create_issue]"
    append lcmd [ashare::get_glob_args]
-   if { [ashare::meme_machine $astk::config($serv,nom_complet) $astk::config(-1,nom_complet)] != 1
-     || $astk::config($serv,login) != $astk::config(-1,login) } {
-      append argu "$astk::config(-1,login)@$astk::config(-1,nom_complet):"
-   }
    append argu $frex
-   # si fichiers associs
-   if { $fich_asso } {
-      append argu " "
-      if { [ashare::meme_machine $astk::config($serv,nom_complet) $astk::config(-1,nom_complet)] != 1
-        || $astk::config($serv,login) != $astk::config(-1,login) } {
-         append argu "$astk::config(-1,login)@$astk::config(-1,nom_complet):"
-      }
-      append argu $fexp
-   }
+   append argu " "
+   append argu $fexp
 #  execution
-   set iret [ ashare::rexec_cmd $serv astk::config $lcmd $argu 0 out $parent]
+   set iret [ ashare::rexec_cmd -1 astk::config $lcmd $argu 0 out $parent progress]
    if { $iret == 0 } {
       if { [regexp {INDEX[ ]*=[ ]*([0-9]+)} $out mat1 index] } {
          set msg [ashare::mess ihm 226 $index]
