@@ -90,7 +90,7 @@ proc affiche_satellite { } {
       incr lig
        checkbutton $astk::ihm(satellite).subtit.choix -offvalue 0 -onvalue 1 -variable astk::profil(suivi_interactif) -text [ashare::mess ihm 47] -command mod_suivi
       grid $astk::ihm(satellite).subtit.choix -row $lig -column 0 -columnspan 2
-             
+
       # pas russi a faire autrement que mettre une ligne vide !
       incr lig
       label $astk::ihm(satellite).subtit.lv0 -font $astk::ihm(font,lab) -text " "
@@ -98,7 +98,7 @@ proc affiche_satellite { } {
     # frame debug / nodebug
        radiobutton $astk::ihm(satellite).subtit.nodebug -font $astk::ihm(font,lab) -text nodebug -value 0 -variable astk::profil(debug)
        radiobutton $astk::ihm(satellite).subtit.debug -font $astk::ihm(font,lab) -text debug -value 1 -variable astk::profil(debug)
-      incr lig  
+      incr lig
       grid $astk::ihm(satellite).subtit.nodebug -row $lig -column 0 -columnspan 2 -padx 15 -sticky sw
       incr lig
       grid $astk::ihm(satellite).subtit.debug -row $lig -column 0 -columnspan 2 -padx 15 -sticky nw
@@ -129,7 +129,7 @@ proc affiche_satellite { } {
     button $astk::ihm(satellite).bas.bjobs -font $astk::ihm(font,labbout) -text [ashare::mess ihm 48] \
         -background $astk::ihm(couleur,suivi) -activebackground $astk::ihm(couleur,suivi) \
         -command "show_fen $astk::ihm(asjob) force"
-    
+
     grid $astk::ihm(satellite).bas.go    -row 0 -column 0 -sticky nsew -padx 5 -pady 5
    grid $astk::ihm(satellite).bas.mode  -row 0 -column 1 -sticky nsew -padx 5 -pady 5
     grid $astk::ihm(satellite).bas.bjobs -row 1 -column 0 -columnspan 2 -sticky nsew -padx 5 -pady 5
@@ -224,7 +224,7 @@ proc mod_lancement { etat {val "run"}} {
 #################################################################
 proc chg_lancement { } {
 # si "dbg" ou "pre", on valide "debug" par dfaut
-   if { $astk::profil(make_etude) == $astk::ihm(mode,dbg) 
+   if { $astk::profil(make_etude) == $astk::ihm(mode,dbg)
      || $astk::profil(make_etude) == $astk::ihm(mode,pre) } {
       set astk::profil(debug) 1
    }
@@ -258,6 +258,7 @@ proc maj_sat { } {
 # contenu adapt  l'onglet
 #  0 : satellite normal
 #  1 : satellite pour agla
+#  2 : satallite pour agla sans changer les paramtres mmoire/temps
 #################################################################
 proc adapt_satellite { level } {
    global last_level
@@ -277,9 +278,17 @@ proc adapt_satellite { level } {
 
    set last_level $level
 
-   foreach mcle { noeud memoire temps } {
-      set astk::profil($mcle) $astk::ihm(old,sat,$level,$mcle)
+   set level_param $level
+   # level = 2 : on prend les paramtres mmoire/temps non_AGLA
+   if { $level == 2 } {
+      set level_param 0
+      set level 1
    }
+   set astk::profil(noeud) $astk::ihm(old,sat,$level,noeud)
+
+   set astk::profil(memoire) $astk::ihm(old,sat,$level_param,memoire)
+   set astk::profil(temps) $astk::ihm(old,sat,$level_param,temps)
+
    switch $level {
       0 {
          $astk::ihm(satellite).subtit.choix configure -state normal
