@@ -244,6 +244,7 @@ proc init_gene { root } {
                         }
    set astk::ihm(l_par) { nbmaxnook    264 {} \
                           cpresok      265 {RESOK RESNOOK} \
+                          only_nook    430 {OUI YES oui yes NON NO non no} \
                           facmtps      266 {} \
                           corefilesize 293 {} \
                         }
@@ -253,6 +254,7 @@ proc init_gene { root } {
                           mpi_nbnoeud 370 {} \
                           classe      334 {} \
                           depart      335 {} \
+                          after_job   387 {} \
                           distrib     386 {OUI YES oui yes NON NO non no} \
                           exectool    385 {} \
                           multiple    413 {OUI YES oui yes NON NO non no}
