@@ -59,7 +59,8 @@ proc raffr_agla { {parent "."} {REINI "DETR"} } {
       set astk::agla(status) off
       recup_info $parent $serv
       # issue17523: always enable agla functions
-      if { 1 || [regexp "EDA" $astk::agla(instance)] } {
+      # may 2013: never!
+      if { 0 && [regexp "EDA" $astk::agla(instance)] } {
          set astk::agla(status) on
       }
 
