@@ -40,6 +40,8 @@ proc init_env { {parent ""} } {
    # fournit la liste  l'ihm
    set astk::profil(noeud) "-"
    cree_liste_machines
+   # rcupre des valeurs pour l'ihm
+   check_config
 
 # serveur de profil_ini
    if { $astk::ihm(serv_ini) != "" } {
@@ -100,21 +102,48 @@ proc init_config {} {
    }
 }
 
+# Utilise certaines de la configuration des serveurs pour l'ihm
+#################################################################
+proc check_config {} {
+    # reinit batch queue groups
+    update_opt classe {} "REINIT"
+    for {set i 0} {$i < $astk::config(nb_serv)} {incr i} {
+        if { $astk::config($i,batch) != "non" } {
+            # batch queue groups
+            update_opt classe $astk::config($i,batch_queue_group) "APPEND"
+        }
+    }
+}
+
+
 # Rcupre les infos sur le serveur
 #################################################################
 proc recup_info { parent serv } {
+   global warn_seen
+   # init warn_seen
+   set val 0
+   catch { set val $warn_seen($serv) }
+   set warn_seen($serv) $val
    set iret -1
-   ashare::mess "info" 12 $astk::config($serv,nom)
+   ashare::mess info 12 $astk::config($serv,nom)
    ShowSplashInfo [ashare::mess "ihm" 368 $astk::config($serv,nom_complet)]
 # prparation de la ligne de commande  excuter
-   set lcmd [file join $astk::config($serv,rep_serv) "bin" as_run]
-   append lcmd " --info"
+   set ftmp [get_tmpname .info_export]
+   set idexp [open $ftmp w]
+   write_server_infos $idexp $serv
+   close $idexp
+   set lcmd [file join $ashare::prefix "bin" as_run]
+   append lcmd " --proxy --info --schema=[get_schema $serv info] $ftmp"
    append lcmd [ashare::get_glob_args]
 # on n'ajoute pas les protocoles en argument :
 # - car as_info ne fait pas de rcp/rsh
 # - pour assurer la comptabilit (au moins rcuprer le numro de version)
 #  execution
-   set iret [ ashare::rexec_cmd $serv astk::config $lcmd "" 0 out $parent]
+   set logprogress "progress"
+   if { $ashare::appli == "bsf" } {
+       set logprogress "None"
+   }
+   set iret [ashare::rexec_cmd -1 astk::config $lcmd "" 0 out $parent $logprogress]
    set jret $iret
    if { $jret == 0 } {
       if { $ashare::dbg >= 5 } {
@@ -194,7 +223,7 @@ proc recup_info { parent serv } {
          set serv_vers   [get_num_vers $tmp_serv_vers]
          set astk::config($serv,asrun_vers) $serv_vers
          set icmp [string compare $serv_vers $client_vers]
-         if { $ashare::show_dialog == 1 } {
+         if { $ashare::show_dialog == 1 && $warn_seen($serv) != 1 } {
             if { $icmp < 0 } {
                tk_messageBox -title [ashare::mess ihm 138] -message [ashare::mess ihm 233 $astk::config($serv,nom) $serv_vers $client_vers] -type ok -icon info
             } elseif { $icmp > 0 } {
@@ -205,7 +234,7 @@ proc recup_info { parent serv } {
          #$astk::config($serv,nom)
          if { [regexp {@MOTD@\n(.*)\n@FINMOTD@} $out mat1 motd] } {
             set motd [string trim $motd]
-            if { $motd != "" && $ashare::show_dialog == 1 } {
+            if { $motd != "" && $ashare::show_dialog == 1 && $warn_seen($serv) != 1 } {
                ashare::fen_info .fen_motd [ashare::mess ihm 114] [ashare::mess ihm 113 $astk::config($serv,nom)] $motd
             }
          }
@@ -217,6 +246,7 @@ proc recup_info { parent serv } {
       # mise  jour de last_recup (ATTENTION : format anglosaxon)
          set hh [clock format [clock seconds] -format "%m/%d/%Y"]
          set astk::config($serv,last_recup) $hh
+         set warn_seen($serv) 1
       }
    } else {
       ashare::mess "erreur" 3 "as_info" $iret $out
@@ -250,7 +280,7 @@ proc lire_prof { } {
    set iret [ ashare::lire_mc_val $fich mots vale nlu ]
    if { $iret != 0 } {
       return $iret }
- 
+
    # phase de vrif
    # mots-cls reconnus
    set mots_cles $ashare::mots(MCF_prof)
@@ -328,7 +358,7 @@ proc cree_liste_machines { } {
       set astk::inv(serv,$astk::config($is,nom)) $is
       for {set k 0} {$k < $is} {incr k} {
          if { $astk::config($k,nom_complet) == $astk::config($is,nom_complet)
-           && $astk::config($k,login) == $astk::config($is,login) 
+           && $astk::config($k,login) == $astk::config($is,login)
            && $astk::config($k,etat) != "off"
            && $astk::config($is,etat) != "off" } {
             set astk::config($is,etat) "off"
