@@ -144,13 +144,19 @@ proc lance_calcul { batch } {
    # avertir si des options supplmentaires sont actives
    set isuppl 0
    set msg ""
-   foreach opt {classe depart distrib exectool} {
+   foreach opt {classe depart after_job exectool} {
       if { $astk::profil(opt_val,$opt) != "" } {
          set isuppl 1
          append msg "$opt=$astk::profil(opt_val,$opt)\n"
       }
    }
-   if { [in_yes_values $astk::profil(opt_val,multiple)] } {
+   set opt "distrib"
+   if { [in_no_values $astk::profil(opt_val,$opt)] == 0 } {
+      set isuppl 1
+      append msg "$opt=$astk::profil(opt_val,$opt)\n"
+   }
+   set opt "multiple"
+   if { [in_no_values $astk::profil(opt_val,$opt)] == 0 } {
       set isuppl [expr $isuppl + 2]
    }
    set ich "yes"
