@@ -22,7 +22,7 @@
 proc Opt_conf { } {
    global serv_conf last_CS_serv
    global old_conf old_inv
-   
+
 # sauvegarde le tableau config avant modif
    copie_tabl astk::config old_conf 1
    copie_tabl astk::inv old_inv 1
@@ -38,9 +38,9 @@ proc Opt_conf { } {
    wm title $fen "[ashare::mess ihm 33] - [ashare::mess ihm 35]"
    wm transient $fen .
    grab set $fen
-   
+
    Opt_conf_list $fen
-   
+
    wm deiconify $fen
 }
 
@@ -86,7 +86,7 @@ proc Opt_conf_list { fen } {
       -bg $astk::ihm(couleur,background) -bd 0 \
       -command "grab release $fen ; aff_aide . 190"
    pack $fen.haut.help -anchor ne -side right
-   
+
    pack [frame $fen.bas.valid -relief solid -bd 0] -side left -fill both -expand yes
       pack [frame $fen.bas.valid.m -relief solid -bd 0]
       button $fen.bas.valid.m.annuler -font $astk::ihm(font,labbout) -text [ashare::mess ihm 85] \
@@ -95,7 +95,7 @@ proc Opt_conf_list { fen } {
          -bg $astk::ihm(couleur,valid) \
          -command "maj_sat ; raffr_agla $fen ; ashare::save_options; destroy $fen ; grab release $fen"
       pack $fen.bas.valid.m.ok $fen.bas.valid.m.annuler -side left -padx 10 -pady 5
-   
+
    pack [frame $fen.bas.del -relief solid -bd 0] -side right
    button $fen.bas.del.bout -font $astk::ihm(font,labbout) -text [ashare::mess ihm 34] \
       -command "del_serv $fen" -bg $astk::ihm(couleur,suppr)
@@ -132,9 +132,8 @@ proc Opt_conf_serv {fen nserv} {
    label $fen.f.nom.lbl -font $astk::ihm(font,lab) -text [ashare::mess ihm 79] -width 35 -anchor w
    entry $fen.f.nom.path -width 30 -font $astk::ihm(font,val) -textvariable astk::config($serv,nom_complet)
    pack $fen.f.nom.lbl $fen.f.nom.path -pady 3 -side left
-# interaction avec l'AGLA : on empeche la modif du nom du serveur
+# interaction avec l'AGLA
    if { $serv == $astk::agla(num_serv) } {
-      $fen.f.nom.path configure -state disabled
       label $fen.f.lblagla -font $astk::ihm(font,labpt) -text [ashare::mess ihm 128]
       pack $fen.f.lblagla -anchor w
    }
@@ -270,7 +269,7 @@ proc Opt_conf_serv {fen nserv} {
    radiobutton $fen.f.batch.act -font $astk::ihm(font,lab) -text on -value oui -variable astk::config($serv,batch) -state disabled
    radiobutton $fen.f.batch.inact -font $astk::ihm(font,lab) -text off -value non -variable astk::config($serv,batch) -state disabled
    pack $fen.f.batch.lbl $fen.f.batch.act $fen.f.batch.inact -pady 3 -side left
-      
+
    if { $astk::config($serv,batch) == "oui" } {
       if { $astk::config($serv,batch_queue_group) != "" } {
          pack [frame $fen.f.bagrp -relief solid -bd 0] -anchor w
