@@ -20,6 +20,7 @@
 # reaction a Configuration/Preferences/Generales
 #################################################################
 proc Opt_prefs { } {
+   global choix_listul
    bckup_prefs
 
    set fen .fen_pref
@@ -125,6 +126,23 @@ proc Opt_prefs { } {
       -variable astk::config(-1,dbglevel) -font $astk::ihm(font,lab) -showvalue 0
    pack $fen.liste.dbg.lbl $fen.liste.dbg.scl -pady 3 -side left
 
+# unites logiques dans ETUDE
+   pack [frame $fen.liste.listul -relief solid -bd 0] -anchor w
+   label $fen.liste.listul.lbl -font $astk::ihm(font,lab) -text [ashare::mess ihm 421] -width 35 -anchor w
+   set MenuLang [tk_optionMenu $fen.liste.listul.choix choix_listul [ashare::mess ihm 414]]
+   $MenuLang configure \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
+   $MenuLang entryconfigure 0 -font $astk::ihm(font,labmenu)
+   for {set j 1} {$j < $astk::ihm(listul,nbre)} {incr j} {
+      $MenuLang add radiobutton
+      set label [ashare::mess ihm [expr 414 + $j]]
+      $MenuLang entryconfigure $j -label $label -font $astk::ihm(font,labmenu) -variable choix_listul
+   }
+   $fen.liste.listul.choix configure -font $astk::ihm(font,labmenu) -bg $astk::ihm(couleur,liste)
+   pack $fen.liste.listul.lbl $fen.liste.listul.choix -pady 3 -side left
+
+
 # bip
    pack [frame $fen.liste.bip -relief solid -bd 0] -anchor w -padx 20
    checkbutton $fen.liste.bip.cb -variable astk::config(-1,bip) -anchor w
@@ -245,6 +263,7 @@ proc Opt_prefs_net { } {
 #################################################################
 proc accept_pref { old_lang } {
    global old_pref
+   global choix_listul
 
 # nom de machine / domaine
    init_nom_complet $astk::config(-1,isdhcp)
@@ -259,21 +278,31 @@ proc accept_pref { old_lang } {
    check_display
 # niveau debug
    set ashare::dbg $astk::config(-1,dbglevel)
+# filtre les types d'unit logique
+   set astk::config(-1,listul) $astk::ihm(listul,$choix_listul)
+   affiche_onglet $astk::profil(onglet_actif)
 # info en cas de changement de la langue
    if { $astk::config(-1,langue) != $old_lang } {
       set ashare::lang $astk::config(-1,langue)
       raffr_princ
    }
+   # repositionne les labels de choix
+   init_choix_ul
 # mise  jour de la liste des profils (nb_reman)
    maj_prof
 # sauvegarde des prfrences
    ashare::save_prefs
 }
 
+# backup des prfrences avant modif + init variables globales
 #################################################################
 proc bckup_prefs {} {
    global old_pref
-   
+   global choix_listul
+
+   set choix_listul $astk::ihm(listul,reverse,default)
+   catch { set choix_listul $astk::ihm(listul,reverse,$astk::config(-1,listul)) }
+
 # valeurs actuelles dans old_pref
    set mots_cles $ashare::mots(MCS_pref)
    lappend mots_cles "nom_complet"
