@@ -132,8 +132,9 @@ proc ashare::lire_prefs { { ini NON } } {
             #incr nberr
             # save keywords/values not used by astk (but by as_run)
             # to be able to save them later.
+            set ind [llength $ashare::mots(MCS_pref_ign)]
             lappend ashare::mots(MCS_pref_ign) $mots($j)
-            set astk::config(ignprefs,$mots($j)) $vale($j)
+            set astk::config(ignprefs,$mots($j),$ind) $vale($j)
          } else {
             incr nbmcs
             set astk::config(-1,$mots($j)) $vale($j)
@@ -175,7 +176,7 @@ proc ashare::save_prefs { } {
    for { set k 0 } { $k < [ llength $mots_cles ] } { incr k } {
       set mcs [lindex $mots_cles $k]
       set val ""
-      catch { set val $astk::config(ignprefs,$mcs) }
+      catch { set val $astk::config(ignprefs,$mcs,$k) }
       if { $val == "" } {
          set val "_VIDE"
       }
