@@ -21,10 +21,11 @@
 #################################################################
 proc ashare::get_glob_args { } {
    set lcmd ""
-   append lcmd " --remote_shell_protocol=$astk::config(-1,remote_shell_protocol)"
-   append lcmd " --remote_copy_protocol=$astk::config(-1,remote_copy_protocol)"
+   #XXX should be unusefull
+   #append lcmd " --remote_shell_protocol=$astk::config(-1,remote_shell_protocol)"
+   #append lcmd " --remote_copy_protocol=$astk::config(-1,remote_copy_protocol)"
    if { $astk::rcdir_mod } {
-      append lcmd " --rcdir=$astk::rcdir"
+      append lcmd " --rcdir=$astk::rcdir_arg"
    }
    return $lcmd
 }
@@ -105,18 +106,15 @@ proc ashare::selecteur {srv_OUT dir_OUT typ_OUT srv_IN dir_IN typ_IN {args_sup "
 #   @R = rpertoire contenant le fichier slectionn
 #################################################################
 proc ashare::subst_var { cmd } {
-   regsub -all "@D" $cmd $ashare::DISPLAY cmd
+   regsub -all {@D([^a-zA-Z0-9\-\+]*)} $cmd "$ashare::DISPLAY\\1" cmd
    set name $astk::sel(filename)
 #   if { $name != "" } {
    set dir  [file dirname $name]
    set base [file tail $name]
    # on ne remplace qui si suivi d'un espace ou fin de ligne
-   regsub -all "@F " $cmd "$name " cmd
-   regsub -all "@f " $cmd "$base " cmd
-   regsub -all "@R " $cmd "$dir " cmd
-   regsub -all "@F\$" $cmd "$name " cmd
-   regsub -all "@f\$" $cmd "$base " cmd
-   regsub -all "@R\$" $cmd "$dir " cmd
+   regsub -all {@F([^a-zA-Z0-9\-\+]*)} $cmd "$name\\1" cmd
+   regsub -all {@f([^a-zA-Z0-9\-\+]*)} $cmd "$base\\1" cmd
+   regsub -all {@R([^a-zA-Z0-9\-\+]*)} $cmd "$dir\\1" cmd
 #   }
    return $cmd
 }
@@ -128,18 +126,24 @@ proc ashare::subst_var { cmd } {
 # cfg(nserv,nom_complet) et cfg(nserv,login)
 # c'est  l'appelant d'mettre ou non un message en fonction du code retour
 #################################################################
-proc ashare::rexec_cmd { serv cfg prog args bg output {parent ""}} {
+proc ashare::rexec_cmd { serv cfg prog args bg output {parent "None"} { logprogress "None" }} {
    upvar $output msg
    upvar $cfg config
-   # on rcupre stdout et stderr dans un fichier unique
-   set num [clock clicks -milliseconds]
-   set fout [file join $astk::tmpdir .file_rexec_out]
-   append fout "_$num"
-   set ferr [file join $astk::tmpdir .file_rexec_err]
-   append ferr "_$num"
+
+   # on rcupre stdout et stderr
+   set fout [get_tmpname .file_rexec_out]
+   set ferr [get_tmpname .file_rexec_err]
    # vrifier qu'il n'y a pas de redirection dans la commande
    # numero du process : process
 
+  # add --log_progress option and reinit logprogress
+  if { $logprogress != "None" } {
+    append args " --log_progress=$ashare::fic_progress"
+    # on pourrait choisir la fenetre de suivi selon $logprogress
+    show_fen $astk::ihm(asjob)
+    set logprogress $asjob::actu(f_progress)
+  }
+
 # attente
    ashare::pointeur off
 # local ?
@@ -161,10 +165,11 @@ proc ashare::rexec_cmd { serv cfg prog args bg output {parent ""}} {
             catch { exec rsh -n $config($serv,nom_complet) $cmd > $fout 2> $ferr & } process
          }
       } elseif { $config(-1,remote_shell_protocol) == "SSH" } {
+         # using a variable for SSH_OPTS fails on some tcl versions...
          if { $config($serv,login) != "" } {
-            catch { exec ssh -n -l $config($serv,login) $config($serv,nom_complet) $cmd > $fout 2> $ferr & } process
+            catch { exec ssh -X -n -o StrictHostKeyChecking=no -o BatchMode=yes -l $config($serv,login) $config($serv,nom_complet) $cmd > $fout 2> $ferr & } process
          } else {
-            catch { exec ssh -n $config($serv,nom_complet) $cmd > $fout 2> $ferr & } process
+            catch { exec ssh -X -n -o StrictHostKeyChecking=no -o BatchMode=yes $config($serv,nom_complet) $cmd > $fout 2> $ferr & } process
          }
       } else {
          set iret 127
@@ -183,10 +188,10 @@ proc ashare::rexec_cmd { serv cfg prog args bg output {parent ""}} {
          set msg $process
          return -999
       }
-         set ashare::fini($process) 0
-         set ashare::cycle($process) 0
-         ashare::attend $process $fout $parent
-         tkwait variable ashare::fini($process)
+      set ashare::fini($process) 0
+      set ashare::cycle($process) 0
+      ashare::attend $process $fout $logprogress "$parent"
+      tkwait variable ashare::fini($process)
    }
 # mettre l'output dans msg
    set idf [open $ferr r]
@@ -197,6 +202,7 @@ proc ashare::rexec_cmd { serv cfg prog args bg output {parent ""}} {
    close $idf
    if { $ashare::dbg < 5 } {
       file delete -force $fout
+      file delete -force $ferr
    }
 
 # code retour renvoy par as_run dans l'output (car rsh renvoie 0)
@@ -317,7 +323,7 @@ proc ashare::kill { process fout } {
 # vrifie que le process tourne encore, sinon ferme la fenetre interrompre
 # on cartonne errorCode quand le process est fini (grep)
 #################################################################
-proc ashare::attend { process fout {parent ""}} {
+proc ashare::attend { process fout logprogress {parent ""}} {
    incr ashare::cycle($process)
    #ashare::log "<DEBUG> (attend) Process $process, cycle numro : $ashare::cycle($process)"
    # on attend le 2me passage avant de faire quoique ce soit
@@ -325,6 +331,8 @@ proc ashare::attend { process fout {parent ""}} {
    if { $ashare::cycle($process) > 1 } {
       set cmd "exec $astk::cmd(shell_cmd) \"$astk::cmd(ps) -p $process | grep $process | grep -vc grep\""
       catch { eval $cmd } out
+      # logprogress
+      ashare::update_progress $logprogress
       # au cas o le regexp ne trouve rien, on considre que c'est fini
       set nocc 0
       regexp {([0-9]+)} $out mat1 nocc
@@ -336,13 +344,13 @@ proc ashare::attend { process fout {parent ""}} {
             display_cancel_button $process $fout $parent
          }
       # scrute le process toutes les 100 millisecondes
-         after 100 "ashare::attend $process $fout $parent"
+         after 100 "ashare::attend $process $fout $logprogress $parent"
       } else {
          set ashare::fini($process) 1
          catch {destroy $astk::ihm(interrompre)}
       }
    } else {
-      after 50 "ashare::attend $process $fout $parent"
+      after 50 "ashare::attend $process $fout $logprogress $parent"
    }
 }
 
@@ -383,6 +391,15 @@ proc display_cancel_button_externe { process fout {parent ""}} {
     wm deiconify $fen
 }
 
+# update progress widget
+#################################################################
+proc ashare::update_progress { w } {
+    if { $w == "None" } {
+        return
+    }
+    textLoadFile $w $ashare::fic_progress
+    $w yview end
+}
 
 # machines identiques ?
 # sans le nom de domaine
@@ -402,3 +419,160 @@ proc ashare::meme_machine { nom1 nom2 } {
    return $iret
 }
 
+# imprime les infos d'un serveur dans le fichier spcifi
+#################################################################
+proc write_server_infos { idf serv } {
+    puts $idf "P serveur $astk::config($serv,nom_complet)"
+    puts $idf "P username $astk::config($serv,login)"
+    puts $idf "P aster_root $astk::config($serv,rep_serv)"
+    puts $idf "P platform $astk::config($serv,plate-forme)"
+    # 1. try to read from server configuration
+    set proto_exec ""
+    set proto_copyto ""
+    set proto_copyfrom ""
+    set proxy_dir ""
+    catch { set proto_exec $astk::config($serv,protocol_exec) }
+    catch { set proto_copyto $astk::config($serv,protocol_copyto) }
+    catch { set proto_copyfrom $astk::config($serv,protocol_copyfrom) }
+    catch { set proxy_dir $astk::config($serv,proxy_dir) }
+    # 2. use the preferences (or a default value)
+    if { $proto_exec == "" } {
+        set proto_exec "asrun.plugins.server.SSHServer"
+        if { $astk::config(-1,remote_shell_protocol) == "RSH" } {
+            set proto_exec "asrun.plugins.server.RSHServer"
+        }
+    }
+    if { $proto_copyto == "" } {
+        set proto_copyto "asrun.plugins.server.SCPServer"
+        if { $astk::config(-1,remote_copy_protocol) == "RCP" } {
+            set proto_copyto "asrun.plugins.server.RCPServer"
+        }
+    }
+    if { $proto_copyfrom == "" } {
+        set proto_copyfrom "asrun.plugins.server.SCPServer"
+        if { $astk::config(-1,remote_copy_protocol) == "RCP" } {
+            set proto_copyfrom "asrun.plugins.server.RCPServer"
+        }
+    }
+    if { $proxy_dir == "" } {
+        set proxy_dir "/tmp"
+    }
+    puts $idf "P protocol_exec $proto_exec"
+    puts $idf "P protocol_copyto $proto_copyto"
+    puts $idf "P protocol_copyfrom $proto_copyfrom"
+    puts $idf "P proxy_dir $proxy_dir"
+}
+
+# Return True (==1) if 'host' is the same machine as localhost.
+#################################################################
+proc is_localhost { host { user "" } { ignore_domain 1 } } {
+    set refe $astk::config(-1,nom_complet)
+    if { $ignore_domain == 1 } {
+        set host [lindex [split $host "."] 0]
+        set refe [lindex [split $refe "."] 0]
+    }
+    set iret 0
+    if { ($host == "" || $host == "localhost" || $host == $refe) \
+       && [is_localuser $user] == 1 } {
+        set iret 1
+    }
+    return $iret
+}
+
+# Shorcut function using server id
+#################################################################
+proc is_localhost_serv { nsrv { ignore_domain 1 } } {
+    return [is_localhost $astk::config($nsrv,nom_complet) $astk::config($nsrv,login) $ignore_domain]
+}
+
+# Return True (==1) if 'user' is local_user.
+#################################################################
+proc is_localuser { user } {
+    set iret 0
+    if { $user == "" || $user == $astk::config(-1,login) } {
+        set iret 1
+    }
+    return $iret
+}
+
+
+# retourne le schema  utiliser pour une action donne sur un
+# serveur donn
+#################################################################
+proc get_schema { serv action } {
+    set schema ""
+    catch { set schema $astk::config($serv,schema_$action) }
+    if { $schema == "" } {
+        set schema [get_default_schema $action]
+    }
+    return $schema
+}
+
+
+# dfinition des schmas par dfaut
+#################################################################
+proc get_default_schema { action } {
+    switch -exact $action {
+        "actu" -
+        "edit" -
+        "get_results" -
+        "info" -
+        "purge_flash" -
+        "sendmail" -
+        "serv" -
+        "stop_del" -
+        "tail" -
+        "get_export" -
+        "create_issue" -
+        "insert_in_db" {
+            return "asrun.plugins.default.$action"
+        }
+        default {
+            ashare::mess erreur 55 $action
+        }
+    }
+}
+
+# retourne un nom de fichier temporaire
+#################################################################
+proc get_tmpname { { basename ".tmpfile"} } {
+   set num [clock clicks -milliseconds]
+   set fout [file join $astk::tmpdir $basename]
+   append fout "_$num"
+   return $fout
+}
+
+# expand environment variables
+# (only a restricted list of variables are supported)
+#################################################################
+proc expandvars { txt } {
+    global env
+    set mapping {}
+    foreach var { ASTER_ROOT ASTER_ETC HOME } {
+        set val ""
+        catch { set val $env($var) }
+        if { $val != "" } {
+            lappend mapping "\$$var" "$val"
+        }
+    }
+    set txt [string map $mapping $txt]
+    return $txt
+}
+
+# unexpand environment variables
+# (only a restricted list of variables are supported)
+#################################################################
+proc unexpandvars { txt } {
+    global env
+    set mapping {}
+    foreach var { ASTER_ROOT ASTER_ETC HOME } {
+        set val ""
+        catch { set val $env($var) }
+        if { $val != "" } {
+            lappend mapping "$val" "\$$var"
+        }
+    }
+    set txt [string map $mapping $txt]
+    return $txt
+}
+
