@@ -1589,7 +1589,7 @@ proc tkgetdir::CreateMenu { m } {
    # manipulation des fichiers
    if { $tkgetdir::bsf } {
       # part de la fin pour toujours insrer en $isupF
-      $m insert $isupF separator
+      #$m insert $isupF separator
       # execute une commande
       $m insert $isupF command -label [ashare::mess ihm 245] -font $astk::ihm(font,labmenu) -command {tkgetdir::AddRep ; tkgetdir::ExecCmde $tkgetdir::dirsel}
       # separateur
@@ -1643,7 +1643,7 @@ proc tkgetdir::UpdateMenu { m } {
       $m entryconfigure [ashare::mess ihm 172] -state disabled
       if { $tkgetdir::bsf } {
       # comportement bsf
-         $m entryconfigure [ashare::mess ihm 179] -state disabled
+         #$m entryconfigure [ashare::mess ihm 179] -state disabled
          $m entryconfigure [ashare::mess ihm 180] -state disabled
          $m entryconfigure [ashare::mess ihm 181] -state disabled
          $m entryconfigure [ashare::mess ihm 182] -state disabled
@@ -1671,8 +1671,8 @@ proc tkgetdir::UpdateMenu { m } {
          $m entryconfigure [ashare::mess ihm 170] -state disabled
          if { $tkgetdir::bsf } {
          # comportement bsf
-            $m entryconfigure [ashare::mess ihm 179] -state disabled
-            $m entryconfigure [ashare::mess ihm 179] -state disabled
+            #$m entryconfigure [ashare::mess ihm 179] -state disabled
+            #$m entryconfigure [ashare::mess ihm 179] -state disabled
          } else {
          # comportement selecteur
             $m entryconfigure [ashare::mess ihm 178] -font $astk::ihm(font,labmenu)
@@ -1686,8 +1686,8 @@ proc tkgetdir::UpdateMenu { m } {
          $m entryconfigure [ashare::mess ihm 170] -state normal
          if { $tkgetdir::bsf } {
          # comportement bsf
-            $m entryconfigure [ashare::mess ihm 179] -state normal
-            $m entryconfigure [ashare::mess ihm 179] -state normal
+            #$m entryconfigure [ashare::mess ihm 179] -state normal
+            #$m entryconfigure [ashare::mess ihm 179] -state normal
          } else {
          # comportement selecteur
             $m entryconfigure [ashare::mess ihm 178] -font $astk::ihm(font,labmenuB)
@@ -1898,9 +1898,6 @@ proc tkgetdir::OpenTerm { } {
    set xt $tkgetdir::config($srv,xterm)
    if { $xt != "" } {
       set cmd "$astk::cmd(shell_cmd) \"cd $dir ; "
-      if { [regexp -- {@D} $xt] == 0 } {
-         append xt " -display @D"
-      }
       append cmd $xt
       append cmd "\""
        ashare::rexec_cmd $srv tkgetdir::config $cmd "" 1 out
