@@ -53,13 +53,19 @@ proc check_conf { sortie } {
 
    if { $sortie } {
 # vrifie que les commandes distantes fonctionnent
+      set proto $astk::config(-1,remote_shell_protocol)
+      if { $proto == "" } {
+          set proto SSH
+      }
       init_config
-      if { $astk::config(-1,remote_shell_protocol) == "" || $astk::config(-1,remote_shell_protocol) == "RSH" } {
+      if { $proto == "RSH" } {
          set cmd "rsh -n -l $astk::config(-1,login) $astk::config(-1,nom_complet) echo hello"
-      } elseif { $astk::config(-1,remote_shell_protocol) == "SSH" } {
+         set iderr 25
+      } elseif { $proto == "SSH" } {
          set cmd "ssh -n -l $astk::config(-1,login) $astk::config(-1,nom_complet) echo hello"
+         set iderr 56
       } else {
-         ashare::mess erreur 49 $astk::config(-1,remote_shell_protocol)
+         ashare::mess erreur 49 $proto
          # le premier appel  rexec_cmd chouera
          cmd="echo ERROR"
       }
@@ -75,11 +81,11 @@ proc check_conf { sortie } {
                if { $jret == 0 && $out == "hello" } {
                   ashare::mess info 30
                } else {
-                  ashare::mess erreur 25 $astk::config(-1,login) $astk::config(-1,nom_complet) $astk::config($i,login) $astk::config($i,nom_complet) $out
+                  ashare::mess erreur $iderr $astk::config(-1,login) $astk::config(-1,nom_complet) $astk::config($i,login) $astk::config($i,nom_complet) $out
                   incr nberr
                }
             } else {
-               ashare::mess erreur 25 $astk::config($i,login) $astk::config($i,nom_complet) $astk::config(-1,login) $astk::config(-1,nom_complet) $out
+               ashare::mess erreur $iderr $astk::config($i,login) $astk::config($i,nom_complet) $astk::config(-1,login) $astk::config(-1,nom_complet) $out
                incr nberr
             }
          }
@@ -208,7 +214,7 @@ proc conv_tps { var } {
    if {[regexp {^[1-9]+} $var] != 1} {
       set var "0$var"
    }
-   
+
    if {[regexp {^[ ]*([0-9]+)[ ]*:[ ]*([0-9]+)[ ]*:[ ]*([0-9]+)[ ]*} $var phr hh mm ss] == 1} {
       set val [ expr $ss+($mm*60)+($hh*3600) ]
    } elseif {[regexp {^[ ]*([0-9]+)[ ]*:[ ]*([0-9]+)[ ]*} $var phr mm ss] == 1} {
@@ -228,11 +234,11 @@ proc conv_tps { var } {
 #################################################################
 proc mod_ORBInitRef { ORBInitRefValue } {
    set repl ""
-   set astk::profil(option,ORBInitRef) 1   
-   append repl " -ORBInitRef"   
-   set astk::profil(opt_val,ORBInitRef) $ORBInitRefValue   
+   set astk::profil(option,ORBInitRef) 1
+   append repl " -ORBInitRef"
+   set astk::profil(opt_val,ORBInitRef) $ORBInitRefValue
    append repl " $ORBInitRefValue"
-   append astk::profil(args_fixe) "$repl"   
+   append astk::profil(args_fixe) "$repl"
    regsub {^[ ]*} $astk::profil(args_fixe) "" astk::profil(args_fixe)
    regsub {[ ]*$} $astk::profil(args_fixe) "" astk::profil(args_fixe)
 }
@@ -385,7 +391,7 @@ proc choixIP { ilast } {
    pack [frame $fen.txt -relief solid -bd 0] -anchor c
    label $fen.txt.lbl -font $astk::ihm(font,txt) -text [ashare::mess ihm 351] -anchor w
    pack $fen.txt.lbl -padx 20 -pady 10 -side left
-   
+
 #  zone IP
    pack [frame $fen.ip -relief solid -bd 0] -padx 15 -pady 10 -anchor c -fill both -expand 1
       grid [frame $fen.ip.f -relief raised -bd 0] -row 0 -column 0 -sticky nsew -padx 15 -pady 10
@@ -407,16 +413,16 @@ proc choixIP { ilast } {
    scrollbar $fen.ip.f.scrolly -command "$fen.ip.f.lst yview"
    pack $fen.ip.f.scrolly -side right  -fill y
    pack $fen.ip.f.lst -expand yes -fill both
-   
+
    set manIP ""
    entry $fen.ip.man.ent -font $astk::ihm(font,zonfix) -textvariable manIP -width 15
    pack $fen.ip.man.ent -fill x -expand 1
-   
+
    button $fen.ip.valid.ok -font $astk::ihm(font,labbout) -text "Ok" \
       -bg $astk::ihm(couleur,valid) \
       -command "acceptIP $fen"
    pack $fen.ip.valid.ok -side left -padx 10 -pady 5
-   
+
    # selection par defaut
    if { $ilast > -1 } {
       $fen.ip.f.lst selection set $ilast
@@ -432,7 +438,7 @@ proc choixIP { ilast } {
 #################################################################
 proc acceptIP { fen } {
    global listadr manIP
-   
+
    set indsel [$fen.ip.f.lst curselection]
    set ip ""
    if { $indsel != "" } {
@@ -449,3 +455,18 @@ proc acceptIP { fen } {
       destroy $fen
    }
 }
+
+# valide une valeur oui/non
+#################################################################
+proc in_yes_values { val } {
+    set iret 0
+    set val [string tolower $val]
+    if { $val == "oui" || $val == "yes" } {
+        set iret 1
+    }
+    return $iret
+}
+
+proc in_no_values { val } {
+    return [expr 1 - [in_yes_values $val] ]
+}
