@@ -435,7 +435,7 @@ class SGE(BatchSystem):
         """Modify submission 'script' file.
         """
         txt = ["#$ -N %(nomjob)s",
-               "#$ -l cpu=%(tpmax)s,s_rss=%(memjob)sK",
+               "#$ -l s_cpu=%(tpmax)s,s_rss=%(memjob)sK",
                "#$ -e %(error)s",
                "#$ -o %(output)s"]
         #if self.dict_info.get('mpi_nbcpu'):
