@@ -1032,7 +1032,8 @@ sys.exit(iret)
         cmd = [osp.join('.', osp.basename(kargs['exe']))]
         cmd.append(osp.join(self.conf['REPPY'][0], self.conf['ARGPYT'][0]))
         cmd.extend(self.conf['ARGEXE'])
-        cmd.append('-commandes fort.1 -memjeveux 64 -tpmax 120')
+        # <512 for 32 bits builds
+        cmd.append('-commandes fort.1 -memjeveux 500 -tpmax 120')
         fo = open('fort.1', 'w')
         fo.write("""
 # COMPILATION DU CATALOGUE D'ELEMENT
@@ -1251,7 +1252,7 @@ FIN()
 
     def _check_file_args(self, args):
         """Check that files and directories in arguments exist."""
-        if type(args) not in (list,tuple):
+        if type(args) not in (list, tuple):
             args = [args, ]
         for occ in args:
             obj = occ
@@ -1531,7 +1532,7 @@ def unigest2dict(funig, conf, with_fordepla=False):
             ext = osp.splitext(nam)[-1]
             if ext in ('', '.comm'):
                 nam = osp.splitext(nam)[0] + '.*'
-            dico['test'].append(osp.join(conf['SRCTEST'][0], nam))
+            dico['test'].extend([osp.join(dtest, nam) for dtest in conf['SRCTEST']])
 
         mat = re.search('^ *FORDEPLA +([-_a-zA-Z0-9]+) +([-_a-zA-Z0-9]+)' \
                 ' +([-_a-zA-Z0-9]+)', line)
@@ -1547,6 +1548,20 @@ def unigest2dict(funig, conf, with_fordepla=False):
     fo.close()
     return dico
 
+def glob_unigest(dico, repref):
+    """Expand paths relatively to `repref`."""
+    prev = os.getcwdu()
+    os.chdir(repref)
+    dico = dico.copy()
+    for key, values in dico.items():
+        if key == 'filename':
+            continue
+        new = []
+        for path in values:
+            new.extend(glob(path))
+        dico[key] = new
+    os.chdir(prev)
+    return dico
 
 def get_include(src):
     """Returns include files in the given source."""
