@@ -264,8 +264,8 @@ class AsterCalcul(BaseCalcul):
             return
         memory = float(self.prof['memjob'][0] or 0.) / 1024. + addmem
         self.prof.set_param_memory(memory)
-        self.run.DBG("new memory parameters: memjob=%s  memjeveux=%s",
-                     self.prof['memjob'][0], self.prof.args['memjeveux'])
+        self.run.DBG("new memory parameters: memjob=%s  memjeveux=%s" % \
+                     (self.prof['memjob'][0], self.prof.args['memjeveux']))
 
     def on_mach_ref(self):
         """Are we on the reference server ?
@@ -659,6 +659,8 @@ class AsterCalcTestcase(AsterCalcul):
         del ptest['follow_output']
         del ptest['rep_trav']
         del ptest['detr_rep_trav']
+        del ptest['depart']
+        del ptest['mem_aster']
 
         # update with the export to run the test
         lunig = ptest.get_type('unig')
@@ -688,16 +690,14 @@ class AsterCalcTestcase(AsterCalcul):
         return ptest
 
     def clean_results(self):
-        """Remove all result files.
-        """
-        erre = self.prof.Get('R', 'erre')[0]['path']
+        """Remove all result files"""
         resu = self.prof.Get('R', 'resu')[0]['path']
         mess = self.prof.Get('R', 'mess')[0]['path']
-        for f in (erre, resu, mess):
+        code = self.prof.Get('R', 'code')[0]['path']
+        for f in (resu, mess, code):
             self.run.Delete(f)
 
 
-
 class AsterCalcParametric(AsterCalcul):
     """Derivation for a parametric study :
         - change all "comm" files
