@@ -85,6 +85,11 @@ def on_64bits():
     """Tell if it's running on a 64 bits platform"""
     return platform.architecture()[0].startswith("64")
 
+def is_newer_mtime(mtime1, file2):
+    """Return True if mtime1 is a newer time than file2's mtime."""
+    # convenient when file1 can be changed in a loop
+    return mtime1 > os.stat(file2).st_mtime
+
 def is_newer(file1, file2):
     """Return True if file1 is newer than file2."""
     return os.stat(file1).st_mtime > os.stat(file2).st_mtime
@@ -144,7 +149,7 @@ def get_exec_name(script):
 def unexpandvars_string(text, vars=None):
     """Reverse of os.path.expandvars."""
     if vars is None:
-        vars = ('ASTER_ETC', 'ASTER_ROOT', 'HOME')
+        vars = ('ASTER_ETC', 'ASTER_ROOT', 'ASTER_VERSION_DIR', 'HOME')
     if type(text) not in (str, unicode):
         return text
     for var in vars:
