@@ -290,7 +290,8 @@ def get_list(ftest, unique=True):
 
 
 list_para_test = ['mem_job', 'tps_job', 'mem_aster', 'memjeveux', 'memjeveux_stat',
-                  'ncpus', 'mpi_nbnoeud', 'mpi_nbcpu', 'liste_test']
+                  'ncpus', 'mpi_nbnoeud', 'mpi_nbcpu', 'liste_test', 'testlist',
+                  'memory_limit', 'time_limit']
 
 def getpara(fpara, platform=None, others=[]):
     """Return a dict object by parsing the file 'fpara' written as :
