@@ -90,6 +90,7 @@ class SectionTitle(Entry):
 
 class Configuration(Singleton):
     """Definition of the configuration"""
+    _singleton_id = 'asrun.configuration.Configuration'
     #XXX transitionnal implementation
     #       (code to change is marking with XXX)
 
@@ -251,6 +252,7 @@ class Magic(Singleton):
     """Store some asrun objects to share them by several modules.
     """
     # stored in a container will make easier the refactoring
+    _singleton_id = 'asrun.configuration.Magic'
     def __init__(self):
         self._run = None
         self._stdout = sys.stdout
