@@ -185,7 +185,8 @@ class MESSAGE_MANAGER(object):
     def check_cata(self):
         """Vérifie les catalogues.
         """
-        print3('%5d catalogues dans %s + %s' \
+        if self.verbose:
+            print3('%5d catalogues dans %s + %s' \
                 % (len(self.l_cata), self.pyt, self.surch_pyt))
         all_msg = []
         error_occurs = False
@@ -212,12 +213,12 @@ class MESSAGE_MANAGER(object):
         union = used.union(all_msg)
         not_found = list(used.difference(all_msg))
         not_found.sort()
-        print3('%6d messages dans les catalogues' % len(all_msg))
-        print3('dont %6d messages appeles presents dans les catalogues' % (len(used) - len(not_found)))
-        print3('  et %6d messages inutilises' % len(unused))
-        print3('   + %6d messages appeles absents des catalogues' % len(not_found))
+        if self.verbose:
+            print3('%6d messages dans les catalogues' % len(all_msg))
+            print3('dont %6d messages appeles presents dans les catalogues' % (len(used) - len(not_found)))
+            print3('  et %6d messages inutilises' % len(unused))
+            print3('   + %6d messages appeles absents des catalogues' % len(not_found))
         #print '%6d messages total (union pour verif)' % len(union)
-
         return unused, not_found
 
 
@@ -250,6 +251,12 @@ class MESSAGE_MANAGER(object):
             s_f.update(glob(osp.join(dsrc, '*', '*.f')))
             s_f.update(glob(osp.join(dsrc, '*.F')))
             s_f.update(glob(osp.join(dsrc, '*', '*.F')))
+            s_f.update(glob(osp.join(dsrc, '*.F90')))
+            s_f.update(glob(osp.join(dsrc, '*', '*.F90')))
+        if self.conf_obj.use_hg:
+            l_f = [osp.abspath(f) for f in s_f]
+            l_f.sort()
+            return l_f
         d_f = {}
         for f in s_f:
             assert d_f.get(osp.basename(f)) is None, 'ERROR : %s  (old : %s)' % (f, d_f[osp.basename(f)])
@@ -298,6 +305,10 @@ class MESSAGE_MANAGER(object):
         s_pyt.update(glob(osp.join(self.pyt, '*', '*.py')))
         s_pyt.update(glob(osp.join(self.capy, '*.capy')))
         s_pyt.update(glob(osp.join(self.capy, '*', '*.capy')))
+        if self.conf_obj.use_hg:
+            l_pyt = [osp.abspath(f) for f in s_pyt]
+            l_pyt.sort()
+            return l_pyt
         d_py = {}
         for f in s_pyt:
             typ = osp.splitext(f)[-1][1:]
@@ -360,7 +371,7 @@ class MESSAGE_MANAGER(object):
             expr  = 'CALL\s+(U2MES.|UTEXC[MP]+|UTPRIN)\s*\(([^,]*?), *[\'\"]+(.*?)[\'\"]+ *[,\)]+'
         else:
             expr = '[\s\.:]+(UTMESS|GetText)\s*\(([^,]*?), *[\'\"]+(.*?)[\'\"]+ *[,\)]+'
-        all_msg = re.findall(expr, txt)
+        all_msg = re.findall(expr, txt, flags=re.I)
         l_msg = []
         for found in all_msg:
             sub, typ, msg = found
@@ -707,9 +718,11 @@ def clean_source(content, ext, ignore_comments, wrap):
     """Nettoie un fichier source.
     """
     if ignore_comments:
-        assert ext in ('.f', '.F', '.py', '.capy'), 'unknown type : %s' % str(ext)
+        assert ext in ('.f', '.F', '.F90', '.py', '.capy'), 'unknown type : %s' % str(ext)
         if ext in ('.f', '.F'):
             reg_ign = re.compile('(^[A-Z!#].*$)', re.MULTILINE)
+        elif ext in ('.F90'):
+            reg_ign = re.compile('(^[!#].*$)', re.MULTILINE)
         elif ext in ('.py', '.capy'):
             reg_ign = re.compile('(#.*$)', re.MULTILINE)
         content = reg_ign.sub('', content).expandtabs()
@@ -735,9 +748,6 @@ def GetMessageInfo(run, *args):
     bibfor = [conf['SRCFOR'][0],]
     if conf['SRCF90'][0] != '':
         bibfor.append(conf['SRCF90'][0])
-    else:
-        run.Mess(_(u'Fortran 90 source files are not used on this machine (see %s)') \
-                % conf.filename, '<A>_ALARM')
 
     args = list(args)
     named_actions = ('check', 'move',)
