@@ -26,10 +26,9 @@ Tools for developpers :
 import os.path as osp
 from glob import glob
 
-from asrun.installation import aster_root
 from asrun.common.i18n import _
 from asrun.mystring import print3
-from asrun.config import AsterConfig
+from asrun.config import build_config_of_version
 
 
 
@@ -66,17 +65,15 @@ def FreeSubroutines(run, *args):
     MAX = 8
     if not run.get('aster_vers'):
         run.parser.error(_(u"You must define 'default_vers' in 'aster' configuration file or use '--vers' option."))
-    REPREF = osp.join(aster_root, run['aster_vers'])
-    if not run.get('config'):
-        fconf = osp.join(REPREF, 'config.txt')
-    else:
-        fconf = osp.abspath(run['config'])
-    conf = AsterConfig(fconf, run)
+    fconf = run.get('config')
+    if fconf:
+        fconf = osp.abspath(fconf)
+    conf = build_config_of_version(run, run['aster_vers'], fconf)
 
     if run['nolocal']:
         run.Mess(_(u'This operation only works on local source files. "--nolocal" option ignored'))
 
-    bibfor = osp.join(REPREF, conf['SRCFOR'][0])
+    bibfor = conf.get_with_absolute_path('SRCFOR')[0]
 
     lte = get_available_te(bibfor)
     lop = get_available_op(bibfor)
