@@ -27,33 +27,13 @@ import time
 from asrun.common.i18n import _
 from asrun.mystring  import print3, ufmt, add_to_tail
 from asrun.calcul    import AsterCalcTestcase, AsterCalcParametric
-from asrun.thread    import Task, TaskAbort, Empty
+from asrun.thread    import Task, TaskAbort, Empty, Lock
 from asrun.repart    import NORESOURCE, ALLOCATED, OVERLIMIT
+# import keep for compatibility ?
+from asrun.common.utils import force_list, force_couple
 
 fmt_resu = '%-12s %-10s %-18s %8.2f %8.2f %8.2f %8.2f'
-
-
-def force_list(obj):
-    """Return 'obj' as a list object."""
-    if type(obj) not in (list, tuple):     # pas une liste
-        obj = [obj,]
-    return obj
-
-
-def force_couple(obj):
-    """Return 'obj' as a list of couples."""
-    if type(obj) not in (list, tuple):     # pas une liste
-        obj = [[obj, None],]
-    elif type(obj[0]) in (list, tuple):    # liste de listes
-        pass
-    else:
-        assert len(obj) == 2, 'not a couple : %s' % obj
-        obj = [obj,]
-    # verif
-    for i, val in enumerate(obj):
-        assert len(val) == 2, 'item %d is not a couple : %s' % (i, val)
-    return obj
-
+FAILURE = object()
 
 def check_opts(obj):
     """Check that values have the expected interface."""
@@ -75,7 +55,7 @@ class DistributionTask(Task):
     """Manage executions of several Code_Aster executions.
     items are couples (jobname, dict_options)
 
-    attributes (init during instanciation) :
+    attributes (initialized during instanciation) :
         run     : AsterRun object
         hostrc  : ResourceManager object
         timeout : timeout for not allocated jobs
@@ -91,6 +71,12 @@ class DistributionTask(Task):
     cpresok = False
     REPREF = reptest = resutest = flashdir = reptrav = ""
 
+    def __init__(self, **kwargs):
+        """Initialization"""
+        Task.__init__(self, **kwargs)
+        # class attrs should be here!
+        self._ended_lock = Lock()
+
     def _mess_timeout(self, dt, timeout, job, refused):
         """Emit a message when submission timeout occurs."""
         self.run.Mess(ufmt(_(u"no submission for last %.0f s (timeout %.0f s), job '%s' " \
@@ -173,7 +159,8 @@ class DistributionTask(Task):
                             opts['submit_time'] = self.last_submit
                             opts['order'] = order
                             run_calc.append([job, opts, itemid, calcul])
-                    if result is not None:
+                    if result is FAILURE:
+                        result = self.failure(job, opts, itemid)
                         l_resu.append(result)
 
             # 2. get calculation state
@@ -189,7 +176,7 @@ class DistributionTask(Task):
                     if self.hostrc is not None:
                         self.hostrc.Free(job)
                     res = list(self.get_calcul_diag(calcul))
-                    result = self.ended(job, opts, itemid, calcul, res)
+                    result = self._ended_thread(job, opts, itemid, calcul, res)
                     sum_elaps += result[6]
                     l_resu.append(result)
                 else:
@@ -204,15 +191,22 @@ class DistributionTask(Task):
         return l_resu
 
     def failure(self, job, opts, itemid):
-        """Define the result returns in case of failure.
-        """
-        return [job, opts, '<F>_NOT_RUN', 0., 0., 0., 0., _(u'none')]
+        """Count failure as NOOK like an error at execution."""
+        self.nbnook[opts['threadid']] += 1
+        res = ['<F>_NOT_RUN', 0., 0., 0., 0.]
+        result = [job, opts]
+        result.extend(res)
+        line = self.summary_line(job, opts, res)
+        add_to_tail(self.resutest, line, filename='NOOK')
+        add_to_tail(self.resutest, line, filename='RESULTAT')
+        result.append('failure')
+        return result
 
     def refused(self, job, opts, itemid, status):
         """Action when a job is refused.
         """
         opts['refused'] =  opts.get('refused', 0) + 1
-        result = self.failure(job, opts, itemid)
+        result = FAILURE
         if   status == OVERLIMIT:
             self.run.Mess(ufmt(_(u"job '%s' exceeds resources limit (defined through "
                 "hostfile), it will not be submitted."), job), '<A>_LIMIT_EXCEEDED')
@@ -235,7 +229,7 @@ class DistributionTask(Task):
     def start_failed(self, job, opts, itemid, msg):
         """Action when a job submitting failed. """
         self.run.Mess(ufmt(_(u"'%s' not submitted. Error : %s"), job, msg), '<A>_NOT_SUBMITTED')
-        return self.failure(job, opts, itemid)
+        return FAILURE
 
     def get_calcul_state(self, calcul):
         """Function to retreive the state of a calculation."""
@@ -263,12 +257,22 @@ class DistributionTask(Task):
 
     def summary_line(self, job, opts, res):
         """Return a summary line of the execution result."""
-        args = [job, '(%d/%d)' % (opts['order'], self.nbitem)]
+        args = [job, '(%d/%d)' % (opts.get('order', 0), self.nbitem)]
         args.extend(res)
-        line = ufmt(fmt_resu, *args)
+        if len(args) == 7:
+            line = ufmt(fmt_resu, *args)
+        else:
+            line = '%s : can not write the summary line' % job
         return line
 
-    # refused, start_failed, ended should return result in the same format
+    def _ended_thread(self, *args):
+        """Call 'ended' method thread safely"""
+        self._ended_lock.acquire()
+        result = self.ended(*args)
+        self._ended_lock.release()
+        return result
+    
+    # failure, ended should return result in the same format
     def ended(self, job, opts, itemid, calcul, res):
         """Call when a job is ended."""
         raise NotImplementedError
@@ -280,7 +284,6 @@ class DistributionTask(Task):
         raise NotImplementedError
 
 
-
 class DistribTestTask(DistributionTask):
     """Manage executions of several Code_Aster testcases.
     items are couples (jobname=testcase name, options)
@@ -367,7 +370,8 @@ class DistribTestTask(DistributionTask):
         """
         nf = len(self.test_result)
         self.test_result.extend(l_resu)
-        for job, opts, diag, tcpu, tsys, ttot, telap, output in l_resu:
+        for values in l_resu:
+            job, diag = values[0], values[2]
             nf += 1
             if self.info >= 2:
                 self.run.Mess(ufmt(_(u'%s completed (%d/%d), diagnostic : %s'),
@@ -445,7 +449,8 @@ class DistribParametricTask(DistributionTask):
         """
         nf = len(self.exec_result)
         self.exec_result.extend(l_resu)
-        for job, opts, diag, tcpu, tsys, ttot, telap, output in l_resu:
+        for values in l_resu:
+            job, diag = values[0], values[2]
             nf += 1
             if self.info >= 2:
                 self.run.Mess(ufmt(_(u'%s completed (%d/%d), diagnostic : %s'),
