@@ -35,7 +35,7 @@ from asrun.mystring     import print3, ufmt
 from asrun.profil       import AsterProfil
 from asrun.build        import AsterBuild
 from asrun.config       import build_config_from_export
-from asrun.maintenance  import get_aster_version
+from asrun.maintenance  import get_aster_version, get_export
 from asrun.execution    import execute, copyfiles, build_export_from_files, add_all_results
 from asrun.mpi          import MPI_INFO
 from asrun.astout       import RunAstout
@@ -63,6 +63,11 @@ def SetParser(run):
             'syntax' : '[options] file1 [file2 [...]] [--surch_pyt=...] [--surch_fort=...]',
             'help'   : _(u'Start quickly an interactive execution using the files given in arguments')
         },
+        'test'     : {
+            'method' : StartTestNow,
+            'syntax' : '[options] testcase',
+            'help'   : _(u'Start an interactive execution of a testcase')
+        },
         'make_shared' : {
             'method' : MakeShared,
             'syntax' : '--output=FILE [src1 [...]] srcN',
@@ -83,7 +88,7 @@ def SetParser(run):
     }
     run.SetActions(
             actions_descr = acts_descr,
-            actions_order = ['run', 'quick', 'make_shared'],
+            actions_order = ['run', 'quick', 'test', 'make_shared'],
             group_options = False,
             options_descr=opts_descr
     )
@@ -415,7 +420,6 @@ def RunAster(run, *args):
                 multiple       = False,
                 with_dbg       = 'make_dbg' in prof['actions'],
                 only_env       = only_env,
-                fpara          = None,
                 mpi_info       = mpi,
                 run=run, conf=conf, prof=prof, build=build, exe=exetmp)
 
@@ -595,7 +599,9 @@ def StartNow(run, *args):
     # build export
     lf = [osp.abspath(f) for f in args]
     prof = build_export_from_files(run, lf, with_results=True)
-
+    # debug mode is enabled using -g/--debug option
+    if run['debug']:
+        prof['debug'] = 'debug'
     # development files
     surch_pyt = run.get('surch_pyt', [])
     if surch_pyt:
@@ -638,4 +644,27 @@ def StartNow(run, *args):
     # execution
     RunAster(run, prof)
 
+def StartTestNow(run, *args):
+    """Start a testcase in interactive mode"""
+    # ----- check argument
+    if not run.get('aster_vers'):
+        run.parser.error(_(u"You must define 'default_vers' in 'aster' configuration file or use '--vers' option."))
+    if len(args) != 1:
+        run.parser.error(_(u"'--%s' requires exactly one argument") % run.current_action)
+    testcase = args[0]
+    prof = get_export(run, testcase)
+    # debug mode is enabled using -g/--debug option
+    if run['debug']:
+        prof['debug'] = 'debug'
+    conf = build_config_from_export(run, prof)
+    try:
+        addmem = float(conf['ADDMEM'][0])
+    except ValueError:
+        addmem = 0.
+    if not addmem:
+        return
+    memory = float(prof['memjob'][0] or 0.) / 1024. + addmem
+    prof.set_param_memory(memory)
+    run.Mess(_("starting %s") % testcase)
+    RunAster(run, prof)
 
