@@ -31,8 +31,9 @@ from math import log10
 from asrun.installation import confdir
 from asrun.common.i18n import _
 from asrun.mystring     import print3, ufmt, file_cleanCR
+from asrun.build        import glob_unigest
 from asrun.mpi          import MPI_INFO
-from asrun.profil       import AsterProfil
+from asrun.profil       import AsterProfil, ExportEntry
 from asrun.common_func  import get_tmpname
 from asrun.common.utils import getpara, check_joker, hms2s
 from asrun.common.sysutils import on_64bits
@@ -79,8 +80,7 @@ def execute(reptrav, multiple=False, with_dbg=False, only_env=False,
         multiple : False if only one execution is run (so stop if it fails),
             True if several executions are run (don't stop when error occurs)
         with_dbg : start debugger or not,
-        fpara    : .para file, if None memory, time limits and number of cpu are
-            read in prof,
+        fpara    : deprecated,
         follow_output : print output to follow the execution,
     kargs give "run, conf, prof, build" instances + exec name
     Return a tuple (diag, tcpu, tsys, ttot, validbase).
@@ -137,7 +137,7 @@ def execute(reptrav, multiple=False, with_dbg=False, only_env=False,
     if prof['ncpus'][0] != '':
         ncpus = prof['ncpus'][0]
 
-    # 4. ----- add parameters from prof or fpara if present
+    # 4. ----- add parameters from prof
     if on_64bits():
         facW = 8
     else:
@@ -146,51 +146,32 @@ def execute(reptrav, multiple=False, with_dbg=False, only_env=False,
     memj  = 0
     memjs = 0
     nbp   = 0
-    if fpara:
-        kret, dpara, msg = getpara( fpara, run['plate-forme'])
-        if kret != 0:
-            run.Mess(ufmt(_(u'can not parse parameter file : %s'), fpara), '<E>_ERROR')
-            return run.diag, tcpu, tsys, ttot, validbase
-        memj = dpara['memjeveux']
-        memjs = dpara['memjeveux_stat']
-        cmd_memtps['memjeveux'] = memj
-        cmd_memtps['memjeveux_stat'] = memjs
-        tps = int(dpara['tps_job']*facmtps)
-        cmd_memtps['tpmax'] = tps
-        if dpara['ncpus'] != 0:
-            ncpus = dpara['ncpus']
-    else:
-        try:
-            tps = int(float(prof.args['tpmax']))
-        except KeyError:
-            run.Mess(_(u'tpmax not provided in profile'), '<E>_INCORRECT_PARA')
-        except ValueError:
-            run.Mess(_(u'incorrect value for tpmax (%s) in profile') % \
-                    prof.args['tpmax'], '<E>_INCORRECT_PARA')
-        try:
-            memj = float(prof.args['memjeveux'])
-        except KeyError:
-            run.Mess(_(u'memjeveux not provided in profile'), '<E>_INCORRECT_PARA')
-        except ValueError:
-            run.Mess(_(u'incorrect value for memjeveux (%s) in profile') % \
-                    prof.args['memjeveux'], '<E>_INCORRECT_PARA')
+    try:
+        tps = int(float(prof.args['tpmax']))
+    except KeyError:
+        run.Mess(_(u'tpmax not provided in profile'), '<E>_INCORRECT_PARA')
+    except ValueError:
+        run.Mess(_(u'incorrect value for tpmax (%s) in profile') % \
+                prof.args['tpmax'], '<E>_INCORRECT_PARA')
+    try:
+        memj = float(prof.args['memjeveux'])
+    except KeyError:
+        run.Mess(_(u'memjeveux not provided in profile'), '<E>_INCORRECT_PARA')
+    except ValueError:
+        run.Mess(_(u'incorrect value for memjeveux (%s) in profile') % \
+                prof.args['memjeveux'], '<E>_INCORRECT_PARA')
 
-        try:
-            memjs = float(prof.args.get('memjeveux_stat', 0))
-        except ValueError:
-            run.Mess(_(u'incorrect value for memjeveux_stat (%s) in profile') % \
-                    prof.args['memjeveux_stat'], '<E>_INCORRECT_PARA')
+    try:
+        memjs = float(prof.args.get('memjeveux_stat', 0))
+    except ValueError:
+        run.Mess(_(u'incorrect value for memjeveux_stat (%s) in profile') % \
+                prof.args['memjeveux_stat'], '<E>_INCORRECT_PARA')
 
     try:
         nbp = int(ncpus)
     except ValueError:
         run.Mess(_(u'incorrect value for ncpus (%s) in profile') % \
                 prof['ncpus'][0], '<E>_INCORRECT_PARA')
-    nf = '%s.para' % run['num_job']
-    if ctest:
-        nf = 'test.para'
-    fillpara(run, filename=nf, tps_job=tps, memjMo=memj*facW, memjstat=memjs,
-             mem_aster=prof['mem_aster'], ncpus=nbp)
 
     # 4.1. check for memory, time and procs limits
     run.Mess(_(u'Parameters : memory %d MB - time limit %d s') % (memj*facW, tps))
@@ -533,13 +514,10 @@ def copyfileR(run, df, copybase=True, alarm=True):
     isdir = False
 
     # 1. ----- files
-    if df['ul'] != 0 or df['type'] in ('nom', 'para'):
+    if df['ul'] != 0 or df['type'] in ('nom', ):
         # if logical unit is set : fort.*
         if df['ul'] != 0:
             lf.append('fort.%d' % df['ul'])
-        elif df['type'] == 'para':
-            fpara = '%s.para' % run['num_job']
-            lf.append(fpara)
         elif df['type'] == 'nom':
             lf.append(osp.basename(df['path']))
 
@@ -621,28 +599,54 @@ def build_test_export(run, conf, REPREF, reptest, test, resutest=None,
         if run.IsRemote(rep):
             run.Mess(ufmt(_(u'reptest (%s) must be on exec host'), rep),
                     '<F>_INVALID_DIR')
+    lrep = [run.PathOnly(rep) for rep in lrep]
     lrm = []
     if d_unig:
-        lrm = [osp.basename(f) for f in d_unig['test']]
-    lall = []
-    lrep = [run.PathOnly(rep) for rep in lrep]
-    for r in lrep:
-        f = osp.join(r, '%s.*' % test)
-        lall.extend(glob(f))
-    lf = []
-    for f in lall:
-        if osp.basename(f) in lrm:
-            run.Mess(ufmt(_(u'deleting %s (matches unigest)'), osp.basename(f)))
-        else:
-            lf.append(f)
-    prof = build_export_from_files(run, lf, test, with_default=with_default)
+        d_unig = glob_unigest(d_unig, REPREF)
+        lrm = set([osp.basename(f) for f in d_unig['test']])
+
+    export = _existing_file(test + '.export', lrep, last=True)
+    # new testcase with .export
+    if export:
+        prof = AsterProfil(run=run)
+        if with_default:
+            prof.add_default_parameters()
+        pexp = AsterProfil(export, run)
+        pexp.set_param_limits()
+        for entry in pexp.get_data():
+            if osp.basename(entry.path) in lrm:
+                run.Mess(ufmt(_(u'deleting %s (matches unigest)'),
+                              osp.basename(entry.path)))
+                pexp.remove(entry)
+            found = _existing_file(entry.path, lrep, last=True)
+            if found is None:
+                run.Mess(ufmt(_(u'file not found : %s'), entry.path),
+                                 '<E>_FILE_NOT_FOUND')
+                pexp.remove(entry)
+            else:
+                entry.path = found
+        pexp._compatibility()
+        prof.update(pexp)
+    else:
+    # old version using .para
+        lall = []
+        for r in lrep:
+            f = osp.join(r, '%s.*' % test)
+            lall.extend(glob(f))
+        lf = []
+        for f in lall:
+            if osp.basename(f) in lrm:
+                run.Mess(ufmt(_(u'deleting %s (matches unigest)'), osp.basename(f)))
+            else:
+                lf.append(f)
+        prof = build_export_from_files(run, lf, test, with_default=with_default)
     if resutest:
-        for typ, ul in {'resu' : 8, 'mess' : 6, 'erre' : 9}.items():
-            prof.Set('R', { 'type'  : typ,
-                         'isrep' : False,
-                         'path'  : osp.join(resutest, '%s.%s' % (test, typ)),
-                         'ul'    : ul,
-                         'compr' : False } )
+        ftyp = { 'resu' : 8, 'mess' : 6, 'code' : 15 }
+        for typ, ul in ftyp.items():
+            new = ExportEntry(osp.join(resutest, '%s.%s' % (test, typ)),
+                              type=typ, ul=ul,
+                              result=True)
+            prof.add(new)
     return prof
 
 
@@ -745,26 +749,6 @@ def getdbgcmd(cmd_dbg, exe, core, lcmd, args):
     return [cmd]
 
 
-def fillpara(run, **kargs):
-    """Write a file `pid`.para in current directory similar to testcases ones.
-    """
-    form = 'tps_job %(tps_job)d mem_job %(mem_job)dMo '\
-          'mem_aster %(mem_aster)d ncpus %(ncpus)d\n'
-    dform = kargs.copy()
-
-    try:
-        dform['tps_job']   = int(kargs['tps_job'])
-        dform['mem_aster'] = int(kargs['mem_aster'][0] or '100')
-        dform['mem_job']   = int(kargs['memjMo'] * 100. / dform['mem_aster'])
-        dform['memjeveux_stat'] = kargs.get('memjeveux_stat', 0)
-        dform['ncpus']     = int(kargs['ncpus'])
-#      dform['nnoeud_mpi'] = int(kargs[''])
-        open(kargs['filename'], 'w').write(form % dform)
-    except Exception, msg:
-        pass
-    run.DBG(kargs)
-
-
 def check_limits(run, mode, tps, mem, nbp, mpi_nbnoeud, mpi_nbcpu):
     """Return True if args are less than limits defined in
     configuration file, False else.
@@ -827,3 +811,17 @@ def update_cmd_memtps(dico):
     if d.get('cpu_restant') is not None:
         dnew['tpmax'] = int(d['cpu_restant'])
     dico.update(dnew)
+
+
+def _existing_file(fname, l_paths, last=False):
+    """Return the first (or `last` if True) existing file in `l_paths`.
+    Return None if `fname` is not found."""
+    l_paths = l_paths[:]
+    if last:
+        l_paths.reverse()
+    path = None
+    for dirn in l_paths:
+        if osp.exists(osp.join(dirn, fname)):
+            path = osp.join(dirn, fname)
+            break
+    return path
