@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
-import os.path
+import sys
+import os
+import os.path as osp
 
 from asrun.common.utils import get_absolute_dirname
 
@@ -10,7 +12,7 @@ if os.environ.get('ASTER_ROOT'):
     aster_root = os.environ['ASTER_ROOT']
 else:
     #               asrun           site-packages pythonX.Y      lib     prefix
-    aster_root = os.path.normpath(os.path.join(
+    aster_root = osp.normpath(osp.join(
         get_absolute_dirname(__file__), os.pardir, os.pardir, os.pardir, os.pardir))
 os.environ['ASTER_ROOT'] = aster_root
 
@@ -19,10 +21,14 @@ os.environ['ASTER_ROOT'] = aster_root
 prefix = aster_root
 if aster_root == '/usr':
     prefix = '/'
-confdir = os.path.join(prefix, 'etc', 'codeaster')
+confdir = osp.join(prefix, 'etc', 'codeaster')
+
+# confdir contains plugins directory
+if confdir not in sys.path:
+    sys.path.append(confdir)
 
 # directory containing data files
-datadir = os.path.join(aster_root, 'share', 'codeaster', 'asrun', 'data')
+datadir = osp.join(aster_root, 'share', 'codeaster', 'asrun', 'data')
 
 # directory for internationalization
-localedir = os.path.join(aster_root, 'share', 'locale')
+localedir = osp.join(aster_root, 'share', 'locale')
