@@ -42,7 +42,6 @@ from asrun.batch         import BatchSystemFactory
 from asrun.system        import shell_cmd
 from asrun.common_func   import get_tmpname, flash_filename, edit_file, is_localhost2
 from asrun.common.utils  import YES_VALUES, dhms2s
-from asrun.common.sysutils import local_user
 from asrun.toolbox       import ConvertToHtml
 from asrun.backward_compatibility import bwc_edit_args
 from asrun.plugins.actions import ACTIONS
@@ -154,7 +153,7 @@ def Info(run, *args):
             'interactif_memmax', 'interactif_tpsmax', 'interactif_nbpmax',
             'interactif_mpi_nbpmax',
             )])
-    # and optionnal ones
+    # and optional ones
     for act in ACTIONS.keys():
         p = 'schema_%s' % act
         if run.get(p) is not None and run[p].strip() != '':
@@ -163,7 +162,7 @@ def Info(run, *args):
 
     # Code_Aster versions
     output.append("@VERSIONS@")
-    lvers = [osp.basename(v) for v in run.get('vers', '').split()]
+    lvers = run.get_ordered_versions()
     output.extend(['vers : %s' % v for v in lvers])
     output.append("@FINVERSIONS@")
 
@@ -261,7 +260,7 @@ def Func_actu(run, *args):
     if mode == "batch":
         m = 'b'
         scheduler = BatchSystemFactory(run, prof)
-        etat, diag, node, tcpu, wrk, queue = scheduler.get_jobstate(njob, nomjob)
+        etat, diag, node, tcpu, wrkb, queue = scheduler.get_jobstate(njob, nomjob)
 
     # 1.2. interactive mode
     elif mode == "interactif":
