@@ -32,11 +32,11 @@ if sys.hexversion < 0x020400F0:
     print "This script requires Python 2.4 or higher, sorry !"
     sys.exit(4)
 
-
-# ----- import as_run modules
+from asrun.core         import magic
 from asrun.mystring     import print3
-from asrun.run          import ASTER_RUN
-from asrun.system       import ASTER_SYSTEM
+from asrun.run          import AsterRun
+from asrun.system       import AsterSystem
+from asrun.common.sysutils import local_full_host
 
 
 def start():
@@ -48,10 +48,15 @@ def start():
     sys.argv = change_argv(sys.argv)
 
     # ----- initialisation
-    run = ASTER_RUN()
+    run = AsterRun()
+    magic.run = run
 
     # ----- retrieve options and arguments
     opts, args = run.ParseArgs()
+    # init magic
+    magic.set_stdout(run['stdout'])
+    magic.set_stderr(run['stderr'])
+    magic.init_logger(filename=run['log_progress'], debug=run['debug'])
     run.current_action = opts.action
 
     if run.current_action == None:
@@ -65,8 +70,10 @@ def start():
             #run.parser.error(_(u'you must specify an action'))
 
     # ----- get system commands
-    run.DBG("Command line:", sys.argv)
-    run.system = ASTER_SYSTEM(run)
+    run.DBG("Command line run on '%s'" % local_full_host,
+            "using python executable '%s' :" % sys.executable,
+             sys.argv)
+    run.system = AsterSystem(run)
     run.PostConf()
 
     # ----- debug information
@@ -77,7 +84,10 @@ def start():
 
     # ----- start 'current_action'
     try :
-        meth = run.actions_info[run.current_action]['method']
+        act = run.current_action
+        if run.options['proxy'] is True:
+            act = 'call_proxy'
+        meth = run.actions_info[act]['method']
     except KeyError:
         run.Mess(_(u'dictionnary bad defined :')+' actions_info', '<F>_PROGRAM_ERROR')
     else:
