@@ -40,6 +40,7 @@ from asrun.mystring     import print3, ufmt
 from asrun.core         import RunAsterError, magic
 from asrun.config       import build_config_of_version
 from asrun.build        import AsterBuild
+from asrun.profil       import AsterProfil
 from asrun.system       import local_host
 from asrun.update       import AstkUpdate, read_version_list, download_package
 from asrun.execution    import build_test_export
@@ -48,7 +49,7 @@ from asrun.mpi          import MPI_INFO
 from asrun.toolbox      import GetInfos
 from asrun.common_func  import get_tmpname, get_devel_param, edit_file
 from asrun.dev          import GetMessageInfo, FreeSubroutines
-from asrun.common.utils import get_list, version2tuple, tuple2version, remove_empty_dirs
+from asrun.common.utils import force_list, get_list, version2tuple, tuple2version, remove_empty_dirs
 
 from asrun.backward_compatibility import bwc_getop, bwc_get_version
 
@@ -161,6 +162,11 @@ def SetParser(run):
             'syntax' : '[--output=FILE] host1 [host2 [...]]',
             'help'   : _(u'Return cpu and memory informations about given hosts'),
         },
+        'showme'        : {
+            'method' : ShowMe,
+            'syntax' : '[options] bin|lib',
+            'help'   : _(u'Print informations about installation')
+        },
     }
     opts_descr = {
         'local' : {
@@ -377,7 +383,7 @@ def SetParser(run):
                     'free_sub', 'list', 'diag', 'messages', 'get_infos',
                     'getversion', 'getversion_path',
                     'make', 'update', 'auto_update', 'astk_update',
-                    'ctags',
+                    'ctags', 'showme',
                     # backward compatibility
                     'getop'],
             group_options=True, group_title=title, actions_group_title=False,
@@ -499,6 +505,7 @@ def Get(run, *args, **kwargs):
         RCAPY = os.path.join(REPREF, conf['SRCCAPY'][0])
         RCATA = os.path.join(REPREF, conf['SRCCATA'][0])
         RTEST = os.path.join(REPREF, conf['SRCTEST'][0])
+        RTEST = [osp.join(REPREF, path) for path in conf['SRCTEST']]
         # si 'local' et 'show', pas de copie
         if not get:
             copy = False
@@ -514,6 +521,7 @@ def Get(run, *args, **kwargs):
 
     nberr = 0
     seen = set()
+    export_dest = ''
     while len(l_file) > 0:
         obj = l_file.pop(0)
         silent = False
@@ -529,7 +537,7 @@ def Get(run, *args, **kwargs):
             ext = re.sub('^\.', '', ext)
         if ext == '':
             silent = True
-            l_file.extend([(obj.lower() + '.f90', silent),
+            l_file.extend([(obj.lower() + '.F90', silent),
                            (obj + '.py', silent),
                            (obj + '.c', silent),
                            (obj.lower() + '.comm', silent),
@@ -537,7 +545,7 @@ def Get(run, *args, **kwargs):
                            (obj.lower() + '.cata', silent),
                            ])
             baseobj = baseobj.lower()
-            ext = 'f'
+            ext = 'F90'
             obj = obj.lower() + '.' + ext
         rep = ''
         srep = 0
@@ -551,10 +559,8 @@ def Get(run, *args, **kwargs):
         elif ext == 'F':
             rep = RF90
             srep = 1
-        elif ext in ('f90', 'F'):    # but files are suffixed by '.F' !
-            ext = 'F'
-            obj = re.sub('.f90$', '.F', obj)
-            rep = RF90
+        elif ext == 'F90':
+            rep = RFORT
             srep = 1
         elif ext == 'py':
             rep = RPY
@@ -568,10 +574,11 @@ def Get(run, *args, **kwargs):
             rep = RCATA
             srep = 1
         elif ext in ('comm', 'mail', 'mmed', 'mess', 'resu', 'para', 'code',
-                   'datg', 'msup', 'msh', 'mgib') \
+                   'datg', 'msup', 'msh', 'mgib', 'export') \
             or re.search('com[0-9]', ext) != None or ext.isdigit():
             rep = RTEST
             ct = 1
+        lrep = force_list(rep)
 
         niverr_cp = '<E>_COPY_ERROR'
         if silent:
@@ -580,88 +587,105 @@ def Get(run, *args, **kwargs):
             print3(fmt % (obj, _(u'type unsupported')))
             nberr += 1
         else:
-            if not silent: print3(fmt % (obj, rep))
-            run.DBG("search '%s' from '%s'" % (obj, rep))
-            jret = 0
-            # le fichier existe ou on ne peut pas le vérifier
-            if mach != machdest or srep == 1 or \
-                (mach == machdest and glob.glob(osp.join(rep, obj))):
-                # 1. récupérer le(s) fichier(s)
-                if run['all_test'] and ct == 1:
-                    # cas-test : all
-                    # est-il dans le cache ?
-                    if not run['force'] and \
-                            os.path.isdir(os.path.join(rdest, baseobj)):
-                        if not silent: print3('  |  '+_(u'from cache'))
-                        copy = True
-                    else:
-                        src = os.path.join(rep, baseobj + '.*')
-                        if copy:
-                            if not os.path.isdir(os.path.join(rdest, baseobj)):
-                                os.mkdir(os.path.join(rdest, baseobj))
-                            if mach == machdest:
-                                if not silent: print3('  |  '+_(u'copy all files of the test'))
-                            else:
-                                if not silent: print3('  |  '+_(u'remote copy of the test files'))
-                                src = user+'@'+mach+':'+src
-                            jret = run.Copy(os.path.join(rdest, baseobj), src, niverr=niverr_cp)
-                        else:
-                            toedit = glob.glob(src)
-                            if not silent: print3('  |  '+_(u'just edit'))
-                else:
-                    # fichier individuel
-                    # est-il dans le cache ?
-                    if not run['force'] and \
-                            os.path.isfile(os.path.join(rdest, obj)):
-                        if not silent: print3('  |  '+_(u'from cache'))
-                        copy = True
-                    else:
-                        if srep == 1:
-                            src = os.path.join(rep, '*', obj)
-                        else:
-                            src = os.path.join(rep, obj)
-                        if copy:
-                            if mach == machdest:
-                                if not silent: print3('  |  '+_(u'copy'))
-                            else:
-                                if not silent: print3('  |  '+_(u'remote copy'))
-                                src = user+'@'+mach+':'+src
-                            jret = run.Copy(rdest, src, niverr=niverr_cp)
-                        else:
-                            toedit = glob.glob(src)
-                            if not silent: print3('  |  '+_(u'just edit'))
-
-                # 2. test / edition
-                if jret != 0:
-                    if not silent: print3('  |  '+_(u'error occurs during copying'))
-                    nberr += 1
-                else:
-                    # si show
-                    if not get:
-                        if not copy:
-                            pass
-                        elif run['all_test'] and ct == 1:
+            with_export = False
+            export_file = ''
+            for rep in lrep:
+                if run['all_test'] and not with_export:
+                    with_export = True
+                    obj = baseobj + '.export'
+                    run.options['all_test'] = False
+                    export_dest = rdest = osp.join(rdest, baseobj)
+                    if not osp.isdir(rdest):
+                        os.mkdir(rdest)
+                    export_file = osp.join(rdest, obj)
+                if export_dest:
+                    rdest = export_dest
+                if not silent: print3(fmt % (obj, rep))
+                run.DBG("search '%s' from '%s'" % (obj, rep))
+                jret = 0
+                # le fichier existe ou on ne peut pas le vérifier
+                if mach != machdest or srep == 1 or \
+                    (mach == machdest and glob.glob(osp.join(rep, obj))):
+                    # 1. récupérer le(s) fichier(s)
+                    if run['all_test'] and ct == 1:
                         # cas-test : all
-                            if not silent: print3('  |  '+_(u'edit files'))
-                            toedit = [os.path.join(rdest, baseobj, '*')]
+                        # est-il dans le cache ?
+                        if not run['force'] and \
+                                os.path.isdir(os.path.join(rdest, baseobj)):
+                            if not silent: print3('  |  '+_(u'from cache'))
+                            copy = True
                         else:
+                            src = os.path.join(rep, baseobj + '.*')
+                            if copy:
+                                if not os.path.isdir(os.path.join(rdest, baseobj)):
+                                    os.mkdir(os.path.join(rdest, baseobj))
+                                if mach == machdest:
+                                    if not silent: print3('  |  '+_(u'copy all files of the test'))
+                                else:
+                                    if not silent: print3('  |  '+_(u'remote copy of the test files'))
+                                    src = user+'@'+mach+':'+src
+                                jret = run.Copy(os.path.join(rdest, baseobj), src, niverr=niverr_cp)
+                            else:
+                                toedit = glob.glob(src)
+                                if not silent: print3('  |  '+_(u'just edit'))
+                    else:
                         # fichier individuel
-                            if not silent: print3('  |  '+_(u'edit file'))
-                            toedit = [os.path.join(rdest, obj)]
-                        toedit = set(toedit).difference(seen)
-                        if len(toedit) == 0:
-                            run.DBG("search '%s' from '%s' : not found" % (obj, rep))
-                            if not silent: run.Mess('', '<E>_FILE_NOT_FOUND')
+                        # est-il dans le cache ?
+                        if not run['force'] and \
+                                os.path.isfile(os.path.join(rdest, obj)):
+                            if not silent: print3('  |  '+_(u'from cache'))
+                            copy = True
                         else:
-                            s_edit = ' '.join(toedit)
-                            seen.update(toedit)
-                            edit_file(run, s_edit)
-            else:
-                # fichier inexistant
-                run.DBG("search '%s' from '%s' : not found" % (obj, rep))
-                if not silent:
-                    print3(' |   '+_(u'file not found'))
-                    nberr += 1
+                            if srep == 1:
+                                src = os.path.join(rep, '*', obj)
+                            else:
+                                src = os.path.join(rep, obj)
+                            if copy:
+                                if mach == machdest:
+                                    if not silent: print3('  |  '+_(u'copy'))
+                                else:
+                                    if not silent: print3('  |  '+_(u'remote copy'))
+                                    src = user+'@'+mach+':'+src
+                                jret = run.Copy(rdest, src, niverr=niverr_cp)
+                            else:
+                                toedit = glob.glob(src)
+                                if not silent: print3('  |  '+_(u'just edit'))
+
+                    # 2. test / edition
+                    if jret != 0:
+                        if not silent: print3('  |  '+_(u'error occurs during copying'))
+                        nberr += 1
+                    else:
+                        # si show
+                        if not get:
+                            if not copy:
+                                pass
+                            elif run['all_test'] and ct == 1:
+                            # cas-test : all
+                                if not silent: print3('  |  '+_(u'edit files'))
+                                toedit = [os.path.join(rdest, baseobj, '*')]
+                            else:
+                            # fichier individuel
+                                if not silent: print3('  |  '+_(u'edit file'))
+                                toedit = [os.path.join(rdest, obj)]
+                            toedit = set(toedit).difference(seen)
+                            if len(toedit) == 0:
+                                run.DBG("search '%s' from '%s' : not found" % (obj, rep))
+                                if not silent: run.Mess('', '<E>_FILE_NOT_FOUND')
+                            else:
+                                s_edit = ' '.join(toedit)
+                                seen.update(toedit)
+                                edit_file(run, s_edit)
+                else:
+                    # fichier inexistant
+                    run.DBG("search '%s' from '%s' : not found" % (obj, rep))
+                    if not silent:
+                        print3(' |   '+_(u'file not found'))
+                        nberr += 1
+                if with_export and osp.isfile(export_file):
+                    prof = AsterProfil(export_file)
+                    data = prof.get_data()
+                    l_file.extend([entry.path for entry in data])
 
     if nberr > 0:
         if nberr > 1:
@@ -713,7 +737,7 @@ def GetVersionPath(run, *args, **kargs):
     repref = run.get_version_path(vers)
     print3(repref)
 
-def get_aster_version(vers):
+def get_aster_version(vers, error=True):
     """Return the Code_Aster version named `vers`.
     """
     run = magic.run
@@ -724,13 +748,21 @@ def get_aster_version(vers):
         bibpyt = osp.join(run.get_version_path(vers), 'bibpyt')
     # ----- properties.py
     f = os.path.join(bibpyt, 'Accas', 'properties.py')
+    if conf.use_hg:
+        f = os.path.join(bibpyt, 'Accas', 'pkginfo.py')
     if not os.path.isfile(f):
+        if not error:
+            return None
         run.Mess(ufmt(_(u'file not found : %s'), f), '<F>_FILE_NOT_FOUND')
     mydict = {}
     execfile(f, mydict)
-    result = mydict['version'].split('.')
-    result.append(mydict['date'])
-    result.append(mydict.get('exploit', False))
+    if conf.use_hg:
+        pkg = mydict['pkginfo']
+        result = map(str, pkg[0]) + [pkg[3], pkg[2].startswith('v')]
+    else:
+        result = mydict['version'].split('.')
+        result.append(mydict['date'])
+        result.append(mydict.get('exploit', False))
     return result
 
 # for backward compatibility
@@ -1099,11 +1131,12 @@ def Update(run, *args, **kwargs):
                         lunig.update(val)
                 os.remove(funig)
                 # delete files from maj which have been modified since last update
-                for f in lunig:
-                    lupd.discard(f)
-                    f = os.path.join(repmaj, f)
-                    if os.path.exists(f):
-                        linfo.append(f)
+                for path in lunig:
+                    lf = glob.glob(os.path.join(repmaj, path))
+                    if len(lf) > 0:
+                        for i in lf:
+                            lupd.discard(f)
+                        linfo.extend(lf)
 
             # 1.4. ----- give info about files to delete before update
             if linfo:
@@ -1639,6 +1672,15 @@ def GenCtags(run, force=False):
     os.chdir(prev)
 
 
+def get_export(run, testcase):
+    """Return the AsterProfil object to run a testcase"""
+    REPREF = run.get_version_path(run['aster_vers'])
+    run.PrintExitCode = False
+    ficconf = os.path.join(REPREF, 'config.txt')
+    conf = build_config_of_version(run, run['aster_vers'])
+    prof = build_test_export(run, conf, REPREF, reptest=[], test=testcase)
+    return prof
+
 def GetExport(run, *args):
     """Build an export file to run a testcase and print it to stdout.
     """
@@ -1646,13 +1688,7 @@ def GetExport(run, *args):
     run.check_version_setting()
     if len(args) != 1:
         run.parser.error(_(u"'--%s' requires one argument") % run.current_action)
-
-    REPREF = run.get_version_path(run['aster_vers'])
-    run.PrintExitCode = False
-    ficconf = os.path.join(REPREF, 'config.txt')
-    conf = build_config_of_version(run, run['aster_vers'])
-
-    prof = build_test_export(run, conf, REPREF, reptest=[], test=args[0])
+    prof = get_export(run, args[0])
     print3(prof.get_content())
 
 
@@ -1669,6 +1705,26 @@ def get_vers(fich, debug=False):
             print3(ufmt(_(u'unable to extract version from %s'), fich))
     return vers
 
+def ShowMe(run, *args):
+    """Print information about the installation (as --showme of compilers)"""
+    from asrun.installation import aster_root, confdir, datadir, localedir
+    from asrun.common.utils import get_absolute_dirname
+    run.PrintExitCode = False
+    if len(args) != 1:
+        run.parser.error(_(u"'--%s' requires one argument") % run.current_action)
+    what = args[0]
+    if what == 'bin':
+        print3(aster_root)
+    elif what == 'lib':
+        print3(osp.normpath(osp.join(get_absolute_dirname(__file__), os.pardir)))
+    elif what == 'etc':
+        print3(confdir)
+    elif what == 'data':
+        print3(datadir)
+    elif what == 'locale':
+        print3(localedir)
+    else:
+        pass
 
 def repr_vers(vers, fmt='%d'):
     """Return a representation of `vers` like '8.3.11' or '08.03.11' using `fmt`.
