@@ -146,7 +146,7 @@ class MPI_INFO:
         """
         run = magic.run
         # add source of environments files
-        if env is not None:
+        if env is not None and self.really():
             envstr = [". %s" % f for f in env]
             envstr.append(cmd_in)
             cmd_in = " ; ".join(envstr)
