@@ -60,16 +60,19 @@ class CONNECT:
         self.debug      = kargs.get('debug', False)
         self.autocommit = kargs.get('autocommit', True)
         rcdir           = kargs.get('rcdir', get_home_directory())
+        mydict = kargs.get('db_params')
+        self.connection = None
         
-        fic = os.path.join(rcdir, '.mysql_connect_'+db)
-        if not os.path.exists(fic):
-            raise IOError, _(u'No such file or directory : %s') % fic
+        if mydict is None:
+            fic = os.path.join(rcdir, '.mysql_connect_'+db)
+            if not os.path.exists(fic):
+                raise IOError, _(u'No such file or directory : %s') % fic
 
-        mydict = dict()
-        try:
-            execfile(fic, mydict)
-        except:
-            raise MySQLError, _(u'Can not read connection parameters')
+            mydict = dict()
+            try:
+                execfile(fic, mydict)
+            except:
+                raise MySQLError, _(u'Can not read connection parameters')
         try:
             self.connection = MySQLdb.connect(host=mydict['host'], user=mydict['user'],
                     passwd=mydict['passwd'], db=mydict['db'])
@@ -86,7 +89,8 @@ class CONNECT:
     def __del__(self):
         """Close the connection on deletion.
         """
-        self.connection.close()
+        if self.connection is not None:
+            self.connection.close()
 
     def exe(self, query):
         """Execute the SQL 'query' using the active connection.
