@@ -130,6 +130,8 @@ def maximize_lines(l_fields, maxlen, sep):
     Les champs sont assemblés avec le séparateur `sep`.
     """
     newlines = []
+    if len(l_fields) == 0:
+        return newlines
     # ceinture
     assert max([len(f) for f in l_fields]) <= maxlen, 'lignes trop longues : %s' % l_fields
     while len(l_fields) > 0:
@@ -143,7 +145,7 @@ def maximize_lines(l_fields, maxlen, sep):
     return newlines
 
 def force_split(txt, maxlen):
-    """Force le découpage de la ligne à 'maxlen' caractèees.
+    """Force le découpage de la ligne à 'maxlen' caractères.
     """
     l_res = []
     while len(txt) > maxlen:
