@@ -38,7 +38,7 @@ The number of available seeds after n cycles = (leech_limit + 1)^n
 Example : For copying a directory on 100 nodes if a unique copy
           takes 10 s, the copy will be completed after 70 s or 50 s
           (leech_limit=1 or 2).
-  #cycle  leech_limit=1  leech_limit=2   
+  #cycle  leech_limit=1  leech_limit=2
      1            2             3
      2            4             9
      3            8            27
@@ -76,14 +76,14 @@ class PARALLEL_COPY:
     - get from 'tracker' an available 'repository'.
     - copy repository:/dirsrc into /dest
     - when done, adds 'leech:/dest' in the repositories list in '/dirsrc/repositories'
-    
+
     number of available source after n cycles = (p + 1)^n
     with p = number of connections to a source
     """
-    max_attempt_src  = 100     # number of attempts to get a source
-    interval_src     = 0.5     # delay between two attempts
+    max_attempt_src  = 300     # number of attempts to get a source
+    interval_src     = 1.0     # delay between two attempts
     max_attempt_lock = 100     # number of attempts to lock repositories list
-    interval_lock    = 0.2     # delay between two attempts
+    interval_lock    = 0.5     # delay between two attempts
 
 
     def __init__(self, tracker, master, dest, leech_limit, verbose=False, run=None):
@@ -103,7 +103,7 @@ class PARALLEL_COPY:
         assert self.leech_limit < 5, \
             "It seems dangerous and inefficient to have too much leechs per seed."
         self.verbose = verbose
-        # use functions from ASTER_RUN object
+        # use functions from AsterRun object
         self.run = run
 
 
@@ -243,7 +243,7 @@ class PARALLEL_COPY:
                 % (self.dest, now(datefmt="")))
         # get a source
         src = self.get_repository()
-        
+
         # copy
         if src == self.dest or src == self.leech:
             print3(_(u'source and destination are identical'))
@@ -258,12 +258,12 @@ class PARALLEL_COPY:
         if not os.path.exists(self.dest):
             os.makedirs(self.dest)
         iret = self.copy('%s/*' % src, self.dest)
-        
+
         # remove repositories file in dest
         dest_repo = os.path.join(self.dest, os.path.basename(self.repo_filename()))
         if os.path.exists(dest_repo):
             os.remove(dest_repo)
-        
+
         l_repo = [src,]
         l_repo.extend([self.leech,] * self.leech_limit)
         self.update_repository(l_repo)
@@ -301,18 +301,18 @@ def main():
     parser.add_option('--long_help', dest='long_help',
             action='store_true', default=False,
             help='print complete help (with example) and exit')
-    
+
     opts, l_args = parser.parse_args()
-    
+
     if opts.long_help:
         parser.usage += __sup_doc__
         parser.print_help()
         parser.exit(1)
-    
+
     if opts.with_as_run:
-        from asrun.system import ASTER_SYSTEM_MINIMAL
-        run = ASTER_SYSTEM_MINIMAL(remote_copy_protocol=opts.remote_copy_protocol,
-                                            remote_shell_protocol=opts.remote_shell_protocol)   
+        from asrun.system import AsterSystemMinimal
+        run = AsterSystemMinimal(remote_copy_protocol=opts.remote_copy_protocol,
+                                            remote_shell_protocol=opts.remote_shell_protocol)
     else:
         run = None
 
