@@ -164,6 +164,8 @@ def Parametric(run, prof, mpi_info, numthread='auto', **kargs):
     txt_summary.append('')
     text_summary = os.linesep.join(txt_summary)
     print3(text_summary)
+    if nbval < 1:
+        run.Mess(_(u"There is no value for the parameters."), '<F>_ERROR')
 
     # change directory before running sub-execution (reptrav will be deleted !)
     os.chdir(run['rep_trav'])
@@ -231,10 +233,10 @@ def Parametric(run, prof, mpi_info, numthread='auto', **kargs):
 def get_distribution_data(txt):
     """Return a dict of the distribution datas :
         (required)  VALE : list of dicts of the parameters values
-        (optionnal) PRE_CALCUL (resp. UNITE_PRE_CALCUL) : list of commands to insert
+        (optional) PRE_CALCUL (resp. UNITE_PRE_CALCUL) : list of commands to insert
             just after the DEBUT/POURSUITE command (respectively an integer defining
             the logical unit provided to INCLUDE)
-        (optionnal) POST_CALCUL (resp. UNITE_POST_CALCUL) : list of commands to
+        (optional) POST_CALCUL (resp. UNITE_POST_CALCUL) : list of commands to
             insert just before the FIN command (respectively an integer defining the
             logical unit provided to INCLUDE)
     """
