@@ -28,7 +28,7 @@ But it's recommended to place them in etc/codeaster/plugins because
 the modules added in this directory will be kept during updates of asrun.
 """
 
-
+import os
 import os.path as osp
 
 from asrun.common.i18n  import _
@@ -96,6 +96,9 @@ def serv(prof, args, print_output=True, **kwargs):
     btc = parse_consbtc(output)
     if btc is not None and print_output:
         print3("BTCFILE=%s" % btc)
+    if iret != 0:
+        output += os.linesep.join([output,
+            "******************** ERROR of as_run --serv ********************", err])
     return iret, output
 
 
@@ -127,7 +130,8 @@ def get_results(prof, args, **kwargs):
         local_resu = oprof.get_result().get_on_serv(local_full_host)
         local_nom, local_other = local_resu.get_type('nom', with_completion=True)
         iret = scopy.copyfrom(convert=unique_basename, *local_other.topath())
-        iret = scopy.copyfrom(*local_nom.topath())
+        jret = scopy.copyfrom(*local_nom.topath())
+        iret = max(iret, jret)
         local_resu = local_resu.topath()
     else:
         local_resu = []
@@ -158,7 +162,7 @@ def get_study_export(prof):
     mode = prof['mode'][0]
     # flasheur is in the home directory
     dirname, fname = osp.split(flash_filename("flasheur", jobname, jobid, "export", mode))
-    run.DBG("export file is in %s named %s" % (dirname, fname))
+    run.DBG("export file in %s is named %s" % (dirname, fname))
 
     # copy export file locally
     serv.set_proxy_dir(dirname)
@@ -195,6 +199,9 @@ def call_generic_service(action, serv, prof, args, options={}):
             #"******************** ERROR of as_run --%s ********************" % action, err,
             "******************** END of as_run --%s ********************" % action,
             all=True, prefix="    ")
+    if iret != 0:
+        output += os.linesep.join([output,
+            "******************** ERROR of as_run --%s ********************" % action, err])
     return iret, output, err
 
 
