@@ -39,6 +39,12 @@ from asrun.backward_compatibility import bwc_deprecate_class
 
 MODES = Enum("INTERACTIF", "BATCH")
 
+def _dbg(*args, **kwargs):
+    """Wrapper to run.DBG"""
+    if magic.run is None:
+        return
+    magic.run.DBG(*args, **kwargs)
+
 
 class ExportEntry(FileName):
     """A FileName additionnal attributes."""
@@ -88,7 +94,7 @@ class ExportEntry(FileName):
                     basn = _defconv(self.path)
                 else:
                     basn = convert(self.path)
-                magic.run.DBG(ufmt("relocate %s to %s", self._path, osp.join(newdir, basn)),
+                _dbg(ufmt("relocate %s to %s", self._path, osp.join(newdir, basn)),
                     stack_id=2)
                 self.set_pathname(osp.join(newdir, basn))
 
@@ -123,7 +129,7 @@ class ExportEntry(FileName):
 
     def get_path_text(self):
         """Return the path as it is saved."""
-        return self._path
+        return self._path or ''
 
     def __get_path(self):
         """private get method"""
@@ -159,7 +165,7 @@ class EntryCollection(object):
                 break
         return ind
 
-    def add(self, entry):
+    def add(self, entry, stacklevel=2):
         """Add an entry into the collection."""
         index = self.index(entry)
         if index < 0:
@@ -174,7 +180,7 @@ class EntryCollection(object):
                     warn(ufmt(u"entry '%s' already exists and " \
                          "attribute '%s' differs from existing (previous '%s', new '%s').",
                          entry.path, attr, getattr(existing, attr), getattr(entry, attr)),
-                         RuntimeWarning, stacklevel=2)
+                         RuntimeWarning, stacklevel=stacklevel)
 
     def remove(self, entry):
         """Remove an entry from the collection."""
@@ -322,6 +328,10 @@ class AsterProfil:
         else:
             return [""]
 
+    def has_param(self, key):
+        """Tell if `key` is a known parameter"""
+        return self.param.has_key(key)
+
     def get_version_path(self):
         """Return the path of the version used.
         """
@@ -445,7 +455,8 @@ class AsterProfil:
                 if len(spl) > 0:
                     typ = spl[0]
                     if typ not in ('A', 'P', 'F', 'R', 'N'):
-                        self._mess(_(u'unexpected type : %s') % typ, '<A>_ALARM')
+                        self._mess(_(u'unexpected type : %s (filename: %s)') \
+                            % (typ, self._filename), '<A>_ALARM')
                 else:
                     continue
                 if len(spl) >= 3:
@@ -483,6 +494,7 @@ class AsterProfil:
                     if typ == 'A':
                         self.args[spl[1]] = ''
         self._for_new_files()
+
         self.update_content()
 
     def copy(self):
@@ -661,7 +673,7 @@ class AsterProfil:
             self.set_param_memory(self.run['interactif_memmax'])
         else:
             self.set_param_time(3600*24)
-            self.set_param_memory(2048)
+            self.set_param_memory(2000)  # < 2 GB for 32 bits platforms
 
         # add default values
         self['actions'] = "make_etude"
@@ -676,8 +688,13 @@ class AsterProfil:
 
     def set_param_time(self, tsec):
         """Set time parameter in seconds."""
+        tsec = float(tsec)
+        self['time_limit'] = tsec
         self['tpsjob'] = max(int(1.0 * tsec / 60), 1)
         self.args['tpmax'] = tsec
+        _dbg('P time_limit: %s    P tpsjob: %s    A tpmax: %s' \
+                      % (self['time_limit'][0], self['tpsjob'][0],
+                         self.args['tpmax']))
 
     def set_param_memory(self, memory):
         """Set memory parameter in MB."""
@@ -685,9 +702,21 @@ class AsterProfil:
             facW = 8
         else:
             facW = 4
+        memory = float(memory)
+        self['memory_limit'] = memory
         self['memjob'] = int(memory * 1024)
         ratio = (float(self['mem_aster'][0] or 100.)) / 100.
         self.args['memjeveux'] = 1.0 * memory / facW * ratio
+        _dbg('P memory_limit: %s    P memjob: %s    A memjeveux: %s' \
+                      % (self['memory_limit'][0], self['memjob'][0],
+                         self.args['memjeveux']))
+
+    def set_param_limits(self):
+        """Set memory and time limits"""
+        if self.has_param('memory_limit'):
+            self.set_param_memory(self['memory_limit'][0])
+        if self.has_param('time_limit'):
+            self.set_param_time(self['time_limit'][0])
 
     def from_remote_server(self, ignore_types=None):
         """Change local pathnames to be visible from a remote server.
@@ -764,9 +793,11 @@ class AsterProfil:
         Must be called by any function modifying .data/.resu attrs."""
         self.collection = EntryCollection()
         for dico in self.data:
-            self.collection.add(ExportEntry(dico['path'], data=True, **dico))
+            self.collection.add(ExportEntry(dico['path'], data=True, **dico),
+                                stacklevel=3)
         for dico in self.resu:
-            self.collection.add(ExportEntry(dico['path'], result=True, **dico))
+            self.collection.add(ExportEntry(dico['path'], result=True, **dico),
+                                stacklevel=3)
 
     def _compatibility(self):
         """Fill .data/.resu from .collection.
