@@ -25,7 +25,7 @@ import os
 from asrun.installation import datadir
 from asrun.common.i18n  import _
 from asrun.mystring     import ufmt
-from asrun.config       import AsterConfig
+from asrun.config       import build_config_from_export
 from asrun.common_func  import get_tmpname
 from asrun.common.utils import YES, YES_VALUES, get_plugin
 
@@ -190,23 +190,11 @@ class ProfileModifierExecTool(ProfileModifier):
             d_exe = self.prof_orig.Get('D', typ='exec')[0]
         else:
             d_exe = { 'path' : '?', 'type' : 'exec', 'isrep' : False, 'compr' : False, 'ul' : 0 }
-            REPREF = self.prof_orig.get_version_path()
-            lconf = self.prof_orig.Get('D', typ='conf')
-            if not lconf:
-                ficconf = os.path.join(REPREF, 'config.txt')
-            else:
-                ficconf = lconf[0]['path']
-                if self.run.IsRemote(ficconf):
-                    ficconf = get_tmpname(self.run, self.run['tmp_user'], basename='config.txt')
-                    self.run.ToDelete(ficconf)
-                    ibid = self.run.Copy(ficconf, lconf[0]['path'])
-                else:
-                    ficconf = self.run.PathOnly(ficconf)
-            conf = AsterConfig(ficconf, self.run)
+            conf = build_config_from_export(self.run, self.prof_orig)
             if dbg == 'nodebug':
-                d_exe['path'] = os.path.join(REPREF, conf['BIN_NODBG'][0])
+                d_exe['path'] = conf.get_with_absolute_path('BIN_NODBG')[0]
             else:
-                d_exe['path'] = os.path.join(REPREF, conf['BIN_DBG'][0])
+                d_exe['path'] = conf.get_with_absolute_path('BIN_DBG')[0]
         # add valgrind command
         if self.prof_orig['exectool'][0] == '':
             self.run.Mess(_(u'"exectool" is not defined !'), '<F>_PROGRAM_ERROR')
