@@ -23,7 +23,7 @@
 
 import sys
 import os
-    
+
 
 class Progress:
     """This class allows to easily follow the progress of a task.
@@ -39,7 +39,7 @@ class Progress:
         self.form  = kargs.get('format', '%3d%%')
         self.file  = sys.stdout
         self.time  = kargs.get('time', True)
-        
+
         self._write(self.msg)
         self._write(self.form % 0, update=True)
         # man 2 times
@@ -66,7 +66,7 @@ class Progress:
         percent = 100.*self.value/self.maxi
         s = self.form % percent
         self._write(len(self.msg+s)*chr(8) + self.msg + s, update=True)
-        
+
 
     def End(self, string='100%\n'):
         """Write the end message.
@@ -78,8 +78,12 @@ class Progress:
         st = ''
         if self.time:
             st = ' (%.2f s user, %.2f s total)' % (self.utime, self.elapsed)
+        val = 100
+        if type(string) in (int, long):
+            val = string
+            string = "100%\n"
         if string[:4] == '100%':
-            string = (self.form % 100) + string[4:]
+            string = (self.form % val) + string[4:]
         if string[-1] == '\n':
             string = string[:-1] + st + string[-1]
         s = self.form % 0
