@@ -56,7 +56,7 @@ def in_adm_group(run):
     """
     if on_linux():
         import grp
-        is_adm = grp.getgrgid(os.getgid())[0] == run.get('agla_adm_group')
+        is_adm = grp.getgrgid(os.getgid())[0] in (run.get('agla_adm_group'), )
     else:
         is_adm = False
     return is_adm
@@ -324,12 +324,173 @@ def Histor(run, *args):
     except Exception, msg:
         run.Mess(msg, '<F>_DB_ERROR')
 
+    histor = build_histor(run, l_nf, c)
+
+    # 5. copy histor file
+    ffich = get_tmpname(run, run['tmp_user'], basename='hist_output')
+    open(ffich, 'w').write(repr(histor))
+    kret = run.Copy(args[1], ffich, niverr='<F>_COPYFILE')
+    run.Mess(_(u"Histor successfully generated."), 'OK')
+
+
+def Solder(run, *args):
+    """Fill corrVdev/corrVexpl fields and close issues found in a histor file.
+    """
+    if not run.get('aster_vers'):
+        run.parser.error(_(u"You must define 'default_vers' in 'aster' configuration file or use '--vers' option."))
+    if len(args) != 1:
+        run.parser.error(_(u"'--%s' requires one argument") % run.current_action)
+
+    on_machref = run.get('rep_agla', 'local') != 'local'
+    if not on_machref:
+        run.Mess(_(u'Only available on the AGLA machine'), '<F>_AGLA_ERROR')
+    try:
+        is_adm = in_adm_group(run)
+        if not is_adm:
+            raise KeyError
+    except KeyError, msg:
+        run.Mess(_(u'insufficient privileges to close issues !'), '<F>_AGLA_ERROR')
+
+    # 0. check imports
+    if not imports_succeed:
+        run.Mess(_(u'Imports of REX interface failed.'), '<F>_IMPORT_ERROR')
+
+    # 1. read histor file
+    jn = run['num_job']
+    ffich = get_tmpname(run, run['tmp_user'], basename='hist_input')
+    kret = run.Copy(ffich, args[0], niverr='<F>_COPYFILE')
+
+    hist_content = open(ffich, 'r').read()
+    expr = re.compile('RESTITUTION FICHE +([0-9]+)', re.MULTILINE)
+    l_nf = [int(n) for n in expr.findall(hist_content)]
+    if len(l_nf) == 0:
+        run.Mess(_(u'Incorrect file, no issue to close.'), '<F>_AGLA_ERROR')
+
+    # 2. get version number and database fields to fill
+    expl = False
+    # also accept a version number (ex. '2011.1') instead of 'NEW10'
+    if run['aster_vers'].replace('.', '').isdigit():
+        tagv = run['aster_vers']
+        run.Mess(ufmt(_(u'Close issues with version tag : %s'), tagv))
+    else:
+        run.Mess(_(u'Close issues in :'))
+        iret, l_res = GetVersion(run, silent=False, vers=run['aster_vers'])
+        tagv = '.'.join(l_res[:3])
+        expl = l_res[4]
+
+    # 3. open database connection
+    try:
+        c = db.CONNECT('REX', rcdir=confdir, verbose=run['debug'])
+    except Exception, msg:
+        run.Mess(msg, '<F>_DB_ERROR')
+
+    etat = _read_table(run, c, STATUS)
+    # 4. read issues from database
+    mark_as_closed(run, l_nf, c, tagv, expl)
+
+    # 5. delete files of *all* closed issues
+    # list of closed issues
+    query = """SELECT id from _issue WHERE _status=%s;""" % etat['ferme']['id']
+    try:
+        res = c.exe(query)
+    except db.MySQLError, msg:
+        run.Mess(ufmt(_("error executing a query to the database\n %s"), query), '<F>_DB_ERROR')
+    l_ferm = set([i[0] for i in res])
+    # list of existing directories
+    l_dirs = set([int(d) for d in os.listdir(osp.join(run['rep_rex'], "emise")) \
+                if osp.isdir(osp.join(run['rep_rex'], "emise", d)) and d.isdigit()])
+    to_del = l_dirs.intersection(l_ferm)
+    dir_to_del = ["%06d" % num for num in to_del]
+    for d in dir_to_del:
+        run.Delete(osp.join(run['rep_rex'], "emise", d))
+        run.Mess(_(u"files of issue %s have been deleted.") % d)
+
+def _read_table(run, cnx, typ):
+    """return status and product tables"""
+    try:
+        tab = ReadDB(typ, cnx)
+    except ReadDBError:
+        run.Mess(_(u'Unable to read the table'), '<F>_DB_ERROR')
+    return tab
+
+def mark_as_closed(run, l_nf, cnx, tagv, expl):
+    """Mark a list of issues as closed
+    l_nf: list of issues numbers
+    cnx: connection object to database
+    tagv: tag inserted in issues
+    expl: True if it concerns a stable version (exploitation)"""
+    etat = _read_table(run, cnx, STATUS)
+    prod = _read_table(run, cnx, PRODUIT)
+    typv = 'dev'
+    autr = 'expl'
+    if expl:
+        typv = 'expl'
+        autr = 'dev'
+    d_champ = {
+        'a_corrige' : '_corrV' + typv,
+        'v_correct' : '_verCorrV' + typv,
+        'a_tester'  : '_corrV' + autr,
+        'v_tester'  : '_verCorrV' + autr,
+    }
+    req_status = 'valide_EDA'
+    for numf in l_nf:
+        # 4.1. read the issue
+        try:
+            issue = ISSUE(numf, cnx)
+        except ReadDBError:
+            run.Mess(_(u'Unable to read issue %s') % numf, '<E>_UNKNOWN_ISSUE')
+            continue
+
+        # 4.2. check issue values
+        status = issue['_status'].GetPrimValue()
+        if status != req_status:
+            run.Mess(_(u"Status of issue %s is not '%s' (%s)") \
+                    % (numf, req_status, status), '<A>_UNEXPECTED_VALUE')
+            issue['_status'] = etat[req_status]
+
+        if issue['_produit'].GetPrimValue() == 'Code_Aster':
+            if not issue[d_champ['a_corrige']] \
+                and issue['_type'].GetPrimValue() != 'aide utilisation':
+                issue[d_champ['a_corrige']] = YES
+                run.Mess(_(u"issue %s should not been solved in version %s") \
+                        % (numf, typv), '<A>_UNEXPECTED_VALUE')
+        else:
+            issue[d_champ['a_corrige']] = NO
+            issue[d_champ['a_tester']] = NO
+
+        # 4.3. fill issue fields
+        issue[d_champ['v_correct']] = tagv
+
+        # 4.4. close issue ?
+        if not issue[d_champ['a_tester']] or not issue[d_champ['v_tester']] in ('', None):
+            new_status = etat['attente_doc']
+            if not issue['_impactDoc']:
+                new_status = etat['ferme']
+            issue['_status'] = new_status
+            run.Mess(_(u'issue %s is closed') % numf)
+        else:
+            run.Mess(_(u'issue %s must be solved in V%s too') % (numf, autr))
+
+        # 4.5. write issue in database
+        try:
+            if not run['debug']:
+                issue.write(force=True)
+            else:
+                issue.repr()
+        except WriteDBError, msg:
+            run.Mess(_(u'error occurs during writing issue'), '<F>_DB_ERROR')
+
+
+def build_histor(run, l_nf, cnx):
+    """Build an Histor instance from a list of issues
+    l_nf: list of issues numbers
+    cnx: connection object to database"""
     # 4. read issues from database
     prec_user = None
     histor = InitHistor(format=run['format'], url=run['rex_url'])
     for numf in l_nf:
         # 4.1. read the issue
-        issue = ISSUE({'id' : numf}, c)
+        issue = ISSUE({'id' : numf}, cnx)
         try:
             issue.read()
         except ReadDBError:
@@ -393,147 +554,5 @@ def Histor(run, *args):
         # 4.3.4. last issue
         if numf == l_nf[-1] and prec_user != None:
             histor.EndUser(prec_user)
-
-    # 5. copy histor file
-    ffich = get_tmpname(run, run['tmp_user'], basename='hist_output')
-    open(ffich, 'w').write(repr(histor))
-    kret = run.Copy(args[1], ffich, niverr='<F>_COPYFILE')
-    run.Mess(_(u"Histor successfully generated."), 'OK')
-
-
-def Solder(run, *args):
-    """Fill corrVdev/corrVexpl fields and close issues found in a histor file.
-    """
-    if not run.get('aster_vers'):
-        run.parser.error(_(u"You must define 'default_vers' in 'aster' configuration file or use '--vers' option."))
-    if len(args) != 1:
-        run.parser.error(_(u"'--%s' requires one argument") % run.current_action)
-
-    on_machref = run.get('rep_agla', 'local') != 'local'
-    if not on_machref:
-        run.Mess(_(u'Only available on the AGLA machine'), '<F>_AGLA_ERROR')
-    try:
-        is_adm = in_adm_group(run)
-        if not is_adm:
-            raise KeyError
-    except KeyError, msg:
-        run.Mess(_(u'insufficient privileges to close issues !'), '<F>_AGLA_ERROR')
-
-    # 0. check imports
-    if not imports_succeed:
-        run.Mess(_(u'Imports of REX interface failed.'), '<F>_IMPORT_ERROR')
-
-    # 1. read histor file
-    jn = run['num_job']
-    ffich = get_tmpname(run, run['tmp_user'], basename='hist_input')
-    kret = run.Copy(ffich, args[0], niverr='<F>_COPYFILE')
-
-    hist_content = open(ffich, 'r').read()
-    expr = re.compile('RESTITUTION FICHE +([0-9]+)', re.MULTILINE)
-    l_nf = [int(n) for n in expr.findall(hist_content)]
-    if len(l_nf) == 0:
-        run.Mess(_(u'Incorrect file, no issue to close.'), '<F>_AGLA_ERROR')
-
-    # 2. get version number and database fields to fill
-    typv = 'dev'
-    autr = 'expl'
-    # also accept a version number (ex. '2011.1') instead of 'NEW10'
-    if run['aster_vers'].replace('.', '').isdigit():
-        tagv = run['aster_vers']
-        run.Mess(ufmt(_(u'Close issues with version tag : %s'), tagv))
-    else:
-        run.Mess(_(u'Close issues in :'))
-        iret, l_res = GetVersion(run, silent=False, vers=run['aster_vers'])
-        tagv = '.'.join(l_res[:3])
-        if l_res[4]:
-            typv = 'expl'
-            autr = 'dev'
-    d_champ = {
-        'a_corrige' : '_corrV' + typv,
-        'v_correct' : '_verCorrV' + typv,
-        'a_tester'  : '_corrV' + autr,
-        'v_tester'  : '_verCorrV' + autr,
-    }
-
-    # 3. open database connection
-    try:
-        c = db.CONNECT('REX', rcdir=confdir, verbose=run['debug'])
-    except Exception, msg:
-        run.Mess(msg, '<F>_DB_ERROR')
-
-    try:
-        etat = ReadDB(STATUS, c)
-        prod = ReadDB(PRODUIT, c)
-    except ReadDBError:
-        run.Mess(_(u'Unable to read status and product'), '<F>_DB_ERROR')
-
-    # 4. read issues from database
-    req_status = 'valide_EDA'
-    for numf in l_nf:
-        # 4.1. read the issue
-        try:
-            issue = ISSUE(numf, c)
-        except ReadDBError:
-            run.Mess(_(u'Unable to read issue %s') % numf, '<E>_UNKNOWN_ISSUE')
-            continue
-
-        # 4.2. check issue values
-        status = issue['_status'].GetPrimValue()
-        if status != req_status:
-            run.Mess(_(u"Status of issue %s is not '%s' (%s)") \
-                    % (numf, req_status, status), '<A>_UNEXPECTED_VALUE')
-            issue['_status'] = etat[req_status]
-
-        if issue['_produit'].GetPrimValue() == 'Code_Aster':
-            if not issue[d_champ['a_corrige']] \
-                and issue['_type'].GetPrimValue() != 'aide utilisation':
-                issue[d_champ['a_corrige']] = YES
-                run.Mess(_(u"issue %s should not been solved in version %s") \
-                        % (numf, typv), '<A>_UNEXPECTED_VALUE')
-        else:
-            issue[d_champ['a_corrige']] = NO
-            issue[d_champ['a_tester']] = NO
-
-        # 4.3. fill issue fields
-        issue[d_champ['v_correct']] = tagv
-
-        # 4.4. close issue ?
-        if not issue[d_champ['a_tester']] or not issue[d_champ['v_tester']] in ('', None):
-            new_status = etat['attente_doc']
-            if not issue['_impactDoc']:
-                new_status = etat['ferme']
-            issue['_status'] = new_status
-            run.Mess(_(u'issue %s is closed') % numf)
-        else:
-            run.Mess(_(u'issue %s must be solved in V%s too') % (numf, autr))
-
-        # 4.5. write issue in database
-        try:
-            if not run['debug']:
-                issue.write(force=True)
-            else:
-                issue.repr()
-        except WriteDBError, msg:
-            run.Mess(_(u'error occurs during writing issue'), '<F>_DB_ERROR')
-
-    # 5. delete files of *all* closed issues
-    # list of closed issues
-    query = """SELECT id from _issue WHERE _status=%s;""" % etat['ferme']['id']
-    try:
-        res = c.exe(query)
-    except db.MySQLError, msg:
-        run.Mess(ufmt(_("error executing a query to the database\n %s"), query), '<F>_DB_ERROR')
-    l_ferm = set([i[0] for i in res])
-    # list of existing directories
-    l_dirs = set([int(d) for d in os.listdir(osp.join(run['rep_rex'], "emise")) \
-                if osp.isdir(osp.join(run['rep_rex'], "emise", d)) and d.isdigit()])
-    to_del = l_dirs.intersection(l_ferm)
-    dir_to_del = ["%06d" % num for num in to_del]
-    for d in dir_to_del:
-        run.Delete(osp.join(run['rep_rex'], "emise", d))
-        run.Mess(_(u"files of issue %s have been deleted.") % d)
-
-
-
-
+    return histor
 
