@@ -29,14 +29,14 @@ import re
 
 from asrun.myconnect    import MySQLError
 from asrun.common.i18n import _
-from asrun.mystring     import print3, convert
+from asrun.mystring     import print3, convert, to_unicode
 from asrun.common.utils import sha1
 
 
 __verbose__ = False
 __all__ = ['ITEM', 'ReadDB', 'USER', 'INTERVENANT', 'MSG', 'PRODUIT', 'VERSION',
            'PROJET', 'STATUS', 'TYPE', 'ISSUE',
-           'PRODUIT_VERSION', 'ISSUE_MESSAGES', 'YES', 'NO',
+           'PRODUIT_VERSION', 'ISSUE_MESSAGES', 'ISSUE_NOSY', 'YES', 'NO',
            'ReadDBError', 'WriteDBError', 'ConnectDBError']
 
 mysql_date_fmt = '%Y-%m-%d %H:%M:%S'
@@ -99,7 +99,7 @@ class ITEM:
         inDB     : True si on a vérifié que l'enregistrement est dans la base
         lu       : True si on a déjà lu l'enregistrement dans la base
         cols     : (cache) ordre des colonnes dans la table (pour SELECT * par ex)
-        
+
         link_class : table où sont stockés les "multi-link"
         parent_class : la classe "parent"
 
@@ -205,8 +205,10 @@ class ITEM:
                 else:
                     txt.append(fmt_vr % (k, v))
             else:
+                if type(v) == str:
+                    v = to_unicode(v)
                 txt.append(fmt_val % (k, v))
-        return os.linesep.join(txt)
+        return convert(os.linesep.join(txt))
 
     def __repr__(self):
         """Affichage
@@ -239,7 +241,7 @@ class ITEM:
         else:
             value = self.get(self.primkeys[0], None)
         return value
-    
+
     def isinDB(self, dcrit=None):
         """Retourne True si l'enregistrement est présent dans la base.
         """
@@ -426,7 +428,7 @@ class ITEM:
                                                         {'name' : re.sub('^[_]+', '', self.table)})
             except MySQLError:
                 raise WriteDBError, _(u'error occurs during writing in database')
-    
+
     def __cachecols(self):
         """Remplit .cols, devrait être appelé par toute méthode l'utilisant.
         """
@@ -480,7 +482,7 @@ class ITEM:
         parent = pclass({pclass.idkey : numf}, self.c)
         parent.read()
         return parent
-        
+
     def AsDict(self):
         """Retourne un dictionnaire avec toutes les valeurs, valeurs du champ
         "primaire" pour les sous-items.
@@ -492,7 +494,7 @@ class ITEM:
                 if mat != None:
                     v = mat.group(1)
             return v
-        
+
         dico = {}
         for k, v in self.values.items():
             if k.startswith('__'):
@@ -757,3 +759,25 @@ class ISSUE_MESSAGES(ITEM):
     primkeys = ['linkid', ]
     idkey = 'linkid'
 
+class ISSUE_NOSY(ITEM):
+    """Enregistrement de la table issue_nosy
+    """
+    table = 'issue_nosy'
+    default = {
+        'linkid'          : None,
+        'nodeid'          : None,
+    }
+    refs = {'linkid':'USER', 'nodeid':'ISSUE'}
+    primkeys = []
+    idkey = 'linkid'
+
+    def write(self, force=False, force_recursive=False):
+        """Ecrit l'enregistrement dans la base.
+        force, force_recursive sans effet car pas de clé primaire.
+        """
+        if self.c == None:
+            raise ConnectDBError, _(u'no database connection')
+        try:
+            self.c.insert(self.table, self.values)
+        except MySQLError:
+            raise WriteDBError, _(u'error occurs during writing in database')
