@@ -36,6 +36,7 @@ from asrun.common.sysutils import (
     FileName,
     on_linux,
     on_windows,
+    on_64bits,
     local_user,
     local_full_host,
     local_host,
@@ -368,7 +369,7 @@ class AsterSystem:
         Remote names format :
             [[user[:passwd]@]machine:]name
         where name is an absolute or a relative path.
-        optionnal arguments : verbose, follow_output passed to local_shell,
+        optional arguments : verbose, follow_output passed to local_shell,
             niverr : default is set to <F>_COPY_ERROR, but may be '<A>' or less !
             protocol : to use a different protocol just for this copy.
         Note : if src[i] is a directory and dest doesn't exist
@@ -493,7 +494,7 @@ class AsterSystem:
         """
         #TODO use list type
         if type(cmd) in (list, tuple):
-            cmd = ' '.join(cmd)
+            cmd = ' '.join(map(convert, cmd))
         iret = 1
         # valeurs par défaut
         kargs = {
@@ -521,8 +522,8 @@ class AsterSystem:
             action = ''
             # pour recuperer correctement l'output, il faut des " et non des ' autour des
             # commandes sous "sh -c" et sous "xterm -e"
-            if cmd.find('"') != -1:
-                cmd = cmd.replace('"', '\\"')
+            cmd = cmd.replace('"', '\\"')
+            cmd = cmd.replace('$', '\\$')
             cmd = '"%s"' % cmd
             if proto == 'RSH':
                 action = 'rsh -n -l '+user+' '+mach+' '+cmd
@@ -545,7 +546,7 @@ class AsterSystem:
 
     def Gzip(self, src, **opts):
         """Compress file or content of directory 'src'.
-        optionnal arguments : verbose, niverr, cmd (to override gzip command).
+        optional arguments : verbose, niverr, cmd (to override gzip command).
         Only local files/directories supported !
         """
         return self._gzip_gunzip('gzip', src, **opts)
@@ -553,7 +554,7 @@ class AsterSystem:
 
     def Gunzip(self, src, **opts):
         """Decompress file or content of directory 'src'.
-        optionnal arguments : verbose, niverr, cmd (to override gzip -d command).
+        optional arguments : verbose, niverr, cmd (to override gzip -d command).
         Only local files/directories supported !
         """
         return self._gzip_gunzip('gunzip', src, **opts)
@@ -867,6 +868,8 @@ class AsterSystem:
                 mat = re.search('^%s *: *([0-9]+) *kb' % what, out, re.MULTILINE | re.IGNORECASE)
                 if mat != None:         # else: it should not !
                     num = int(mat.group(1))/1024
+                    if not on_64bits():
+                        num = min(num, 2047)
             self._meminfo_cache[what+mach+user] = num
             self._dbg("GetMemInfo '%s' returns : %s" % (what, num))
             return num
