@@ -25,6 +25,7 @@ from asrun.common.sysutils import on_linux
 
 if on_linux():
     COMMAND = {
+        'foreground' : '( %(cmd)s ) > /dev/null 2>&1',
         'background' : '( %(cmd)s ) > /dev/null 2>&1 &',
         'follow_with_stderr' : '( %(cmd)s ; echo %(var)s=$? ) 2>&1 | tee %(output)s',
         'follow_separ_stderr' : '( %(cmd)s ; echo %(var)s=$? ) 2> %(error)s | tee %(output)s',
@@ -36,10 +37,12 @@ if on_linux():
         'ping' : 'ping -c 1 -W %(timeout)s %(host)s',
         'shell_cmd' : "bash -c",
         'file' : "file %(args)s",
+        'hostid' : 'ifconfig',
     }
 else:
     #TODO
     COMMAND = {
+        'foreground' : 'start %(cmd)s',
         'background' : 'start %(cmd)s',
         'follow_with_stderr' : '( %(cmd)s ; echo %(var)s=%errorlevel% ) | tee %(output)s',
         'follow_separ_stderr' : '( %(cmd)s ; echo %(var)s=%errorlevel% ) | tee %(output)s',
@@ -51,4 +54,5 @@ else:
         'ping' : 'ping -n 1 -w %(timeout)s %(host)s',
         'shell_cmd' : "cmd.exe",
         'file' : "file %(args)s", #XXX
+        'hostid' : 'ipconfig',
     }
