@@ -20,19 +20,20 @@
 """
 Build a list of testcases using a list of command/keywords and/or
 verifying some criterias about cputime or memory.
-
-Supported parameters :  ['mem_aster', 'ncpus', 'tps_job', 'mem_job']
 """
-
+PARAMS = ('memory_limit', 'memjob', 'time_limit', 'tpsjob', 'mem_aster',
+          'ncpus', 'mpi_nbnoeud', 'mpi_nbcpu', 'testlist')
 
 import os
 import os.path as osp
 import re
 from glob         import glob
 
+from asrun.core import magic
 from asrun.installation import aster_root
 from asrun.common.i18n import _
 from asrun.mystring     import print3, ufmt
+from asrun.profil       import AsterProfil
 from asrun.config       import build_config_of_version
 from asrun.progress     import Progress
 from asrun.common.utils import getpara, get_list, list_para_test, force_list
@@ -98,7 +99,7 @@ class LISTE_CT(object):
         self.alltest = all
         self.filter = []
         self.liste_crit = []
-        self.list_para_test = list_para_test + ['liste_test']
+        self.list_para_test = list_para_test
         self.verbose = verbose
         if self.verbose:
             print3(ufmt(_(u'Directory of testcases : %s'), self.astest_dir))
@@ -106,49 +107,69 @@ class LISTE_CT(object):
     def add_ct(self, l_file):
         """Ajoute des cas-tests dans la liste.
         """
-        new_ct = []
+        new_ct = set()
         if len(l_file) == 0 and self.alltest:
             if self.verbose:
-                print3(ufmt(_(u"Searching '*.comm' from %s..."), ','.join(self.astest_dir)))
+                print3(ufmt(_(u"Searching '*.export' from %s..."), ','.join(self.astest_dir)))
             l_file = '*'
         # sans extension
         for ct in l_file:
-            l_gl = force_list(self.filename(ct, 'comm'))
-            new_ct.extend([osp.basename(osp.splitext(t)[0]) for t in l_gl])
-        # tests existants
-        new_ct = set([ct for ct in new_ct if osp.isfile(self.filename(ct, 'comm'))])
+            l_gl = self.filename(ct, 'export', first_only=False)
+            new_ct.update([osp.basename(osp.splitext(t)[0]) for t in l_gl])
         new_ct.update(self.liste_ct)
         self.liste_ct = list(new_ct)
         self.liste_ct.sort()
         if self.verbose:
             print3(ufmt(_(u'%6d testcases in the list.'), len(self.liste_ct)))
 
-    def filename(self, ct, ext):
-        """Retourne le nom du fichier du cas-test.
-        """
+    def filename(self, ct, ext, first_only=True):
+        """Retourne la liste des fichiers du cas-test qui existent dans les
+        répertoires."""
         lf = []
         for tdir in self.astest_dir:
             lf.extend(glob(osp.join(tdir, '%s.%s' % (ct, ext))))
-        return len(lf) == 1 and lf[0] or lf
+        if first_only and len(lf) >= 1:
+            lf = lf[0]
+        return lf
 
     def read_para_ct(self, ct):
-        """Lecture du fichier .para d'un cas-test
-        """
-        return getpara(self.filename(ct, 'para'), others=['liste_test'])
+        """Lecture des paramètres d'un cas-test"""
+        export = self.filename(ct, 'export')
+        if not export:
+            para = self.filename(ct, 'para')
+            assert para, 'neither .export or .para found for %s' % ct
+            return getpara(para, others=['liste_test'])
+        pexp = AsterProfil(export, magic.run)
+        dpara = {}
+        for key in PARAMS:
+            val = pexp[key][0]
+            if val.isdigit():
+                dpara[key] = int(val)
+            else:
+                try:
+                    dpara[key] = float(val)
+                except ValueError:
+                    dpara[key] = val
+        # compatibility
+        dpara['mem_job'] = dpara['memory_limit']
+        dpara['tps_job'] = dpara['time_limit']
+        return 0, dpara, ''
 
     def decode_critere(self, txt):
         """Rend le critère évaluable sur le dictonnaire des paramètres d'un cas-test
         """
-        mat = re.search(' *([a-z_]+) *([<>=]+) *([a-zA-Z0-9_\'\"]+) *', txt)
+        mat = re.search(' *([a-zA-Z0-9_\'\"]+) *((?:not *)?(?:[<>=]+|in)) *([a-zA-Z0-9_\'\"]+) *', txt)
         crit = None
         if mat is None:
             print3(ufmt(_(u'>>> Invalid criteria : %s'), txt))
         else:
             key, comp, val = mat.groups()
-            if key not in self.list_para_test:
-                print3(ufmt(_(u'>>> Unknown parameter : %s'), key))
-            else:
+            if key in self.list_para_test:
                 crit = "d['%s'] %s %s" % (key, comp, val)
+            elif val in self.list_para_test:
+                crit = "%s %s d['%s']" % (key, comp, val)
+            else:
+                print3(ufmt(_(u'>>> Unknown parameter : %s'), key))
         return crit
 
     def decode_cmde(self, txt0):
@@ -229,7 +250,7 @@ class LISTE_CT(object):
             # texte du jdc
             if need_content:
                 l_content = []
-                for fic in self.filename(ct, 'com*'):
+                for fic in self.filename(ct, 'com*', first_only=False):
                     l_content.append(open(fic, 'r').read())
                 jdc = os.linesep.join(l_content)
             else:
@@ -283,8 +304,7 @@ def TestList(run, *args):
             run.Mess(ufmt(_(u'error during reading file : %s'), run['test_list']), '<F>_ERROR')
 
     l_dirs = run.get('astest_dir', ','.join(conf['SRCTEST']))
-    l_dirs = [os.path.join(REPREF, os.path.abspath(p.strip())) \
-            for p in l_dirs.split(',')]
+    l_dirs = [osp.abspath(osp.join(REPREF, p.strip())) for p in l_dirs.split(',')]
 
     run.PrintExitCode = False
     if run['debug']:
