@@ -32,20 +32,18 @@ from asrun.installation import aster_root
 
 if __name__ == '__main__':
 
-   VERSION    = 'NEW10'
+   VERSION    = 'unstable'
    REPREF     = os.path.join(aster_root, VERSION)
    run = AsRunFactory()
 
    #-------------------------------------------------------------------------------
    # Methods to build Code_Aster
    from asrun.build     import AsterBuild
-   from asrun.config    import AsterConfig
+   from asrun.config    import build_config_of_version
 
    # help(AsterBuild)    prints help on available methods
 
-   fconf = os.path.join(REPREF, 'config.txt')
-
-   conf = AsterConfig(fconf, run)
+   conf = build_config_of_version(run, VERSION)
    build = AsterBuild(run, conf)
 
    # Compile all files of a directory
