@@ -178,7 +178,7 @@ class TestMisc(unittest.TestCase):
 
     def test09_Configuration(self):
         from asrun.core.configuration import Configuration, Entry, EntryAlias
-        from asrun.common.sysutils import CommandLine
+        from asrun.common.sysutils import CommandLine, get_display
         # without...
         ls = CommandLine("ls")
         assert ls.get_cmd() == "ls", ls.get_cmd()
@@ -186,8 +186,11 @@ class TestMisc(unittest.TestCase):
         assert ls.get_cmdline() == "ls", ls.get_cmdline()
         # ...and with argument
         edit = CommandLine("/usr/bin/editor", "--display=@D")
-        refv = "/usr/bin/editor --display=%s" % os.environ.get("DISPLAY", ":0.0")
-        assert edit.get_cmdline() == refv, edit.get_cmdline()
+        disp = os.environ.get("DISPLAY", ":0.0")
+        if ':0' in disp:
+            disp = get_display()
+        refv = "/usr/bin/editor --display=%s" % disp
+        assert edit.get_cmdline() == refv, (edit.get_cmdline(), refv)
 
         simple_entry = Entry("terminal", "xterm", "doc string")
         edit_entry = Entry("editor", edit, "Entry using a CommandLine object")
