@@ -15,7 +15,9 @@ class TestPackage(unittest.TestCase):
         aster_root_ini = os.environ.get("ASTER_ROOT")
         assert aster_root_ini, "ASTER_ROOT environment variable required!"
         inst = osp.join(get_python_lib(prefix=aster_root_ini), "asrun", "installation.py")
-        
+        cmd = "%s run_test.py [args]" % os.environ['PYTHONEXECUTABLE']
+        assert osp.exists(inst), "%s not found. You should probably run %s" % (inst, cmd)
+
         def run_inst(aster_root):
             previous = os.environ.get("ASTER_ROOT")
             os.environ["ASTER_ROOT"] = aster_root
@@ -24,7 +26,7 @@ class TestPackage(unittest.TestCase):
             os.environ["ASTER_ROOT"] = previous
             return tuple([ctxt[var] for var in \
                         ("aster_root", "prefix", "confdir", "datadir", "localedir")])
-        
+
         #XXX adjustement needed to be check on windows
         res = run_inst("/opt/aster")
         assert res == ("/opt/aster", "/opt/aster", "/opt/aster/etc/codeaster",
@@ -35,7 +37,6 @@ class TestPackage(unittest.TestCase):
 
 
 if __name__ == "__main__":
-   #unittest.main()
-   pass
+   unittest.main()
 
 
