@@ -185,6 +185,17 @@ class TestObjects(unittest.TestCase):
             fname.set_pathname("%s:$HOME/fname_$LOGNAME.ext" % rhost)
             assert fname.path.find(':') < 0, fname.path
 
+    def test02h_entry_collection(self):
+        #check that we can change values into EntryExport objects
+        # even if _compatibility must be called
+        run = AsRunFactory()
+        sample = osp.join("datafiles", "sample2.export")
+        prof = AsterProfil(sample, run)
+        for entr in prof.get_data():
+            entr.path = osp.basename(entr.path) + '.changed'
+        prof._compatibility()
+        assert prof.get_data()[0].path.endswith('.changed'), prof
+
     def test03_config(self):
         run = AsRunFactory()
         vers = dict_conf['ASTER_VERSION']
