@@ -6,7 +6,7 @@ import unittest
 import random
 from glob import glob
 
-from common import tmpdir
+from common import dict_conf, tmpdir
 
 import asrun
 from asrun.installation import aster_root
@@ -22,7 +22,7 @@ class TestBuildExport(unittest.TestCase):
         """Initialize run and conf object.
         """
         self.run = AsRunFactory()
-        vers = self.run['default_vers']
+        vers = dict_conf['ASTER_VERSION']
         assert vers is not None, "default_vers is None! Check aster configuration file"
         vers = self.run.get_version_path(vers)
 ##      print "aster_root=", aster_root, vers
@@ -41,7 +41,7 @@ class TestBuildExport(unittest.TestCase):
         lcomm = prof.Get('D', 'comm')
         assert len(lcomm) >= 1
         df = lcomm[0]
-        assert df['ul'] == '1'
+        assert df['ul'] == 1
         assert df['isrep'] == False
         assert df['compr'] == False
         assert df['type'] == 'comm'
@@ -58,7 +58,7 @@ class TestBuildExport(unittest.TestCase):
         assert len(llibr) == 3
         lul = [df['ul'] for df in llibr]
         lul.sort()
-        assert lul == ["11", "21", "22"]
+        assert lul == [11, 21, 22]
 
 
     def test03_build_export_from_files_list(self):
@@ -72,7 +72,7 @@ class TestBuildExport(unittest.TestCase):
         llibr = prof.Get('D', 'libr')
         assert len(llibr) == 1
         df = llibr[0]
-        assert df['ul'] == '34'
+        assert df['ul'] == 34
         assert df['isrep'] is False
         assert df['compr'] is False
         assert df['type'] == 'libr'
