@@ -12,8 +12,9 @@ import sys
 import unittest
 import shutil
 
-from common import tmpdir, on_dev_machine
+from common import tmpdir, on_dev_machine, dict_conf
 
+from asrun.core import magic
 from asrun.run import AsRunFactory
 from asrun.mystring import file_cleanCR
 
@@ -22,6 +23,7 @@ from asrun.mystring import file_cleanCR
 class TestSystem(unittest.TestCase):
 
     def test01_scroll(self):
+        # ssnl127d can be useful to test the scrolling
         can_follow = not sys.stdout.isatty()
         run = AsRunFactory()
         run.print_timer = True
@@ -61,7 +63,7 @@ class TestSystem(unittest.TestCase):
         if not on_dev_machine():
             return
         run = AsRunFactory()
-        path = osp.join("datafiles", "test_profile.sh")
+        path = osp.join(dict_conf['DATA'], "test_profile.sh")
         run.AddToEnv(path)
         assert os.environ.get('TESTVAR') is not None
         assert len(os.environ["TESTVAR"].split(":")) == 2, os.environ['TESTVAR']
@@ -69,10 +71,10 @@ class TestSystem(unittest.TestCase):
 
     def test03_utils(self):
         run = AsRunFactory()
-        path = osp.join("datafiles", "study.comm")
+        path = osp.join(dict_conf['DATA'], "study.comm")
         assert run.IsText(path)
         assert not run.IsTextFileWithCR(path)
-        path = osp.join("datafiles", "with_win_CR.export")
+        path = osp.join(dict_conf['DATA'], "with_win_CR.export")
         assert run.IsText(path)
         assert run.IsTextFileWithCR(path)
 
