@@ -49,13 +49,15 @@ class TestServerFunctions(unittest.TestCase):
         job, jobid_, etat, diag = parse_tail_result(out)
         assert etat == "RUN", etat
 
-        time.sleep(8)
-        cmd = dict_conf["as_run"] + ["--actu", jobid, nomjob, "interactif"]
-        iret, out = execcmd(cmd, "server.4", return_output=True)
-        assert iret == 0
-        etat, diag, node, tcpu, wrk, queue = parse_actu_result(out)
+        etat = None
+        while etat not in ('ENDED', '_'):
+            time.sleep(4)
+            cmd = dict_conf["as_run"] + ["--actu", jobid, nomjob, "interactif"]
+            iret, out = execcmd(cmd, "server.4", return_output=True)
+            assert iret == 0
+            etat, diag, node, tcpu, wrk, queue = parse_actu_result(out)
         assert etat == "ENDED", etat
-        assert diag == "OK", diag
+        assert diag == "<A>_ALARM", diag
 
         cmd = dict_conf["as_run"] + ["--del", jobid, nomjob, "interactif"]
         iret = execcmd(cmd, "server.5")
@@ -82,8 +84,8 @@ class TestServerFunctions(unittest.TestCase):
 
         etat, diag, node, tcpu, wrk, queue = calc.get_state()
         assert etat == "ENDED", etat
-        assert diag == "OK", diag
-        assert run.GetGrav(calc.diag) == 0
+        assert diag == "<A>_ALARM", diag
+        assert run.GetGrav(calc.diag) in (0, 1), calc.diag
         assert os.path.isfile(calc.flash('output'))
         calc.kill()
 
