@@ -2,22 +2,25 @@
 # -*- coding: utf-8 -*-
 
 import os
+import os.path as osp
 import unittest
 
-from common import dict_conf, execcmd, tmpdir
+from common import dict_conf, execcmd, tmpdir, aster_version
 from data   import astout_export
 
 import asrun
 
-srcfiles = os.path.join(dict_conf['ASTER_ROOT'], dict_conf['ASTER_VERSION'], "astest", "efica02a.*")
 
 class TestAstout(unittest.TestCase):
 
     def test01_cmdline(self):
-        export = os.path.join(tmpdir, "astout.export")
+        from asrun.run import AsRunFactory
+        run = AsRunFactory()
+        srcfiles = osp.join(run.get_version_path(aster_version), "astest", "efica02a.*")
+        export = osp.join(tmpdir, "astout.export")
         #dict_conf['ASTER_VERSION'] = 'NEW10_intel'
         open(export, "w").write(astout_export % dict_conf)
-        dest = os.path.join(tmpdir, "astout.rep_test")
+        dest = osp.join(tmpdir, "astout.rep_test")
         try:
             os.makedirs(dest)
         except OSError:
