@@ -66,7 +66,7 @@ def client():
     assert client.get_server_rcinfo() == '1.1'
 
     servers = client.get_server_list()
-    assert len(servers) == 5, servers
+    assert len(servers) == 3, servers
     for serv in servers:
         cfg = client.get_server_config(serv)
         assert cfg['etat'] in ('on', 'off')
@@ -203,7 +203,7 @@ def use_proxy_calcul():
         prof['aster_root'] = root
         assert prof['serveur'][0], prof['serveur']
         req = calcul.request('mem')
-        assert req == 64.0, prof
+        assert req == 128.0, prof
         req = calcul.request('cpu')
         assert req == 1, req
         jret, out = calcul.start()
@@ -254,20 +254,7 @@ class TestClientFunctions(unittest.TestCase):
         use_proxy(prof)
 
     def test03_proxy_aster4(self):
-        #host = "aster4"
-        #assert host in [h.split('.')[0] for h in available_hosts.keys()], host
-        #rcdir = osp.join(tmpdir, 'astkrc')
-        #if osp.exists(rcdir):
-            #shutil.rmtree(rcdir)
-        #run = AsRunFactory(rcdir=rcdir)
-        #client = ClientConfig(rcdir)
-        #shutil.copy(osp.join(dict_conf['DATA'], "config_serveurs"), rcdir)
-        #client.init_server_config()
-
-        #cfg = client.get_server_config(host)
-        #assert cfg, "Can not read configuration of aster4"
-        #self.init_prof_aster4 = pserv = serv_infos_prof(cfg)
-        #pserv['aster_root'] = available_hosts[dict_conf['remhost']]
+        assert len(available_hosts) > 0, "no remote host available."
         pserv = init_prof_aster4()
         # the same test from server side is 110_server.test01_from_cmdline
         export = osp.join(tmpdir, "proxy_batch.export")
