@@ -5,6 +5,8 @@ import os.path as osp
 import sys
 import re
 import platform
+import socket
+import getpass
 from distutils import sysconfig
 from subprocess import Popen, PIPE
 
@@ -15,11 +17,14 @@ def _get_version():
     """get default Code_Aster version used for testcases"""
     fconfig = osp.join(confdir, 'aster')
     txt = open(fconfig, 'r').read()
-    mat = re.search('default_vers *: *(.+)', txt)
+    mat = re.search('^default_vers *: *(.+)', txt, re.M)
     assert mat != None, 'default_vers not found in %s' % fconfig
     vers = mat.group(1)
     return vers
 
+def set_version(vers):
+    global aster_version, dict_conf
+    aster_version = dict_conf['ASTER_VERSION'] = vers
 
 def _get_tmpdir():
     """use current temporary directory"""
@@ -33,7 +38,6 @@ def _get_tmpdir():
     tmpdir = osp.join(mat.group(1), "unittest.as_run.%s" % num)
     return tmpdir
 
-
 def execcmd(cmd, trace_name, return_output=False):
     """execute a command and write output and error to trace_name.xxx"""
     ferr = open(osp.join(tmpdir, trace_name + ".err"), "w")
@@ -48,18 +52,31 @@ def execcmd(cmd, trace_name, return_output=False):
         result = (p.returncode, out)
     return result
 
-
-def init():
+def init(hostlist):
     try:
         os.makedirs(tmpdir)
     except OSError:
         pass
-
+    _check_hosts(hostlist)
 
 def on_dev_machine():
     return platform.uname()[1] == "cli70cx" and \
         osp.abspath(osp.join(__file__, os.pardir, os.pardir)).endswith('ASTK_SERV')
 
+def _check_hosts(hostlist):
+    # fill the available remote hosts
+    from data import available_hosts
+    from asrun.run import AsRunFactory
+    if not hostlist:
+        return
+    hosts = dict([hdir.split(':') for hdir in hostlist.split(',')])
+    run = AsRunFactory()
+    for host, root in hosts.items():
+        if run.Ping(host):
+            available_hosts[host] = root
+    if len(available_hosts) > 0:
+        dict_conf['remhost'] = available_hosts.keys()[0]
+
 
 # to find asrun package
 if os.environ.get('ASTER_ROOT'):
@@ -101,5 +118,8 @@ dict_conf = {
     'DATA' : osp.abspath(osp.join(__file__, os.pardir, "datafiles")),
     'TMPDIR' : tmpdir,
     'as_run' : as_run_cmd,
+    'localhost' : socket.gethostname(),
+    'localuser' : getpass.getuser(),
+    'remhost' : '',
 }
 
