@@ -125,6 +125,8 @@ def get_parameters(version, where, prefix=None):
       func_config_files(parameters, where, version)
       # read config file
       func_config(parameters, where, version)
+      # for auto_update.cron
+      func_config_auto_update(parameters, where)
    # print dict
    log.info("parameters values :")
    pprint(parameters)
@@ -163,6 +165,13 @@ def func_config(param, where, version):
       read_rcfile(config_file, per_file[new])
    # if the philosophy of a field changes, it should be written here.
 
+def func_config_auto_update(param, where):
+    """Store the parameters set in auto_update.cron"""
+    dico = param['server_conf_values']['auto_update.cron'] = {}
+    fname = os.path.join(where, 'bin', 'auto_update.cron')
+    for var in ('VERSIONS_TO_UPDATE', 'VERSIONS_TO_BUILD', 'MAIL_DEST'):
+        mat = re_search(fname, '%s=(.*)' % var)
+        check_and_store(dico, mat, var)
 
 def func_config_files(param, where, version):
    server = ( ('0.0.0', os.path.join(where, 'ASTK', 'ASTK_SERV', 'conf')),
